@@ -28,6 +28,9 @@
 
 MODULE_DESCRIPTION("\
 Driver: AD1848/AD1847/CS4248\n\
+Card: Analog Devices AD1848\n\
+Card: Analog Devices Ad1847\n\
+Card: Crystal Semiconductors CS4248\n\
 ");
 
 int snd_index[SND_CARDS] = SND_DEFAULT_IDX;	/* Index 0-MAX */
