@@ -40,9 +40,15 @@
 
 MODULE_DESCRIPTION("\
 Driver: Aztech Systems AZT2320\n\
+Card: Aztech Systems PRO16V\n\
+Card: Aztech Systems AZT2320\n\
+Card: Aztech Systems AT3300\n\
+Card: Aztech Systems AT3000\n\
+Card: Packard Bell Sound III 336 AM/SP\n\
 ISAPNP: AZT1008=AZT1008,AZT2001\n\
 ISAPNP: AZT2320=AZT0001,AZT0002\n\
 ISAPNP: AZT3002=AZT1004,AZT2001\n\
+ISAPNP: AZT3000=AZT1003,AZT2001\n\
 ");
 
 int snd_index[SND_CARDS] = SND_DEFAULT_IDX;		/* Index 0-MAX */
@@ -115,6 +121,10 @@ static unsigned int snd_card_azt2320_pnpids[] = {
 	(ISAPNP_VENDOR('A','Z','T')<<16)|ISAPNP_DEVICE(0x3002),    /* device */
 	(ISAPNP_VENDOR('A','Z','T')<<16)|ISAPNP_FUNCTION(0x1004),  /* audio */
 	(ISAPNP_VENDOR('A','Z','T')<<16)|ISAPNP_FUNCTION(0x2001),  /* mpu401 */
+	/* Packard Bell Sound III 336 AM/SP */
+	(ISAPNP_VENDOR('A','Z','T')<<16)|ISAPNP_DEVICE(0x3000),    /* device */
+	(ISAPNP_VENDOR('A','Z','T')<<16)|ISAPNP_FUNCTION(0x1002),  /* audio */
+	(ISAPNP_VENDOR('A','Z','T')<<16)|ISAPNP_FUNCTION(0x2001),  /* mpu401 */
 	0	/* end */
 };
 #endif	/* __ISAPNP__ */
@@ -385,7 +395,7 @@ static int __init snd_card_azt2320_probe(int dev, struct snd_card_azt2320 *acard
 	if (snd_fm_port[dev] > 0) {
 		if (snd_opl3_new(card, 0,
 				snd_fm_port[dev], snd_fm_port[dev] + 2,
-				OPL3_HW_AUTO, -1, &synth) < 0)
+				OPL3_HW_AUTO, 1, &synth) < 0)
 			snd_azt2320_printk("no OPL device at 0x%x-0x%x ?\n",
 				snd_fm_port[dev], snd_fm_port[dev] + 2);
 	}
