@@ -107,7 +107,9 @@ MODULE_PARM_DESC(snd_wssdma_size, "DMA size in kB for CMI8330 WSS driver. [DMA_S
 #define CMI8330_LINGAIN   25
 #define CMI8330_CDINGAIN  26
 
-static unsigned char snd_cmi8330_image[] =
+#define image_idx(v) ((v) - CMI8330_RMUX3D)
+
+static unsigned char snd_cmi8330_image[image_idx(CMI8330_CDINGAIN) + 1] =
 {
 	0x40,			/* 16 - recording mux */
 	0x40,			/* 17 - mute mux */
@@ -145,7 +147,7 @@ static struct snd_cmi8330 {
 	snd_card_t *card;
 	struct snd_cmi8330_wss wss;
 	struct snd_cmi8330_sb sb;
-	unsigned char image[10];
+	unsigned char image[image_idx(CMI8330_CDINGAIN) + 1];
 #ifdef __ISAPNP__
 	struct isapnp_dev *cap;
 	struct isapnp_dev *play;
@@ -220,7 +222,7 @@ static int snd_cmi8330_3d_switch(snd_kmixer_element_t *element,
 
 	acard = (struct snd_cmi8330 *) element->private_data;
 	codec = snd_magic_cast(ad1848_t, acard->wss.pcm->private_data, -ENXIO);
-	field = (unsigned int) acard->image[CMI8330_RMUX3D];
+	field = (unsigned int) acard->image[image_idx(CMI8330_RMUX3D)];
 	spin_lock_irqsave(&codec->reg_lock, flags);
 
 	if (w_flag) {
@@ -230,7 +232,7 @@ static int snd_cmi8330_3d_switch(snd_kmixer_element_t *element,
 			snd_mixer_set_bit(&field, 5, 1);
 		}
 		snd_ad1848_out(codec, CMI8330_RMUX3D, field);
-		acard->image[CMI8330_RMUX3D] = (unsigned char) field;
+		acard->image[image_idx(CMI8330_RMUX3D)] = (unsigned char) field;
 	} else {
 		*bitmap = !snd_mixer_get_bit(&field, 5);
 	}
@@ -249,7 +251,7 @@ static int snd_cmi8330_loud_switch(snd_kmixer_element_t *element,
 
 	acard = (struct snd_cmi8330 *) element->private_data;
 	codec = snd_magic_cast(ad1848_t, acard->wss.pcm->private_data, -ENXIO);
-	field = (unsigned int) acard->image[CMI8330_MUTEMUX];
+	field = (unsigned int) acard->image[image_idx(CMI8330_MUTEMUX)];
 	spin_lock_irqsave(&codec->reg_lock, flags);
 
 	if (w_flag) {
@@ -259,7 +261,7 @@ static int snd_cmi8330_loud_switch(snd_kmixer_element_t *element,
 			snd_mixer_set_bit(&field, 6, 1);
 		}
 		snd_ad1848_out(codec, CMI8330_MUTEMUX, field);
-		acard->image[CMI8330_MUTEMUX] = (unsigned char) field;
+		acard->image[image_idx(CMI8330_MUTEMUX)] = (unsigned char) field;
 	} else {
 		*bitmap = !snd_mixer_get_bit(&field, 6);
 	}
@@ -553,9 +555,10 @@ static int __init snd_cmi8330_probe(int dev, struct snd_cmi8330 *acard)
 
 	spin_lock_irqsave(&codec->reg_lock, flags);
 	snd_ad1848_out(codec, AD1848_MISC_INFO,	/* switch on MODE2 */
-		       codec->image[AD1848_MISC_INFO] |= 0x40);
+		       /* codec->image[AD1848_MISC_INFO] |= */
+		       0x40);
 	snd_ad1848_out(codec, CMI8330_RMUX3D,	/* enable SB16 mixer */
-		       acard->image[CMI8330_RMUX3D] |= 0x40);
+		       acard->image[image_idx(CMI8330_RMUX3D)] |= 0x40);
 	spin_unlock_irqrestore(&codec->reg_lock, flags);
 
 	if (snd_cmi8330_mixer(acard) < 0) {
