@@ -40,16 +40,10 @@ ISAPNP: CSCa836=CSCa800,CSCa810,CSCa8a3\n\
 #else
 MODULE_DESCRIPTION("\
 Driver: Cirrus Logic CS4236+\n\
-Card: Generic CS4235\n\
-Card: Generic CS4236B\n\
-Card: Generic CS4237B\n\
-Card: Generic CS4238B\n\
-Card: Generic CS4239\n\
+Card: Generic CS4235,6,7,9\n\
 Card: Genius Sound Maker 3DJ\n\
 Card: HP 6330 Onboard sound\n\
-Card: ACER AW35/Pro\n\
-Card: ACER AW37\n\
-Card: ACER AW37/Pro\n\
+Card: ACER AW3[57]/Pro\n\
 Card: EliteGroup P5TX-LA motherboard\n\
 Card: Dell Optiplex GX1\n\
 Card: Dell Workstation 400 Onboard\n\
@@ -63,6 +57,7 @@ ISAPNP: CSC1425=CSC0100,CSC0110\n\
 ISAPNP: CSC1525=CSC0100,CSC0110,CSC0103\n\
 ISAPNP: CSC4236=CSC0000,CSC0010,CSC0003\n\
 ISAPNP: CSC4237=CSC0000,CSC0010,CSC0003\n\
+ISAPNP: CSC4336=CSC0000,CSC0010,CSC0003\n\
 ISAPNP: CSC4837=CSC0000,CSC0010,CSC0003\n\
 ISAPNP: CSC6835=CSC0000,CSC0010,CSC0003\n\
 ISAPNP: CSC6836=CSC0000,CSC0010,CSC0003\n\
@@ -72,6 +67,7 @@ ISAPNP: CSC9837=CSC0000,CSC0010,CSC0003\n\
 ISAPNP: CSCd925=CSC0000,CSC0010,CSC0003\n\
 ISAPNP: CSCd937=CSC0000,CSC0010,CSC0003\n\
 ISAPNP: CSCe825=CSC0100,CSC0110\n\
+ISAPNP: CSCf235=CSC0000,CSC0010,CSC0003\n\
 ");
 #endif
 
@@ -96,7 +92,9 @@ int snd_dma1[SND_CARDS] = SND_DEFAULT_DMA;	/* 0,1,3,5,6,7 */
 int snd_dma1_size[SND_CARDS] = SND_DEFAULT_DMA_SIZE;	/* 8,16,32,64,128 */
 int snd_dma2[SND_CARDS] = SND_DEFAULT_DMA;	/* 0,1,3,5,6,7 */
 int snd_dma2_size[SND_CARDS] = SND_DEFAULT_DMA_SIZE;	/* 8,16,32,64,128 */
+#ifdef __ISAPNP__
 int snd_isapnp[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = 1};
+#endif
 MODULE_PARM(snd_index, "1-" __MODULE_STRING(SND_CARDS) "i");
 MODULE_PARM_DESC(snd_index, "Index value for " IDENT " soundcard.");
 MODULE_PARM(snd_id, "1-" __MODULE_STRING(SND_CARDS) "s");
@@ -123,8 +121,10 @@ MODULE_PARM(snd_dma2, "1-" __MODULE_STRING(SND_CARDS) "i");
 MODULE_PARM_DESC(snd_dma2, "DMA2 # for " IDENT " driver. [DMA]");
 MODULE_PARM(snd_dma2_size, "1-" __MODULE_STRING(SND_CARDS) "i");
 MODULE_PARM_DESC(snd_dma2_size, "Size of DMA2 # for " IDENT " driver. [DMA_SIZE]");
+#ifdef __ISAPNP__
 MODULE_PARM(snd_isapnp, "1-" __MODULE_STRING(SND_CARDS) "i");
 MODULE_PARM_DESC(snd_isapnp, "ISA PnP detection for specified soundcard. [BOOL]");
+#endif
 
 static struct snd_card_cs4236 {
 	snd_irq_t *irqptr;
@@ -199,6 +199,11 @@ static unsigned int snd_card_pnpids[] = {
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0000), /* WSS */
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0010), /* CTRL */
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0003), /* MPU */
+	/* Crystal 3D - CS4237B */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_DEVICE(0x4336),   /* DEVICE */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0000), /* WSS */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0010), /* CTRL */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0003), /* MPU */
 	/* NewClear 3D - CX4237B-XQ3 */
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_DEVICE(0x4837),   /* DEVICE */
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0000), /* WSS */
@@ -244,6 +249,11 @@ static unsigned int snd_card_pnpids[] = {
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0100), /* WSS */
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0110), /* CTRL */
 	0,							  /* MPU */
+	/* CS4236 */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_DEVICE(0xf235),   /* DEVICE */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0000), /* WSS */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0010), /* CTRL */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0003), /* MPU */
 	/* --- */
 	0	/* end */
 };
@@ -501,9 +511,9 @@ static void snd_card_cs4236_deactivate(struct snd_card_cs4236 *acard)
 	if (acard->wss)
 		acard->wss->deactivate(acard->wss);
 	if (acard->ctrl)
-		acard->wss->deactivate(acard->ctrl);
+		acard->ctrl->deactivate(acard->ctrl);
 	if (acard->mpu)
-		acard->wss->deactivate(acard->mpu);
+		acard->mpu->deactivate(acard->mpu);
 }
 #endif
 
