@@ -223,9 +223,7 @@ static void snd_card_dummy_pcm_interrupt(unsigned long data)
 	dpcm->pcm_buf_pos %= dpcm->pcm_size;
 	while (dpcm->pcm_irq_pos >= dpcm->pcm_count) {
 		dpcm->pcm_irq_pos -= dpcm->pcm_count;
-		spin_unlock_irq(&dpcm->lock);
 		snd_pcm_transfer_done(dpcm->subchn);
-		spin_lock_irq(&dpcm->lock);
 	}
 	spin_unlock_irq(&dpcm->lock);	
 }
