@@ -1,9 +1,7 @@
 /*
  *  Driver for generic ESS AudioDrive ES18xx soundcards
- *  Copyright (c) by Christian Fischbach
- *  <fishbach@pool.informatik.rwth-aachen.de>
- *  Copyright (c) by Abramo Bagnara
- *  <abbagnara@racine.ra.it>
+ *  Copyright (c) by Christian Fischbach <fishbach@pool.informatik.rwth-aachen.de>
+ *  Copyright (c) by Abramo Bagnara <abramo@alsa-project.org>
  *
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -35,7 +33,10 @@ Card: ESS ES1868\n\
 Card: ESS ES1869\n\
 Card: ESS ES1878\n\
 Card: ESS ES1879\n\
+Card: ESS ES1887\n\
+Card: ESS ES1888\n\
 ISAPNP: ESS1868=ESS1868,ESS0000\n\
+ISAPNP: ESS1868=ESS8601,ESS8600\n\
 ISAPNP: ESS1868=ESS8611,ESS8610\n\
 ISAPNP: ESS0003=ESS1869,ESS0006\n\
 ISAPNP: ESS1869=ESS1869,ESS0006\n\
@@ -109,6 +110,10 @@ static unsigned int snd_audiodrive_pnpids[] = {
 	(ISAPNP_VENDOR('E','S','S')<<16)|ISAPNP_FUNCTION(0x0000), /* Control */
 	/* ESS 1868 (integrated on Maxisound Cards) */
 	(ISAPNP_VENDOR('E','S','S')<<16)|ISAPNP_DEVICE(0x1868),	 /* DEVICE */
+	(ISAPNP_VENDOR('E','S','S')<<16)|ISAPNP_FUNCTION(0x8601), /* Audio */
+	(ISAPNP_VENDOR('E','S','S')<<16)|ISAPNP_FUNCTION(0x8600), /* Control */
+	/* ESS 1868 (integrated on Maxisound Cards) */
+	(ISAPNP_VENDOR('E','S','S')<<16)|ISAPNP_DEVICE(0x1868),	 /* DEVICE */
 	(ISAPNP_VENDOR('E','S','S')<<16)|ISAPNP_FUNCTION(0x8611), /* Audio */
 	(ISAPNP_VENDOR('E','S','S')<<16)|ISAPNP_FUNCTION(0x8610), /* Control */
 	/* --- */
@@ -208,9 +213,10 @@ static void snd_audiodrive_interrupt(int irq, void *dev_id, struct pt_regs *regs
 		return;
 
 	if (codec->caps & ES18XX_CONTROL) {
+#if 0
 		/* Mask all interrupts */
 		outb(0, codec->ctrl_port + 7);
-		
+#endif
 		/* Read Interrupt status */
 		status = inb(codec->ctrl_port + 6);
 	}
@@ -237,10 +243,10 @@ static void snd_audiodrive_interrupt(int irq, void *dev_id, struct pt_regs *regs
 		snd_mpu401_uart_interrupt(acard->rmidi);
 	/* Hardware volume */
 	if (status & HWV_IRQ) {
+#if 0 /* TODO!!! */
 		int left,right,mute;
 		left = snd_es18xx_mixer_read(codec, 0x60);
 		right = snd_es18xx_mixer_read(codec, 0x62);
-#if 0 /* TODO!!! */
 		mute = (((left & 0x40) ? SND_MIX_MUTE_LEFT : 0) |
 			((right & 0x40) ? SND_MIX_MUTE_RIGHT : 0));
 		left &= 0x3f;
@@ -248,15 +254,19 @@ static void snd_audiodrive_interrupt(int irq, void *dev_id, struct pt_regs *regs
 		snd_mixer_hardware_volume(acard->mixer, SND_MIXER_PRI_MASTER, 
 					  0, SND_MIX_VOL_OUTPUT,
 					  left, right, mute);
+#else
+		snd_es18xx_mixer_read(codec, 0x60);
+		snd_es18xx_mixer_read(codec, 0x62);
 #endif
 		/* ack interrupt */
 		snd_es18xx_mixer_write(codec, 0x66, 0x00);
 	}
-
+#if 0
 	if (codec->caps & ES18XX_CONTROL) {
 		/* Unmask all interrupts */
 		outb(0x0f, codec->ctrl_port + 7);
 	}
+#endif
 }
 
 static int __init snd_audiodrive_resources(int dev,
@@ -378,11 +388,9 @@ static void snd_audiodrive_deactivate(struct snd_audiodrive *acard)
 
 static int __init snd_audiodrive_probe(int dev, struct snd_audiodrive *acard)
 {
-#ifndef __ISAPNP__
 	static int possible_ports[] =
 		{0x220, 0x240, 0x260, 0x280, -1};
 	int *ports = possible_ports;
-#endif
 	snd_card_t *card;
 	snd_pcm_t *pcm = NULL;
 	snd_kmixer_t *mixer = NULL;
@@ -407,8 +415,10 @@ static int __init snd_audiodrive_probe(int dev, struct snd_audiodrive *acard)
 		return -EBUSY;
 	}
 	codec = NULL;
-#ifndef __ISAPNP__
 	if(snd_port[dev] == SND_AUTO_PORT) {
+		/* Note: if snd_isapnp[dev]=1, snd_port[dev] is redefined
+		   always, so that this legacy auto-probe is not applied.
+		   */
 		for(ports = possible_ports; *ports >= 0; ports++) {
 			codec = snd_audiodrive_detect(card, *ports,
 				snd_mpu_port[dev], snd_fm_port[dev],
@@ -421,7 +431,6 @@ static int __init snd_audiodrive_probe(int dev, struct snd_audiodrive *acard)
 			return -ENODEV;
 		}
 	} else {
-#endif
 		codec = snd_audiodrive_detect(card, snd_port[dev],
 			snd_mpu_port[dev], snd_fm_port[dev],
 			acard->irqptr, acard->dma1ptr, acard->dma2ptr);
@@ -429,9 +438,7 @@ static int __init snd_audiodrive_probe(int dev, struct snd_audiodrive *acard)
 			snd_card_free(card);
 			return -ENODEV;
 		}
-#ifndef __ISAPNP__
 	}
-#endif
 	err = snd_es18xx_pcm(codec, 0, &pcm);
 	if (err < 0)
 		goto __nodev;
