@@ -56,6 +56,9 @@ ISAPNP: ADV550a=ADV0010,ADV0015\n\
 
 int snd_index[SND_CARDS] = SND_DEFAULT_IDX;	/* Index 0-MAX */
 char *snd_id[SND_CARDS] = SND_DEFAULT_STR;	/* ID for this card */
+#ifdef __ISAPNP__
+int snd_isapnp[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = 1};
+#endif
 int snd_port[SND_CARDS] = SND_DEFAULT_PORT;	/* 0x210,0x220,0x230,0x240,0x250,0x260 */
 #ifdef SND_STB
 int snd_port_tc[SND_CARDS] = SND_DEFAULT_PORT;	/* 0x350,0x360,0x370,0x380 */
@@ -74,6 +77,10 @@ MODULE_PARM(snd_index, "1-" __MODULE_STRING(SND_CARDS) "i");
 MODULE_PARM_DESC(snd_index, "Index value for InterWave soundcard.");
 MODULE_PARM(snd_id, "1-" __MODULE_STRING(SND_CARDS) "s");
 MODULE_PARM_DESC(snd_id, "ID string for InterWave soundcard.");
+#ifdef __ISAPNP__
+MODULE_PARM(snd_isapnp, "1-" __MODULE_STRING(SND_CARDS) "i");
+MODULE_PARM_DESC(snd_isapnp, "ISA PnP detection for specified soundcard. [BOOL]");
+#endif
 MODULE_PARM(snd_port, "1-" __MODULE_STRING(SND_CARDS) "i");
 MODULE_PARM_DESC(snd_port, "Port # for InterWave driver. [list=0x210,0x220,0x230,0x240,0x250,0x260]");
 #ifdef SND_STB
@@ -847,11 +854,9 @@ static void snd_interwave_deactivate(struct snd_interwave *iwcard)
 
 static int __init snd_interwave_probe(int dev, struct snd_interwave *iwcard)
 {
-#ifndef __ISAPNP__
 	static int possible_ports[] =
 			{0x210, 0x220, 0x230, 0x240, 0x250, 0x260, -1};
 	int *ports = possible_ports;
-#endif
 	snd_card_t *card;
 	snd_gus_card_t *gus = NULL;
 	snd_pcm_t *pcm = NULL;
@@ -866,7 +871,7 @@ static int __init snd_interwave_probe(int dev, struct snd_interwave *iwcard)
 	if (card == NULL)
 		return -ENOMEM;
 #ifdef __ISAPNP__
-	if (snd_interwave_isapnp(dev, iwcard)) {
+	if (snd_isapnp[dev] && snd_interwave_isapnp(dev, iwcard)) {
 		snd_card_free(card);
 		return -ENODEV;
 	}
@@ -885,8 +890,10 @@ static int __init snd_interwave_probe(int dev, struct snd_interwave *iwcard)
 		snd_card_free(card);
 		return -ENOMEM;
 	}
-#ifndef __ISAPNP__
 	if (snd_port[dev] == SND_AUTO_PORT) {
+		/* Note: if snd_isapnp[dev]=1, snd_port[dev] is redefined
+		   always, so that this legacy auto-probe is not applied.
+		   */
 		for (ports = possible_ports; *ports >= 0; ports++) {
 			if (!snd_interwave_detect(iwcard, gus, *ports, dev))
 				break;
@@ -896,14 +903,11 @@ static int __init snd_interwave_probe(int dev, struct snd_interwave *iwcard)
 			return -ENODEV;
 		}
 	} else {
-#endif
 		if (snd_interwave_detect(iwcard, gus, snd_port[dev], dev)) {
 			snd_card_free(card);
 			return -ENODEV;
 		}
-#ifndef __ISAPNP__
 	}
-#endif
 	iwcard->gus_status_reg = gus->gf1.reg_irqstat;
 	iwcard->pcm_status_reg = gus->gf1.port + 0x10c + 2;
 	snd_interwave_init(dev, gus);
