@@ -80,20 +80,20 @@ MODULE_PARM_DESC(snd_index, "Index value for opti9xx based soundcard.");
 MODULE_PARM(snd_id, "s");
 MODULE_PARM_DESC(snd_id, "ID string for opti9xx based soundcard.");
 MODULE_PARM(snd_port, "i");
-MODULE_PARM_DESC(snd_port, "WSS port # for opti9xx driver.");
+MODULE_PARM_DESC(snd_port, "WSS port # for opti9xx driver. [list=0x530,0xe80,0xf40,0x604]");
 MODULE_PARM(snd_mpu_port, "i");
-MODULE_PARM_DESC(snd_mpu_port, "MPU-401 port # for opti9xx driver.");
+MODULE_PARM_DESC(snd_mpu_port, "MPU-401 port # for opti9xx driver. [list=0x300,0x310,0x320,0x330]");
 MODULE_PARM(snd_fm_port, "i");
-MODULE_PARM_DESC(snd_fm_port, "FM port # for opti9xx driver.");
+MODULE_PARM_DESC(snd_fm_port, "FM port # for opti9xx driver. [list=0x388]");
 MODULE_PARM(snd_irq, "i");
-MODULE_PARM_DESC(snd_irq, "WSS irq # for opti9xx driver.");
+MODULE_PARM_DESC(snd_irq, "WSS irq # for opti9xx driver. [IRQ]");
 MODULE_PARM(snd_mpu_irq, "i");
-MODULE_PARM_DESC(snd_mpu_irq, "MPU-401 irq # for opti9xx driver.");
+MODULE_PARM_DESC(snd_mpu_irq, "MPU-401 irq # for opti9xx driver. [IRQ]");
 MODULE_PARM(snd_dma1, "i");
-MODULE_PARM_DESC(snd_dma1, "1st dma # for opti9xx driver.");
+MODULE_PARM_DESC(snd_dma1, "1st dma # for opti9xx driver. [DMA8]");
 #if defined(CS4231) || defined(OPTi93X)
 MODULE_PARM(snd_dma2, "i");
-MODULE_PARM_DESC(_DESCsnd_dma2, "2nd dma # for opti9xx driver.");
+MODULE_PARM_DESC(snd_dma2, "2nd dma # for opti9xx driver. [DMA8]");
 #endif	/* CS4231 || OPTi93X */
 
 
@@ -212,9 +212,12 @@ static opti9xx_t * __init snd_card_opti9xx_detect(snd_card_t *card)
 		}
 
 		value = snd_opti9xx_read(chip, OPTi9XX_MC_REG(1));
-		if ((value != 0xff) && (value != inb(chip->mc_base + 1)))
+		if (value != 0xff) {
+			if (value != inb(chip->mc_base + 1))
+				snd_printk("warning: opti92x: port didn't close after read\n");
 			if (value == snd_opti9xx_read(chip, OPTi9XX_MC_REG(1)))
 				break;
+		}
 
 		snd_unregister_ioports(card);
 		snd_kfree(chip);
@@ -369,7 +372,7 @@ static int __init snd_card_opti9xx_resources(struct snd_card_opti9xx *acard,
 	int error, i, pnp = 0;
 	static int no_alternatives[] = {-1};
 	static int possible_ports[] = {0x530, 0xe80, 0xf40, 0x604, -1};
-	static int possible_mpu_ports[] = {0x300, 0x310, 0x320, 0x310, -1};
+	static int possible_mpu_ports[] = {0x300, 0x310, 0x320, 0x330, -1};
 #ifdef OPTi93X
 	static int possible_irqs[] = {5, 9, 10, 11, 7, -1};
 #else
@@ -571,7 +574,11 @@ static int __init snd_card_opti9xx_probe(struct snd_card_opti9xx *acard)
 	else
 		if ((error = snd_opl3_new(card, 0,
 				acard->chip->fm_port, acard->chip->fm_port + 2,
+#ifdef CS4231
+				OPL3_HW_AUTO, 1, &synth)))
+#else
 				OPL3_HW_AUTO, 0, &synth)))
+#endif	/* CS4231 */
 			snd_card_opti9xx_printk("no OPL device at 0x%x-0x%x?\n",
 				acard->chip->fm_port, acard->chip->fm_port + 2);
 
