@@ -35,6 +35,7 @@ Driver: Sound Blaster 16\n\
 ISAPNP: CTL0024=CTL0041\n\
 ISAPNP: CTL0026=CTL0031\n\
 ISAPNP: CTL0027=CTL0031\n\
+ISAPNP: CTL0028=CTL0031\n\
 ISAPNP: CTL0029=CTL0031\n\
 ISAPNP: CTL002b=CTL0031\n\
 ISAPNP: CTL0051=CTL0001\n\
@@ -56,6 +57,7 @@ ISAPNP: CTL0054=CTL0031,CTL0021\n\
 ISAPNP: CTL009c=CTL0041,CTL0021\n\
 ISAPNP: CTL009d=CTL0042,CTL0022\n\
 ISAPNP: CTL009e=CTL0044,CTL0023\n\
+ISAPNP: CTL00b2=CTL0044,CTL0023\n\
 ISAPNP: CTL00c1=CTL0042,CTL0022\n\
 ISAPNP: CTL00c3=CTL0045,CTL0022\n\
 ISAPNP: CTL00c5=CTL0045,CTL0022\n\
@@ -76,7 +78,7 @@ int snd_index[SND_CARDS] = SND_DEFAULT_IDX;	/* Index 0-MAX */
 char *snd_id[SND_CARDS] = SND_DEFAULT_STR;	/* ID for this card */
 int snd_port[SND_CARDS] = SND_DEFAULT_PORT;	/* 0x220,0x240,0x260 */
 int snd_mpu_port[SND_CARDS] = {0x330, 0x300,[2 ... (SND_CARDS - 1)] = -1};
-int snd_fm_port[SND_CARDS] = SND_DEFAULT_PORT;	/* optional, not used */
+int snd_fm_port[SND_CARDS] = {0x388, [1 ... (SND_CARDS - 1)] = -1};
 #ifdef SND_SBAWE_EMU8000
 int snd_awe_port[SND_CARDS] = {0x620,[1 ... (SND_CARDS - 1)] = -1};
 #endif
@@ -170,6 +172,9 @@ static unsigned int snd_sb16_pnpids[] = {
 	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_DEVICE(0x0027),   /* DEVICE */
 	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_FUNCTION(0x0031), /* Audio */
 	/* Sound Blaster 16 PnP */
+	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_DEVICE(0x0028),   /* DEVICE */
+	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_FUNCTION(0x0031), /* Audio */
+	/* Sound Blaster 16 PnP */
 	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_DEVICE(0x0029),   /* DEVICE */
 	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_FUNCTION(0x0031), /* Audio */
 	/* Sound Blaster 16 PnP */
@@ -243,6 +248,12 @@ static unsigned int snd_sb16_pnpids[] = {
 	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_FUNCTION(0x0044), /* Audio */
 #ifdef SND_SBAWE_EMU8000
 	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_FUNCTION(0x0023), /* WaveTable */
+#endif
+	/* Sound Blaster AWE 64 PnP Gold */
+	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_DEVICE(0x00b2),   /* DEVICE */
+	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_FUNCTION(0x0044), /* Audio */
+#ifdef SND_SBAWE_EMU8000
+	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_FUNCTION(0x0023), /* WaveTable */
 #endif
 	/* Sound Blaster AWE 64 PnP */
 	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_DEVICE(0x00c1),   /* DEVICE */
@@ -542,10 +553,8 @@ static void snd_sb16_deactivate(struct snd_sb16 *acard)
 
 static int __init snd_sb16_probe(int dev, struct snd_sb16 *acard)
 {
-#ifndef __ISAPNP__
 	static int possible_ports[] = {0x220, 0x240, 0x260, -1};
 	int *ports = possible_ports;
-#endif
 	sbdsp_t *codec;
 	snd_card_t *card;
 	snd_pcm_t *pcm = NULL;
@@ -576,8 +585,10 @@ static int __init snd_sb16_probe(int dev, struct snd_sb16 *acard)
 		snd_card_free(card);
 		return -EBUSY;
 	}
-#ifndef __ISAPNP__
 	if (snd_port[dev] == SND_AUTO_PORT) {
+		/* Note: if snd_isapnp[dev]=1, snd_port[dev] is redefined
+		   always, so that this legacy auto-probe is not applied.
+		   */
 		for (ports = possible_ports; *ports >= 0; ports++) {
 			pcm = snd_sb16_detect(dev, card, *ports,
 					      acard->irqptr,
@@ -587,14 +598,11 @@ static int __init snd_sb16_probe(int dev, struct snd_sb16 *acard)
 				break;
 		}
 	} else {
-#endif
 		pcm = snd_sb16_detect(dev, card, snd_port[dev],
 				      acard->irqptr,
 				      acard->dma8ptr,
 				      acard->dma16ptr);
-#ifndef __ISAPNP__
 	}
-#endif
 	if (pcm == NULL) {
 		snd_card_free(card);
 		return -ENODEV;
@@ -685,7 +693,7 @@ static int __init snd_sb16_probe(int dev, struct snd_sb16 *acard)
 #endif
 		acard->rmidi = rmidi;
 #ifdef CONFIG_SND_SEQUENCER
-		/*acard->synth = synth;*/
+		acard->synth = synth;
 #endif
 #ifdef SND_SBAWE_EMU8000
 		acard->awe = awe;
