@@ -363,10 +363,10 @@ static void snd_via686a_setup_fragments(via686a_t *codec, viadev_t *viadev,
 
 static inline void snd_via686a_update(via686a_t *codec, viadev_t *viadev)
 {
-	spin_lock_irq(&codec->reg_lock);
+	spin_lock(&codec->reg_lock);
 	viadev->position += viadev->fragsize;
 	viadev->position %= viadev->size;
-	spin_unlock_irq(&codec->reg_lock);
+	spin_unlock(&codec->reg_lock);
 	snd_pcm_transfer_done(viadev->subchn);
 	outb(VIA_REG_STAT_FLAG | VIA_REG_STAT_EOL, VIAREG(codec, OFFSET_STATUS) + viadev->reg_offset);
 }
@@ -481,8 +481,6 @@ static int snd_via686a_capture_prepare(void *private_data,
 	via686a_t *codec = snd_magic_cast(via686a_t, private_data, -ENXIO);
 	snd_pcm_runtime_t *runtime = subchn->runtime;
 
-	*((int *)runtime->dma_area->buf) = 0x55aa55aa;
-	memset(runtime->dma_area->buf, 0, snd_pcm_lib_transfer_size(subchn));
 	codec->capture.physbuf = virt_to_bus(runtime->dma_area->buf);
 	codec->capture.size = snd_pcm_lib_transfer_size(subchn);
 	codec->capture.fragsize = snd_pcm_lib_transfer_fragment(subchn);
@@ -955,7 +953,7 @@ static int snd_via686a_chip_init(via686a_t *codec)
 	pci_write_config_byte(codec->pci, 0x41, 0x60);
 	udelay(2);
 	/* ACLink on, deassert ACLink reset, VSR, SGD data out */
-	/* not FM data out has trouble with non VRA codecs !! */
+	/* note - FM data out has trouble with non VRA codecs !! */
 	pci_write_config_byte(codec->pci, 0x41, 0xcc);
 
 	snd_via686a_codec_ready(codec, 0, 1);
