@@ -109,13 +109,13 @@ snd_wavefront_isapnp (int dev, snd_wavefront_card_t *acard, int pnp_id)
 	static struct isapnp_card *card = NULL;
 	unsigned int tmp;
 	struct isapnp_dev *pdev;
-    
+
 	tmp = (ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_DEVICE(pnp_id);
 
 	/* Find the device */
 
 	if ((card = isapnp_find_card (tmp >> 16, tmp & 0xffff, card)) == NULL) {
-		snd_printk ("isapnp failed for device\n");
+		snd_printk (LOGNAME "isapnp: device not found\n");
 		return -ENODEV;
 	}
 
@@ -144,7 +144,7 @@ snd_wavefront_isapnp (int dev, snd_wavefront_card_t *acard, int pnp_id)
 	tmp = snd_wavefront_pnpids[3];
 	acard->synth = isapnp_find_dev(card, tmp >> 16, tmp & 0xffff, NULL);
 	if (acard->synth == NULL) {
-		snd_printk (LOGNAME "isapnp failed for Synth device\n");
+		snd_printk (LOGNAME "isapnp no SYNTH device found\n");
 		return -ENODEV;
 	}
 
@@ -157,7 +157,7 @@ snd_wavefront_isapnp (int dev, snd_wavefront_card_t *acard, int pnp_id)
 		acard->mpu = isapnp_find_dev(card, tmp >> 16, 
 					     tmp & 0xffff, NULL);
 		if (acard->mpu == NULL) {
-			snd_printk ("isapnp failed for CS4232 MPU-401\n");
+			snd_printk (LOGNAME "isapnp CS4232 MPU-401 device not found\n");
 			return -ENODEV;
 		}
 	}
@@ -165,8 +165,18 @@ snd_wavefront_isapnp (int dev, snd_wavefront_card_t *acard, int pnp_id)
 	/* PCM/FM initialization */
 
 	pdev = acard->wss;
-	if (pdev->prepare(pdev)<0)
+
+	if ((tmp = pdev->prepare (pdev)) < 0) {
+		if (tmp == -EBUSY) {
+			snd_printk (LOGNAME
+				    "ISA PnP configuration appears to have been "
+				    "done. Restart the isa-pnp module.\n");
+			return 0;
+		}
+				    
+		snd_printk (LOGNAME "isapnp WSS preparation failed\n");
 		return -EAGAIN;
+	}
 
 	if (snd_cs4232_pcm_port[dev] != SND_AUTO_PORT)
 		isapnp_resource_change(&pdev->resource[0], snd_cs4232_pcm_port[dev], 4);
@@ -186,7 +196,7 @@ snd_wavefront_isapnp (int dev, snd_wavefront_card_t *acard, int pnp_id)
 		isapnp_resource_change(&pdev->irq_resource[0], snd_cs4232_pcm_irq[dev], 1);
 
 	if (pdev->activate(pdev)<0) {
-		snd_printk (LOGNAME "isapnp configuration failed\n");
+		snd_printk (LOGNAME "isapnp WSS activation failed\n");
 		return -EBUSY;
 	}
 
@@ -199,9 +209,9 @@ snd_wavefront_isapnp (int dev, snd_wavefront_card_t *acard, int pnp_id)
 	snd_dma2[dev] = pdev->dma_resource[1].start == 4 ? -1 : pdev->dma_resource[1].start;
 	snd_cs4232_pcm_irq[dev] = pdev->irq_resource[0].start;
 
-	snd_printk ("isapnp CS4232: port=0x%x, fm port=0x%x, wss port=0x%x\n",
+	snd_printk (LOGNAME "isapnp CS4232: port=0x%x, fm port=0x%x, wss port=0x%x\n",
 		    snd_cs4232_pcm_port[dev], snd_fm_port[dev], snd_wss_port[dev]);
-	snd_printk ("isapnp CS4232: dma1=%i, dma2=%i, irq=%i\n",
+	snd_printk (LOGNAME "isapnp CS4232: dma1=%i, dma2=%i, irq=%i\n",
 		    snd_dma1[dev], snd_dma2[dev], snd_cs4232_pcm_irq[dev]);
 
 	/* CTRL initialization */
@@ -212,6 +222,7 @@ snd_wavefront_isapnp (int dev, snd_wavefront_card_t *acard, int pnp_id)
 
 		if (pdev->prepare(pdev)<0) {
 			acard->wss->deactivate(acard->wss);
+			snd_printk (LOGNAME "isapnp CTRL preparation failed\n");
 			return -EAGAIN;
 		}
 		
@@ -219,13 +230,13 @@ snd_wavefront_isapnp (int dev, snd_wavefront_card_t *acard, int pnp_id)
 			isapnp_resource_change(&pdev->resource[0], snd_control_port[dev], 8);
 		
 		if (pdev->activate(pdev)<0) {
-			snd_printk(LOGNAME "isapnp configuration failed (step 2)\n");
+			snd_printk(LOGNAME "isapnp CTRL activation failed\n");
 			acard->wss->deactivate(acard->wss);
 			return -EBUSY;
 		}
 		
 		snd_control_port[dev] = pdev->resource[0].start;
-		snd_printk ("isapnp CTRL: control port=0x%x\n", 
+		snd_printk (LOGNAME "isapnp CTRL: control port=0x%x\n", 
 			    snd_control_port[dev]);
 	}
 
@@ -239,6 +250,7 @@ snd_wavefront_isapnp (int dev, snd_wavefront_card_t *acard, int pnp_id)
 			acard->wss->deactivate(acard->wss);
 			if (acard->ctrl)
 				acard->ctrl->deactivate(acard->ctrl);
+			snd_printk (LOGNAME "ICS2115 synth preparation failed\n");
 			return -EAGAIN;
 		}
 		
@@ -247,7 +259,7 @@ snd_wavefront_isapnp (int dev, snd_wavefront_card_t *acard, int pnp_id)
 			isapnp_resource_change(&pdev->irq_resource[0], snd_ics2115_irq[dev], 1);
 
 		if (pdev->activate(pdev)<0) {
-			snd_printk(LOGNAME "isapnp synth configuration failed\n");
+			snd_printk(LOGNAME "synth configuration failed\n");
 			acard->wss->deactivate(acard->wss);
 			if (acard->ctrl)
 				acard->ctrl->deactivate(acard->ctrl);
@@ -274,6 +286,7 @@ snd_wavefront_isapnp (int dev, snd_wavefront_card_t *acard, int pnp_id)
 				acard->ctrl->deactivate(acard->ctrl);
 			if (acard->synth)
 				acard->synth->deactivate(acard->synth);
+			snd_printk (LOGNAME "CS4232 MPU preparation failed\n");
 			return -EAGAIN;
 		}
 
@@ -283,7 +296,7 @@ snd_wavefront_isapnp (int dev, snd_wavefront_card_t *acard, int pnp_id)
 			isapnp_resource_change(&pdev->resource[0], snd_cs4232_mpu_irq[dev], 1);
 
 		if (pdev->activate(pdev)<0) {
-			snd_printk(LOGNAME "isapnp CS4232 MPU configuration failed\n");
+			snd_printk(LOGNAME "isapnp CS4232 MPU activation failed\n");
 			snd_cs4232_mpu_port[dev] = SND_AUTO_PORT;
 		} else {
 			snd_cs4232_mpu_port[dev] = pdev->resource[0].start;
@@ -301,6 +314,8 @@ snd_wavefront_isapnp (int dev, snd_wavefront_card_t *acard, int pnp_id)
 static void 
 snd_wavefront_deactivate (snd_wavefront_card_t *acard)
 {
+	snd_printk (LOGNAME "deactivating PnP devices\n");
+#if 0
 	if (acard->wss)
 		acard->wss->deactivate(acard->wss);
 	if (acard->ctrl)
@@ -309,6 +324,7 @@ snd_wavefront_deactivate (snd_wavefront_card_t *acard)
 		acard->mpu->deactivate(acard->mpu);
 	if (acard->synth)
 		acard->synth->deactivate(acard->synth);
+#endif 
 }
 
 #endif __ISAPNP__
@@ -907,10 +923,20 @@ static int __init alsa_card_wavefront_init(void)
 			continue;
 
 		init_waitqueue_head(&acard->wavefront.interrupt_sleeper);
+		
+                acard->wavefront.midi.open =  SPIN_LOCK_UNLOCKED;
+		acard->wavefront.midi.virtual =  SPIN_LOCK_UNLOCKED;
 
 		spin_lock_init(&acard->wavefront.midi.open);
 		spin_lock_init(&acard->wavefront.midi.virtual);
 
+#ifdef __ISAPNP__
+		acard->wss = NULL;
+		acard->ctrl = NULL;
+		acard->mpu = NULL;
+		acard->synth = NULL;
+#endif __ISAPNP__
+
 		if (snd_wavefront_probe (dev, acard) < 0) {
 			snd_kfree (acard);
 			if (snd_cs4232_pcm_port[dev] == SND_AUTO_PORT) {
@@ -939,6 +965,9 @@ static void __exit alsa_card_wavefront_exit(void)
 	for (idx = 0; idx < SND_CARDS; idx++) {
 		acard = wavefront_cards[idx];
 		if (acard) {
+#ifdef __ISAPNP__
+			snd_wavefront_deactivate (acard);
+#endif
 			snd_card_unregister (acard->card);
 			snd_kfree (acard);
 		}
