@@ -85,16 +85,15 @@ typedef struct snd_stru_ac97 ac97_t;
 struct snd_stru_ac97 {
 	void (*write) (void *private_data, unsigned short reg, unsigned short val);
 	unsigned short (*read) (void *private_data, unsigned short reg);
-	void (*init) (void *private_data);
+	void (*init) (void *private_data, ac97_t *ac97);
 	snd_info_entry_t *proc_entry;
 	snd_info_entry_t *proc_regs_entry;
 	void *private_data;
 	void (*private_free) (void *private_data);
 	/* --- */
+	snd_kmixer_t *mixer;
 	spinlock_t reg_lock;
-	int rev_is_not_rev;
 	unsigned int id;	/* identification of codec */
-	char name[64];		/* CODEC name */
 	unsigned short caps;	/* capabilities (register 0) */
 	unsigned short micgain;	/* mic gain is active */
 	unsigned short regs[0x80]; /* register cache */
@@ -182,6 +181,7 @@ int snd_ac97_mixer(snd_card_t * card, int device,
 void snd_ac97_write(ac97_t *ac97, unsigned short reg, unsigned short value);
 unsigned short snd_ac97_read(ac97_t *ac97, unsigned short reg);
 void snd_ac97_write_lock(ac97_t *ac97, unsigned short reg, unsigned short value);
+void snd_ac97_write_bitmask_lock(ac97_t *ac97, unsigned short reg, unsigned short bitmask, unsigned short value);
 unsigned short snd_ac97_read_lock(ac97_t *ac97, unsigned short reg);
 
 #endif				/* __AC97_CODEC_H */
