@@ -111,15 +111,15 @@
 #define AD1816A_TIMER_IRQ_ENABLE	0x2000
 #define AD1816A_TIMER_ENABLE		0x0080
 
-#define AD1816A_SRC_CD			0x02
+#define AD1816A_SRC_CD			0x20
 #define AD1816A_SRC_LINE		0x00
-#define AD1816A_SRC_MIC			0x05
-#define AD1816A_SRC_OUT			0x01
-#define AD1816A_SRC_PHONE_IN		0x06
-#define AD1816A_SRC_SYNTH		0x03
-#define AD1816A_SRC_VIDEO		0x04
-#define AD1816A_SRC_MONO		0x05
-#define AD1816A_SRC_MASK		0x07
+#define AD1816A_SRC_MIC			0x50
+#define AD1816A_SRC_OUT			0x10
+#define AD1816A_SRC_PHONE_IN		0x60
+#define AD1816A_SRC_SYNTH		0x30
+#define AD1816A_SRC_VIDEO		0x40
+#define AD1816A_SRC_MONO		0x50
+#define AD1816A_SRC_MASK		0x70
 
 #define AD1816A_CAPTURE_NOT_EQUAL	0x1000
 #define AD1816A_WSS_ENABLE		0x8000
@@ -133,6 +133,8 @@ struct snd_stru_ad1816a {
 	unsigned short dma2;
 	snd_dma_t *dma1ptr;
 	snd_dma_t *dma2ptr;
+
+	unsigned short hardware;
 	unsigned short version;
 
 	spinlock_t lock;
@@ -206,6 +208,12 @@ struct snd_stru_ad1816a {
 	snd_kmixer_element_t *me_playback;
 };
 
+
+#define AD1816A_HW_AUTO		0
+#define AD1816A_HW_AD1816A	1
+#define AD1816A_HW_AD1815	2
+#define AD1816A_HW_AD18MAX10	3
+
 #define AD1816A_MODE_PLAYBACK	0x01
 #define AD1816A_MODE_CAPTURE	0x02
 #define AD1816A_MODE_TIMER	0x04
