@@ -56,11 +56,8 @@
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 3, 1)
 #define LINUX_2_3
 #endif
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 3, 11)
-#define NEW_RESOURCE
-#endif
-#if defined(LINUX_2_3) && LINUX_VERSION_CODE < KERNEL_VERSION(2, 3, 48)
-#error "This driver requires Linux 2.3.48 and higher."
+#if defined(LINUX_2_3) && LINUX_VERSION_CODE < KERNEL_VERSION(2, 3, 99)
+#error "This code requires Linux 2.3.99-pre5 and higher."
 #endif
 
 #ifdef ALSA_BUILD
@@ -112,6 +109,7 @@
 #endif
 #ifdef LINUX_2_3
 #include <linux/init.h>
+#include <linux/pm.h>
 #define PCI_GET_DRIVER_DATA(pci) pci->driver_data
 #define PCI_SET_DRIVER_DATA(pci, data) pci->driver_data = data
 #endif
@@ -210,16 +208,16 @@ typedef struct snd_stru_port {
 	unsigned int port;
 	unsigned int size;
 	char *name;
-#ifdef NEW_RESOURCE
+#ifdef LINUX_2_3
 	struct resource *res;
 #endif
 	struct snd_stru_port *next;
 } snd_port_t;
 
-typedef void (snd_irq_handler_t) (int irq, void *dev_id, struct pt_regs * regs);
+typedef void (snd_irq_handler_t) (int irq, void *dev_id, struct pt_regs *regs);
 
 typedef struct snd_stru_vma {
-	struct vm_area_struct * area;
+	struct vm_area_struct *area;
 	void *notify_client;
 	void *notify_data;
 	long notify_size;
@@ -299,8 +297,8 @@ struct snd_stru_card {
 	snd_irq_t *irqs;			/* pointer to first IRQ */
 	snd_port_t *ports;			/* pointer to first I/O port */
 
-	void (*use_inc) (snd_card_t * card);	/* increment use count */
-	void (*use_dec) (snd_card_t * card);	/* decrement use count */
+	void (*use_inc) (snd_card_t *card);	/* increment use count */
+	void (*use_dec) (snd_card_t *card);	/* decrement use count */
 
 	struct semaphore control;		/* control card mutex */
 
