@@ -27,7 +27,7 @@
 #define MPU401_HW_MPU401		1	/* native MPU401 */
 #define MPU401_HW_SB			2	/* SoundBlaster MPU-401 UART */
 #define MPU401_HW_ES1688		3	/* AudioDrive ES1688 MPU-401 UART */
-#define MPU401_HW_OPL3SA		4	/* Yamaha OPL3-SA */
+#define MPU401_HW_OPL3SA2		4	/* Yamaha OPL3-SA2 */
 #define MPU401_HW_SONICVIBES		5	/* S3 SonicVibes */
 #define MPU401_HW_CS4232		6	/* CS4232 */
 #define MPU401_HW_ES18XX		7	/* AudioDrive ES18XX MPU-401 UART */
@@ -37,6 +37,7 @@
 #define MPU401_HW_ALS100		11	/* Avance Logic ALS100 */
 #define MPU401_HW_ICE1712		12	/* Envy24 */
 #define MPU401_HW_VIA686A		13	/* VIA 82C686A */
+#define MPU401_HW_YMFPCI		14	/* YMF DS-XG PCI */
 
 #define MPU401_MODE_INPUT		(1<<0)
 #define MPU401_MODE_OUTPUT		(1<<1)
@@ -66,6 +67,7 @@ struct snd_stru_mpu401 {
 	spinlock_t open_lock;
 	spinlock_t input_lock;
 	spinlock_t output_lock;
+	spinlock_t timer_lock;
 
 	struct timer_list timer;
 };
