@@ -66,7 +66,7 @@ static int snd_hwdep_open(unsigned short minor, int cardnum, int device, struct
 {
 	snd_hwdep_t *hw = snd_hwdep_devices[(cardnum * SND_MINOR_HWDEPS) + device];
 	int err;
-	
+
 	snd_debug_check(hw == NULL, -ENODEV);
 	if (hw->ops.open) {
 		while (1) {
@@ -227,6 +227,9 @@ int snd_hwdep_new(snd_card_t * card, char *id, int device, snd_hwdep_t ** rhwdep
 	if (id) {
 		strncpy(hwdep->id, id, sizeof(hwdep->id) - 1);
 	}
+#ifdef CONFIG_SND_OSSEMUL
+	hwdep->oss_type = -1;
+#endif
 	if ((err = snd_device_new(card, SND_DEV_HWDEP, hwdep, device, &ops, NULL)) < 0) {
 		snd_hwdep_free(hwdep);
 		return err;
@@ -262,10 +265,29 @@ static int snd_hwdep_register(snd_hwdep_t * hwdep, snd_device_t *devptr)
 	if ((err = snd_register_device(SND_DEVICE_TYPE_HWDEP,
 				       hwdep->card, hwdep->device,
 				       &snd_hwdep_reg, name)) < 0) {
+		snd_printk("unable to register hardware dependant device %i:%i\n",
+			   hwdep->card->number, hwdep->device);
 		snd_hwdep_devices[idx] = NULL;
 		up(&register_mutex);
 		return err;
 	}
+#ifdef CONFIG_SND_OSSEMUL
+	hwdep->ossreg = 0;
+	if (hwdep->oss_type >= 0) {
+		if ((hwdep->oss_type == SND_OSS_DEVICE_TYPE_DMFM) && (hwdep->device != 0)) {
+			snd_printk ("only hwdep device 0 can be registered as OSS direct FM device!\n");
+		} else {
+			if (snd_register_oss_device(hwdep->oss_type,
+						    hwdep->card, hwdep->device,
+						    &snd_hwdep_reg, hwdep->oss_dev) < 0) {
+				snd_printk("unable to register OSS compatibility device %i:%i\n",
+					   hwdep->card->number, hwdep->device);
+			} else {
+				hwdep->ossreg = 1;
+			}
+		}
+	}
+#endif
 	up(&register_mutex);
 	return 0;
 }
@@ -281,6 +303,10 @@ static int snd_hwdep_unregister(snd_hwdep_t * hwdep)
 		up(&register_mutex);
 		return -EINVAL;
 	}
+#ifdef CONFIG_SND_OSSEMUL
+	if (hwdep->ossreg)
+		snd_unregister_oss_device(hwdep->oss_type, hwdep->card, hwdep->device);
+#endif
 	snd_unregister_device(SND_DEVICE_TYPE_HWDEP, hwdep->card, hwdep->device);
 	snd_hwdep_devices[idx] = NULL;
 	up(&register_mutex);
