@@ -28,17 +28,6 @@
 #include <linux/devfs_fs_kernel.h>
 #endif
 
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 3, 27)
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 3, 29)
-#error "Please, upgrade to 2.3.29..."
-#endif
-#define NO_FILL_ROUTINE
-#endif
-
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 3, 48)
-#define NEW_INODE_OPS
-#endif
-
 /*
  *
  */
@@ -128,7 +117,7 @@ struct proc_dir_entry *snd_proc_dev = NULL;
 #endif
 struct proc_dir_entry *snd_proc_seq = NULL;
 
-#ifndef NO_FILL_ROUTINE
+#ifndef LINUX_2_3
 static void snd_info_fill_inode(struct inode *inode, int fill)
 {
 	if (fill)
@@ -560,7 +549,7 @@ static struct file_operations snd_info_entry_operations =
 	release:	snd_info_entry_release,
 };
 
-#ifndef NEW_INODE_OPS
+#ifndef LINUX_2_3
 static struct inode_operations snd_info_entry_inode_operations =
 {
 	&snd_info_entry_operations,	/* default sound info directory file-ops */
@@ -572,7 +561,7 @@ static struct inode_operations snd_info_device_inode_operations =
 	&snd_fops,		/* default sound info directory file-ops */
 };
 #endif
-#endif	/* NEW_INODE_OPS */
+#endif	/* LINUX_2_3 */
 
 static int snd_info_card_readlink(struct dentry *dentry,
 				  char *buffer, int buflen)
@@ -595,9 +584,14 @@ static int snd_info_card_readlink(struct dentry *dentry,
 	return len;
 }
 
+#ifdef LINUX_2_3
+static int snd_info_card_followlink(struct dentry *dentry,
+				    struct nameidata *nd)
+#else
 static struct dentry *snd_info_card_followlink(struct dentry *dentry,
 					       struct dentry *base,
 					       unsigned int follow)
+#endif
 {
 	snd_card_t *card;
 	char tmp[16];
@@ -606,14 +600,22 @@ static struct dentry *snd_info_card_followlink(struct dentry *dentry,
 	card = snd_info_find_card(dentry->d_inode->i_ino);
 	if (card == NULL || card->proc_dir == NULL) {
 		up(&info_mutex);
+#ifdef LINUX_2_3
+		return -ENOENT;
+#else
 		return NULL;
+#endif
 	}
 	strcpy(tmp, card->id);
 	up(&info_mutex);
+#ifdef LINUX_2_3
+	return vfs_follow_link(nd, tmp);
+#else
 	return lookup_dentry(tmp, base, follow);
+#endif
 }
 
-#ifndef NEW_INODE_OPS
+#ifndef LINUX_2_3
 static struct file_operations snd_info_card_link_operations =
 {
 	NULL
@@ -622,7 +624,7 @@ static struct file_operations snd_info_card_link_operations =
 
 struct inode_operations snd_info_card_link_inode_operations =
 {
-#ifndef NEW_INODE_OPS
+#ifndef LINUX_2_3
 	default_file_ops:	&snd_info_card_link_operations,
 #endif
 	readlink:		snd_info_card_readlink,
@@ -688,7 +690,7 @@ int __exit snd_info_done(void)
 	if (snd_proc_root) {
 		snd_info_entry_remove(snd_proc_root, snd_proc_seq);
 #ifndef CONFIG_DEVFS_FS
-		snd_info_entry_remove(snd_proc_root, snd_proc_seq);
+		snd_info_entry_remove(snd_proc_root, snd_proc_dev);
 #endif
 		snd_info_entry_remove(&proc_root, snd_proc_root);
 	}
@@ -719,7 +721,7 @@ int snd_info_card_register(snd_card_t * card)
 		return -ENOMEM;
 	}
 	snd_info_entry_prepare(p);
-#ifdef NEW_INODE_OPS
+#ifdef LINUX_2_3
 	p->proc_iops = &snd_info_card_link_inode_operations;
 #else
 	p->ops = &snd_info_card_link_inode_operations;
@@ -832,7 +834,7 @@ void snd_info_free_entry(snd_info_entry_t * entry)
 }
 
 #ifndef CONFIG_DEVFS_FS
-#ifndef NO_FILL_ROUTINE
+#ifndef LINUX_2_3
 static void snd_info_device_fill_inode(struct inode *inode, int fill)
 {
 	struct proc_dir_entry *de;
@@ -862,7 +864,7 @@ static inline void snd_info_device_entry_prepare(struct proc_dir_entry *de, snd_
 	de->rdev = MKDEV(entry->t.device.major, entry->t.device.minor);
 	de->owner = THIS_MODULE;
 }
-#endif /* NO_FILL_ROUTINE */
+#endif /* LINUX_2_3 */
 #endif /* CONFIG_DEVFS_FS */
 
 snd_info_entry_t *snd_info_create_device(const char *name, unsigned int number, unsigned int mode)
@@ -894,7 +896,7 @@ snd_info_entry_t *snd_info_create_device(const char *name, unsigned int number,
 	p = create_proc_entry(entry->name, entry->mode, snd_proc_dev);
 	if (p) {
 		snd_info_device_entry_prepare(p, entry);
-#ifdef NEW_INODE_OPS
+#ifdef LINUX_2_3
 		p->proc_fops = &snd_fops;
 #else
 		p->ops = &snd_info_device_inode_operations;
@@ -1000,7 +1002,7 @@ int snd_info_register(snd_info_entry_t * entry)
 	p = create_proc_entry(entry->name, entry->mode, root);
 	if (p) {
 		snd_info_entry_prepare(p);
-#ifdef NEW_INODE_OPS
+#ifdef LINUX_2_3
 		p->proc_fops = &snd_info_entry_operations;
 #else
 		p->ops = &snd_info_entry_inode_operations;
