@@ -1,5 +1,5 @@
 /*
- *  Misc things
+ *  Misc and compatibility things
  *  Copyright (c) by Jaroslav Kysela <perex@suse.cz>
  *
  *
@@ -95,26 +95,30 @@ const struct pci_device_id * snd_pci_compat_match_device(const struct pci_device
 
 static int snd_pci_announce_device(struct pci_driver *drv, struct pci_dev *dev)
 {
+        int i;
 	const struct pci_device_id *id;
 
 	if (drv->id_table) {
 		id = snd_pci_compat_match_device(drv->id_table, dev);
 		if (!id)
 			return 0;
-	} else
+	} else {
 		id = NULL;
-	if (drv->probe(dev, id) >= 0) {
-		int i;
-		
-		for (i = 0; i < PCI_MAX_MAPPINGS; i++) {
-			if (!drvmap[i].dev) {
-				drvmap[i].dev = dev;
-				drvmap[i].drv = drv;
-				return 1;
-			}
-		}
 	}
-	return 0;
+        for (i = 0; i < PCI_MAX_MAPPINGS; i++) {
+	        if (drvmap[i].dev == NULL) {
+	                drvmap[i].dev = dev;
+	                drvmap[i].drv = drv;
+	                break;
+	        }
+        }
+        if (i >= PCI_MAX_MAPPINGS)
+		return 0;
+	if (drv->probe(dev, id) < 0) {
+                 drvmap[i].dev = NULL;
+	         return 0;
+	}
+	return 1;
 }
 
 int snd_pci_compat_register_driver(struct pci_driver *drv)
@@ -125,9 +129,11 @@ int snd_pci_compat_register_driver(struct pci_driver *drv)
 	list_add_tail(&drv->node, &pci_drivers);
 	pci_for_each_dev(dev) {
 		found = 0;
-		for (i = 0; i < PCI_MAX_MAPPINGS && !found; i++)
-			if (drvmap[i].dev == dev)
+		for (i = 0; i < PCI_MAX_MAPPINGS; i++)
+			if (drvmap[i].dev == dev) {
 				found = 1;
+				break;
+			}
 		if (!found)
 			count += snd_pci_announce_device(drv, dev);
 	}
@@ -137,19 +143,18 @@ int snd_pci_compat_register_driver(struct pci_driver *drv)
 void snd_pci_compat_unregister_driver(struct pci_driver *drv)
 {
 	struct pci_dev *dev;
-	int i, found;
+	int i;
 
 	list_del(&drv->node);
 	pci_for_each_dev(dev) {
-		found = 0;
-		for (i = 0; i < PCI_MAX_MAPPINGS && !found; i++)
-			if (drvmap[i].dev == dev)
-				found = 1;
-		if (found) {
-			if (drv->remove)
-				drv->remove(dev);
-			drvmap[i].dev = NULL;
-		}
+	        for (i = 0; i < PCI_MAX_MAPPINGS; i++) {
+		        if (drvmap[i].dev == dev && drvmap[i].drv == drv) {
+			        if (drv->remove)
+				        drv->remove(dev);
+			        drvmap[i].dev = NULL;
+			        break;
+		        }
+	        }
 	}
 }
 
@@ -237,9 +242,13 @@ int snd_pci_compat_set_power_state(struct pci_dev *dev, int new_state)
  */
 int snd_pci_compat_enable_device(struct pci_dev *dev)
 {
+	u16 pci_command;
+
 #if 0
 	pci_compat_set_power_state(dev, 0);
 #endif
+	pci_read_config_word(dev, PCI_COMMAND, &pci_command);
+	pci_write_config_word(dev, PCI_COMMAND, pci_command | (PCI_COMMAND_IO | PCI_COMMAND_MEMORY));
 	return 0;
 }
 
@@ -265,4 +274,119 @@ int snd_pci_compat_find_capability(struct pci_dev *dev, int cap)
 	return 0;
 }
 
-#endif /* kernel version < 2.3.0 */
+#endif /* kernel version < 2.3.0 && CONFIG_PCM */
+
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,3,0) && defined(CONFIG_APM)
+
+#include <linux/apm_bios.h>
+
+static spinlock_t pm_devs_lock = SPIN_LOCK_UNLOCKED;
+static LIST_HEAD(pm_devs);
+
+static int snd_apm_callback(apm_event_t ev)
+{
+	struct list_head *entry;
+	pm_request_t rqst;
+	void *data;
+	int status;
+	
+	switch (ev) {
+	case APM_SYS_SUSPEND:
+	case APM_USER_SUSPEND:
+	case APM_CRITICAL_SUSPEND:
+		rqst = PM_SUSPEND;
+		data = (void *)3;
+		break;
+	case APM_NORMAL_RESUME:
+	case APM_CRITICAL_RESUME:
+	case APM_STANDBY_RESUME:		/* ??? */
+		rqst = PM_RESUME;
+		data = (void *)0;
+		break;
+	default:
+		return 0;
+	}
+	for (entry = pm_devs.next; entry != &pm_devs; entry = entry->next) {
+		struct pm_dev *dev = list_entry(entry, struct pm_dev, entry);
+		if ((status = pm_send(dev, rqst, data)))
+			return status;
+	}
+	return 0;
+}
+
+int pm_init(void)
+{
+	if (apm_register_callback(snd_apm_callback))
+		snd_printk("apm_register_callback failure!\n");
+	return 0;
+}
+
+void pm_done(void)
+{
+	apm_unregister_callback(snd_apm_callback);
+}
+
+struct pm_dev *pm_register(pm_dev_t type,
+			   unsigned long id,
+			   pm_callback callback)
+{
+	struct pm_dev *dev = kmalloc(sizeof(struct pm_dev), GFP_KERNEL);
+
+	if (dev) {
+		unsigned long flags;
+		
+		memset(dev, 0, sizeof(*dev));
+		dev->type = type;
+		dev->id = id;
+		dev->callback = callback;
+		
+		spin_lock_irqsave(&pm_devs_lock, flags);
+		list_add(&dev->entry, &pm_devs);
+		spin_unlock_irqrestore(&pm_devs_lock, flags);
+	}
+	return dev;
+}
+
+void pm_unregister(struct pm_dev *dev)
+{
+	if (dev) {
+		unsigned long flags;
+		
+		spin_lock_irqsave(&pm_devs_lock, flags);
+		list_del(&dev->entry);
+		spin_unlock_irqrestore(&pm_devs_lock, flags);
+
+		kfree(dev);
+	}
+}
+
+int pm_send(struct pm_dev *dev, pm_request_t rqst, void *data)
+{
+	int status = 0;
+	int prev_state, next_state;
+	
+	switch (rqst) {
+	case PM_SUSPEND:
+	case PM_RESUME:
+		prev_state = dev->state;
+		next_state = (int) data;
+		if (prev_state != next_state) {
+			if (dev->callback)
+				status = (*dev->callback)(dev, rqst, data);
+			if (!status) {
+				dev->state = next_state;
+				dev->prev_state = prev_state;
+			}
+		} else {
+			dev->prev_state = prev_state;
+		}
+		break;
+	default:
+		if (dev->callback)
+			status = (*dev->callback)(dev, rqst, data);
+		break;
+	}
+	return status;
+}
+
+#endif /* kernel version < 2.3.0 && CONFIG_APM */
