@@ -281,10 +281,6 @@ int snd_mixer_element_remove(snd_kmixer_t * mixer, snd_kmixer_element_t * elemen
 	snd_kmixer_element_t *prev;
 
 	snd_debug_check(mixer == NULL || element == NULL, -ENXIO);
-	for (prev = mixer->elements; prev; prev = prev->next) {
-		snd_mixer_element_list_remove(&element->routes_next, prev);
-		snd_mixer_element_list_remove(&prev->routes_prev, element);
-	}
 	if (mixer->elements == element) {
 		mixer->elements_count--;
 		mixer->elements = element->next;
@@ -295,8 +291,14 @@ int snd_mixer_element_remove(snd_kmixer_t * mixer, snd_kmixer_element_t * elemen
 			prev->next = element->next;
 		}
 	}
-	snd_mixer_element_free(element);
+	for (prev = mixer->elements; prev; prev = prev->next) {
+		snd_mixer_element_list_remove(&element->routes_next, prev);
+		snd_mixer_element_list_remove(&element->routes_prev, prev);
+		snd_mixer_element_list_remove(&prev->routes_next, element);
+		snd_mixer_element_list_remove(&prev->routes_prev, element);
+	}
 	snd_mixer_element_notify(mixer, element, SND_MIXER_READ_ELEMENT_REMOVE);
+	snd_mixer_element_free(element);
 	return 0;
 }
 
@@ -594,8 +596,8 @@ int snd_mixer_group_remove(snd_kmixer_t * mixer, snd_kmixer_group_t * group)
 			prev->next = group->next;
 		}
 	}
-	snd_mixer_group_free(group);
 	snd_mixer_group_notify(mixer, group, SND_MIXER_READ_GROUP_REMOVE);
+	snd_mixer_group_free(group);
 	return 0;
 }
 
@@ -1125,7 +1127,7 @@ static long snd_mixer_read(struct file *file, char *buffer, long count)
 		spin_lock_irqsave(&mfile->read_lock, flags);
 		if (mfile->rebuild) {
 			mfile->rebuild = 0;
-			spin_unlock_irqrestore(&mfile->read_lock, &flags);
+			spin_unlock_irqrestore(&mfile->read_lock, flags);
 			memset(&rebuild, 0, sizeof(rebuild));
 			rebuild.cmd = SND_MIXER_READ_REBUILD;
 			copy_to_user(buffer, &rebuild, sizeof(rebuild));
@@ -1238,20 +1240,11 @@ int snd_mixer_new(snd_card_t * card, char *id, int device, snd_kmixer_t ** rmixe
 
 static int snd_mixer_free(snd_kmixer_t * mixer)
 {
-	snd_kmixer_element_t *element;
-	snd_kmixer_group_t *group;
-
 	snd_debug_check(mixer == NULL, -ENXIO);
-	while (mixer->elements) {
-		element = mixer->elements;
-		mixer->elements = element->next;
-		snd_mixer_element_free(element);
-	}
-	while (mixer->groups) {
-		group = mixer->groups;
-		mixer->groups = group->next;
-		snd_mixer_group_free(group);
-	}
+	while (mixer->groups)
+		snd_mixer_group_remove(mixer, mixer->groups);
+	while (mixer->elements)
+		snd_mixer_element_remove(mixer, mixer->elements);
 	snd_switch_free(mixer->card, &mixer->switches);
 	if (mixer->private_data && mixer->private_free)
 		mixer->private_free(mixer->private_data);
