@@ -861,6 +861,7 @@ static int snd_pcm_mmap(struct inode *inode, struct file *file,
 	long size, size1;
 	char *ptr;
 	int res;
+	unsigned long page;
 	
 	pcm_file = snd_magic_cast(snd_pcm_file_t, file->private_data, -ENXIO);
 	subchn = pcm_file->subchn;
@@ -880,10 +881,11 @@ static int snd_pcm_mmap(struct inode *inode, struct file *file,
 		return -EBADFD;
 	size = area->vm_end - area->vm_start;
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 3, 25)
-	switch (area->vm_pgoff << PAGE_SHIFT) {
+	page = area->vm_pgoff << PAGE_SHIFT;
 #else
-	switch (area->vm_offset) {
+	page = area->vm_offset;
 #endif
+	switch (page) {
 	case SND_PCM_MMAP_OFFSET_CONTROL:
 		if (size != PAGE_ALIGN(sizeof(snd_pcm_mmap_control_t)))
 			return -EINVAL;
