@@ -700,7 +700,7 @@ static int snd_pcm_oss_sync(snd_pcm_oss_file_t *pcm_oss_file)
 			return err;
 		runtime = subchn->runtime;
 		while (runtime->oss.buffer && runtime->oss.buffer_used > 0) {
-			neutral = snd_pcm_lib_silence(subchn);
+			neutral = snd_pcm_format_silence(runtime->format.format);
 			memset(runtime->oss.buffer + runtime->oss.buffer_used, neutral, runtime->oss.fragment_size - runtime->oss.buffer_used);
 			fs = snd_enter_user();
 			result = snd_pcm_oss_write2(subchn, runtime->oss.buffer, runtime->oss.fragment_size);
@@ -930,7 +930,7 @@ static int snd_pcm_oss_set_fragment1(snd_pcm_subchn_t *subchn, int fragment)
 		return -EINVAL;
 	bytes = fragment & 0xffff;
 	count = (fragment >> 16) & 0xffff;
-	if (count == 0) {
+	if (count == 0 || count > 128) {
 		count = 128;
 	} else if (count < 128) {
 		count++;
@@ -1154,6 +1154,7 @@ static int snd_pcm_oss_get_space(snd_pcm_oss_file_t *pcm_oss_file, int channel,
 	snd_pcm_channel_status_t status;
 	struct snd_pcm_buffer_info info;
 	int err;
+	unsigned int tmp;
 
 	if (_info == NULL)
 		return -EFAULT;
@@ -1186,6 +1187,12 @@ static int snd_pcm_oss_get_space(snd_pcm_oss_file_t *pcm_oss_file, int channel,
 	} else {
 		info.fragments = status.count / runtime->buf.block.frag_size;
 	}
+	/* very experimental stuff to get Quake2 working */
+	runtime->oss.fragment = (info.fragments - 1) << 16;
+	for (tmp = info.fragsize; tmp > 1; tmp >>= 1)
+		runtime->oss.fragment++;
+	runtime->oss.subdivision = 1;	/* disable SUBDIVIDE */
+	// printk("space: bytes = %i, fragments = %i, fragstotal = %i, fragsize = %i\n", info.bytes, info.fragments, info.fragstotal, info.fragsize);
 	if (copy_to_user(_info, &info, sizeof(info)))
 		return -EFAULT;
 	return 0;
@@ -1677,6 +1684,8 @@ static unsigned int snd_pcm_oss_poll(struct file *file, poll_table * wait)
 		if (*csubchn->runtime->status == SND_PCM_STATUS_OVERRUN)
 			csubchn->runtime->oss.prepare = 1;
 		snd_pcm_oss_make_ready(csubchn);
+		if (*csubchn->runtime->status == SND_PCM_STATUS_PREPARED)
+			snd_pcm_kernel_capture_ioctl(csubchn, SND_PCM_IOCTL_CHANNEL_GO, 0);
 	}
 
 	mask = 0;
@@ -1751,7 +1760,7 @@ static int snd_pcm_oss_mmap(struct inode *inode, struct file *file,
 	pdma = runtime->dma_area;
 	if (pdma == NULL)
 		return -ENOENT;
-#if KERNEL_VERSION(2, 3, 25) <= LINUX_VERSION_CODE
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 3, 25)
 	if (area->vm_pgoff != 0)
 #else
 	if (area->vm_offset != 0)
