@@ -128,7 +128,7 @@ int snd_rawmidi_flush_output(snd_rawmidi_t * rmidi)
 	while (pchn->used > 0) {
 		timeout = interruptible_sleep_on_timeout(&pchn->sleep, 10 * HZ);
 		if (signal_pending(current)) {
-			err = -EINTR;
+			err = -ERESTARTSYS;
 			break;
 		}
 		if (pchn->used > 0 && !timeout) {
@@ -872,7 +872,7 @@ static long snd_rawmidi_write(struct file *file, const char *buf, long count)
 				return result > 0 ? result : -EAGAIN;
 			timeout = interruptible_sleep_on_timeout(&pchn->sleep, 30 * HZ);
 			if (signal_pending(current))
-				return -EINTR;
+				return -ERESTARTSYS;
 			if (pchn->used >= pchn->size && !timeout)
 				return -EIO;
 		}
