@@ -32,7 +32,7 @@
 #include "seq_info.h"
 #include "../../include/seq_device.h"
 
-int snd_seq_client_load[64] = {63, 62, [2 ... 63] = -1};
+int snd_seq_client_load[64] = {[0 ... 63] = -1};
 int snd_seq_default_timer = SND_TIMER_TYPE_GLOBAL | SND_TIMER_GLOBAL_SYSTEM;
 int snd_seq_default_timer_resolution = 250;	/* Hz */
 
