@@ -269,7 +269,8 @@ static int snd_seq_open(unsigned short minor, int cardnum, int device, struct fi
 	client_t *client;
 	user_client_t *user;
 
-	down(&register_mutex);
+	if (down_interruptible(&register_mutex))
+		return -ERESTARTSYS;
 	client = seq_create_client1(-1, SND_SEQ_DEFAULT_EVENTS);
 	if (client == NULL) {
 		up(&register_mutex);
@@ -426,7 +427,7 @@ static long snd_seq_read(struct file *file, char *buf, long count)
  * check access permission to the port
  * if capability doesn't match, check the group capability, too.
  */
-static int check_port_perm(client_port_t *port, char *group, int flags)
+static int check_port_perm(client_port_t *port, char *group, unsigned int flags)
 {
 	if ((port->capability & flags) != flags) {
 		if (strncmp(port->group, group, sizeof(port->group)) != 0 ||
@@ -1840,7 +1841,8 @@ static int snd_seq_ioctl_get_queue_timer(client_t * client, snd_seq_queue_timer_
 	memset(&timer, 0, sizeof(timer));
 	timer.queue = queue->queue;
 
-	down(&queue->use_mutex);
+	if (down_interruptible(&queue->use_mutex))
+		return -ERESTARTSYS;
 	timer.type = tmr->type;
 	timer.slave = tmr->slave_type;
 	timer.number = tmr->timer_no;
@@ -1884,7 +1886,8 @@ static int snd_seq_ioctl_set_queue_timer(client_t * client, snd_seq_queue_timer_
 		if (q == NULL)
 			return -ENXIO;
 		tmr = q->timer;
-		down(&q->use_mutex);
+		if (down_interruptible(&q->use_mutex))
+			return -ERESTARTSYS;
 		snd_seq_queue_timer_close(timer.queue);
 		tmr->type = timer.type;
 		tmr->slave_type = timer.slave;
@@ -2458,7 +2461,8 @@ int snd_seq_create_kernel_client(snd_card_t *card, int client_index, snd_seq_cli
 	if (card)
 		client_index += 64 + (card->number << 3);
 
-	down(&register_mutex);
+	if (down_interruptible(&register_mutex))
+		return -ERESTARTSYS;
 	/* empty write queue as default */
 	client = seq_create_client1(client_index, 0);
 	if (client == NULL) {
@@ -2780,7 +2784,8 @@ int __init snd_sequencer_device_init(void)
 {
 	int err;
 
-	down(&register_mutex);
+	if (down_interruptible(&register_mutex))
+		return -ERESTARTSYS;
 
 	if ((err = snd_register_device(SND_DEVICE_TYPE_SEQUENCER, NULL, 0, &snd_seq_reg, "seq")) < 0) {
 		up(&register_mutex);
