@@ -1,6 +1,6 @@
 /*
  * ALSA sequencer MIDI-through client
- * Copyright (c) 1999-2000 by Takashi Iwai <iwai@ww.uni-erlangen.de>
+ * Copyright (c) 1999-2000 by Takashi Iwai <tiwai@suse.de>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -267,6 +267,6 @@ static void __exit alsa_seq_dummy_exit(void)
 module_init(alsa_seq_dummy_init)
 module_exit(alsa_seq_dummy_exit)
 
-MODULE_AUTHOR("Takashi Iwai <iwai@ww.uni-erlangen.de>");
+MODULE_AUTHOR("Takashi Iwai <tiwai@suse.de>");
 MODULE_DESCRIPTION("ALSA sequencer MIDI-through client");
 MODULE_SUPPORTED_DEVICE("sound");
