@@ -132,7 +132,8 @@ static int event_process_midi(snd_seq_event_t * ev, int direct,
 
 	snd_debug_check(msynth == NULL, -EINVAL);
 	rmidi = msynth->output_rmidi;
-	snd_debug_check(rmidi == NULL, -EINVAL);
+	if (rmidi == NULL)
+		return -EINVAL;
 	if (ev->type == SND_SEQ_EVENT_SYSEX) {	/* special case, to save space */
 		if ((ev->flags & SND_SEQ_EVENT_LENGTH_MASK) != SND_SEQ_EVENT_LENGTH_VARIABLE) {
 			/* invalid event */
@@ -168,7 +169,7 @@ static seq_midisynth_t *snd_seq_midisynth_new(snd_card_t *card, int device)
 		return NULL;
 	}
 	
-	if (snd_midi_event_new(&msynth->parser) < 0) {
+	if (snd_midi_event_new(MAX_MIDI_EVENT_BUF, &msynth->parser) < 0) {
 		snd_kfree(msynth);
 		return NULL;
 	}
