@@ -138,9 +138,9 @@ static queue_t *queue_new(int owner, int locked)
 		return NULL;
 	}
 
-	q->owner_lock = SPIN_LOCK_UNLOCKED;
-	q->clients_lock = SPIN_LOCK_UNLOCKED;
-	q->check_lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&q->owner_lock);
+	spin_lock_init(&q->clients_lock);
+	spin_lock_init(&q->check_lock);
 	init_MUTEX(&q->use_mutex);
 
 	q->tickq = snd_seq_prioq_new();
