@@ -267,13 +267,13 @@ static int snd_ioctl(struct inode *inode, struct file *file,
 	if ((mptr = snd_verify_card(minor)) == NULL)
 		return -ENODEV;
 #ifndef READV_WRITEV_FILE_OPERATIONS
-	if (arg == SND_IOCTL_READV ||
-	    arg == SND_IOCTL_WRITEV) {
+	if (cmd == SND_IOCTL_READV ||
+	    cmd == SND_IOCTL_WRITEV) {
 		snd_v_args_t rargs;
 		struct iovec iovstack[UIO_FASTIOV];
 		struct iovec *iov = iovstack;
 		int ret;
-		if (arg == SND_IOCTL_READV) {
+		if (cmd == SND_IOCTL_READV) {
 			if (mptr->readv == NULL)
 				return -ENXIO;
 		} else if (mptr->writev == NULL)
@@ -547,6 +547,9 @@ static int __init alsa_sound_init(void)
 		if (ok == 0)
 			printk("  No soundcards found.\n");
 	}
+#endif
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,3,0) && defined(CONFIG_APM)
+	pm_init();
 #endif
 	return 0;
 }
@@ -591,6 +594,9 @@ static void __exit alsa_sound_exit(void)
 #ifdef CONFIG_DEVFS_FS
 	devfs_unregister(devfs_handle);
 #endif
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,3,0) && defined(CONFIG_APM)
+	pm_done();
+#endif
 }
 
 module_init(alsa_sound_init)
@@ -689,7 +695,7 @@ EXPORT_SYMBOL(snd_control_switch_new);
 EXPORT_SYMBOL(snd_control_switch_change);
   /* misc.c */
 EXPORT_SYMBOL(snd_task_name);
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2,3,0)
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,3,0) && defined(CONFIG_PCI)
 EXPORT_SYMBOL(snd_pci_compat_match_device);
 EXPORT_SYMBOL(snd_pci_compat_register_driver);
 EXPORT_SYMBOL(snd_pci_compat_unregister_driver);
@@ -701,3 +707,8 @@ EXPORT_SYMBOL(snd_pci_compat_find_capability);
 EXPORT_SYMBOL(snd_pci_compat_get_driver_data);
 EXPORT_SYMBOL(snd_pci_compat_set_driver_data);
 #endif
+#ifdef CONFIG_PM
+EXPORT_SYMBOL(pm_register);
+EXPORT_SYMBOL(pm_unregister);
+EXPORT_SYMBOL(pm_send);
+#endif
