@@ -498,7 +498,7 @@ void snd_timer_interrupt(snd_timer_t * timer, unsigned long ticks_left)
 		return;
 	ts.iprev = NULL;
 	ts.inext = NULL;
-	spin_lock_irq(&timer->lock);
+	spin_lock(&timer->lock);
 	ti = timer->first;
 	while (ti) {
 		if (ti->flags & SND_TIMER_IFLG_RUNNING) {
@@ -516,7 +516,7 @@ void snd_timer_interrupt(snd_timer_t * timer, unsigned long ticks_left)
 				}
 				if (snd_timer_insert(&ts, &tc, ti))
 					atomic_inc(&timer->in_use);
-				spin_lock_irq(&snd_timer_slave);
+				spin_lock(&snd_timer_slave);
 				tm = ti->slave;
 				while (tm) {
 					tm->ticks = ti->ticks;
@@ -524,7 +524,7 @@ void snd_timer_interrupt(snd_timer_t * timer, unsigned long ticks_left)
 						atomic_inc(&snd_timer_slave_in_use);
 					tm = tm->slave;
 				}				
-				spin_unlock_irq(&snd_timer_slave);
+				spin_unlock(&snd_timer_slave);
 			}
 		}
 		ti = ti->next;
@@ -557,17 +557,17 @@ void snd_timer_interrupt(snd_timer_t * timer, unsigned long ticks_left)
 			ts.inext->iprev = &ts;
 		ti->iprev = ti->inext = NULL;
 		ticks = ti->ticks;
-		spin_unlock_irq(&timer->lock);
+		spin_unlock(&timer->lock);
 		if (ti->callback)
 			ti->callback(ti, resolution, ticks, ti->callback_data);
-		spin_lock_irq(&timer->lock);
+		spin_lock(&timer->lock);
 		if (!(ti->flags & SND_TIMER_IFLG_SLAVE)) {
 			atomic_dec(&timer->in_use);
 		} else {
 			atomic_dec(&snd_timer_slave_in_use);
 		}
 	}
-	spin_unlock_irq(&timer->lock);
+	spin_unlock(&timer->lock);
 }
 
 /*
@@ -1149,8 +1149,7 @@ static long snd_timer_user_read(struct file *file, char *buffer, long count)
 			}
 
 			set_current_state(TASK_INTERRUPTIBLE);
-			/* 2.3.x: init_waitqueue_entry(&wait, current); */
-			wait.task = current;
+			init_waitqueue_entry(&wait, current);
 			add_wait_queue(&tu->qchange_sleep, &wait);
 
 			spin_unlock(&tu->qlock);
