@@ -49,7 +49,7 @@ inline static void snd_emu10k1_write_op(emu10k1_t *emu, int op, int z, int w, in
 static void snd_emu10k1_init_efx(emu10k1_t *emu)
 {
 	int i;
-	u32 pc = 16;
+	u32 pc = 0;
 
 	for (i = 0; i < 512; i++) {
 		snd_emu10k1_efx_write(emu, i * 2, 0x10040);
@@ -142,9 +142,9 @@ static int snd_emu10k1_init(emu10k1_t * emu)
 	outl(HCFG_LOCKSOUNDCACHE | HCFG_LOCKTANKCACHE | HCFG_MUTEBUTTONENABLE, emu->port + HCFG);
 
 	/* reset recording buffers */
-	snd_emu10k1_ptr_write(emu, MICBS, 0, 0);
+	snd_emu10k1_ptr_write(emu, MICBS, 0, ADCBS_BUFSIZE_NONE);
 	snd_emu10k1_ptr_write(emu, MICBA, 0, 0);
-	snd_emu10k1_ptr_write(emu, FXBS, 0, 0);
+	snd_emu10k1_ptr_write(emu, FXBS, 0, ADCBS_BUFSIZE_NONE);
 	snd_emu10k1_ptr_write(emu, FXBA, 0, 0);
 	snd_emu10k1_ptr_write(emu, ADCBS, 0, ADCBS_BUFSIZE_NONE);
 	snd_emu10k1_ptr_write(emu, ADCBA, 0, 0);
@@ -250,12 +250,16 @@ static int snd_emu10k1_init(emu10k1_t * emu)
 	 *   Lock Sound Memory = 0
 	 *   Auto Mute = 1
 	 */
-	if (emu->revision < 6)
+	if (emu->model == 0x20 ||
+	    emu->model == 0xc400 ||
+	    (emu->model == 0x21 && emu->revision <= 3))
 		outl(HCFG_AUDIOENABLE | HCFG_LOCKTANKCACHE | HCFG_AUTOMUTE, emu->port + HCFG);
 	else
 		// With on-chip joystick
 		outl(HCFG_AUDIOENABLE | HCFG_LOCKTANKCACHE | HCFG_AUTOMUTE | HCFG_JOYENABLE, emu->port + HCFG);
 
+#if 0
+	/* FIXME: the following routine disables LiveDrive-II !! */
 	// TOSLink detection
 	emu->tos_link = 0;
 	tmp = inl(emu->port + HCFG);
@@ -267,6 +271,7 @@ static int snd_emu10k1_init(emu10k1_t * emu)
 			outl(tmp, emu->port + HCFG);
 		}
 	}
+#endif
 
 	snd_emu10k1_intr_enable(emu, INTE_PCIERRORENABLE);
 
@@ -590,6 +595,7 @@ int snd_emu10k1_create(snd_card_t * card,
 	/* read revision & serial */
 	pci_read_config_byte(pci, PCI_REVISION_ID, (char *)&emu->revision);
 	pci_read_config_dword(pci, PCI_SUBSYSTEM_VENDOR_ID, &emu->serial);
+	pci_read_config_word(pci, PCI_SUBSYSTEM_ID, &emu->model);
 	emu->APS = emu->serial == 0x40011102;
 
 	if (emu->APS) {
@@ -615,33 +621,6 @@ int snd_emu10k1_create(snd_card_t * card,
 	return 0;
 }
 
-#if 0
-static void snd_emu10k1_mixer_free_ac97(void *private_data)
-{
-	emu10k1_t * emu = snd_magic_cast(emu10k1_t, private_data, );
-	emu->mixer = NULL;
-}
-
-int snd_emu10k1_mixer(emu10k1_t * emu, int device, snd_pcm_t * pcm, snd_kmixer_t ** rmixer)
-{
-	ac97_t ac97;
-	snd_kmixer_t *mixer;
-	int err, dev;
-
-	*rmixer = NULL;
-	memset(&ac97, 0, sizeof(ac97));
-	ac97.write = snd_emu10k1_ac97_write;
-	ac97.read = snd_emu10k1_ac97_read;
-	ac97.private_data = emu;
-	ac97.private_free = snd_emu10k1_mixer_free_ac97;
-	dev = 0;
-	if ((err = snd_ac97_mixer(emu->card, device, &ac97, 1, &dev /* &pcm->device */, &mixer)) < 0)
-		return err;
-	emu->ac97 = snd_magic_cast(ac97_t, mixer->private_data, -ENXIO);
-	*rmixer = emu->mixer = mixer;
-	return 0;
-}
-#endif
 
 /*
  *  INIT part
