@@ -1,7 +1,7 @@
 /*
  *  synth callback routines for Emu10k1
  *
- *  Copyright (C) 2000 Takashi Iwai <iwai@ww.uni-erlangen.de>
+ *  Copyright (C) 2000 Takashi Iwai <tiwai@suse.de>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -160,7 +160,7 @@ free_voice(snd_emux_voice_t *vp)
 	
 	hw = snd_magic_cast(emu10k1_t, vp->hw, );
 	if (vp->ch >= 0) {
-		snd_emu10k1_ptr_write(hw, IFATN, vp->ch, 0xffff);
+		snd_emu10k1_ptr_write(hw, IFATN, vp->ch, 0xff00);
 		snd_emu10k1_ptr_write(hw, DCYSUSV, vp->ch, ENV_OFF);
 		snd_emu10k1_ptr_write(hw, VTFT, vp->ch, 0xffff);
 		snd_emu10k1_ptr_write(hw, CVCF, vp->ch, 0xffff);
@@ -302,7 +302,6 @@ start_voice(snd_emux_voice_t *vp)
 	unsigned int temp;
 	int ch;
 	int addr;
-	soundfont_voice_parm_block_t *parm;
 	snd_midi_channel_t *chan;
 	emu10k1_t *hw;
 	
@@ -310,7 +309,6 @@ start_voice(snd_emux_voice_t *vp)
 	ch = vp->ch;
 	snd_debug_check(ch < 0,);
 	chan = vp->chan;
-	parm = (soundfont_voice_parm_block_t*)&vp->reg.parm;
 
 	/* channel to be silent and idle */
 	snd_emu10k1_ptr_write(hw, DCYSUSV, ch, 0x0080);
