@@ -39,17 +39,17 @@ static void snd_emu10k1_midi_interrupt(emu10k1_t *emu, unsigned int status)
 		return;
 	}
 
-	spin_lock_irq(&emu->midi_input_lock);
+	spin_lock(&emu->midi_input_lock);
 	bstatus = inb(emu->port + MUSTAT);
 	if ((status & IPR_MIDIRECVBUFEMPTY) && !(bstatus & 0x80)) {
 		byte = inb(emu->port + MUDATA);
-		spin_unlock_irq(&emu->midi_input_lock);
+		spin_unlock(&emu->midi_input_lock);
 		snd_rawmidi_receive(rmidi, &byte, 1);
-		spin_lock_irq(&emu->midi_input_lock);
+		spin_lock(&emu->midi_input_lock);
 	}
-	spin_unlock_irq(&emu->midi_input_lock);
+	spin_unlock(&emu->midi_input_lock);
 
-	spin_lock_irq(&emu->midi_output_lock);
+	spin_lock(&emu->midi_output_lock);
 	bstatus = inb(emu->port + MUSTAT);
 	if ((status & IPR_MIDITRANSBUFEMPTY) && !(bstatus & 0x40)) {
 		if (snd_rawmidi_transmit(rmidi, &byte, 1) == 1) {
@@ -58,7 +58,7 @@ static void snd_emu10k1_midi_interrupt(emu10k1_t *emu, unsigned int status)
 			snd_emu10k1_intr_disable(emu, INTE_MIDITXENABLE);
 		}
 	}
-	spin_unlock_irq(&emu->midi_output_lock);
+	spin_unlock(&emu->midi_output_lock);
 }
 
 /*
