@@ -47,28 +47,34 @@ static void snd_emu10k1_pcm_interrupt(emu10k1_t *emu, emu10k1_voice_t *voice)
 
 static void snd_emu10k1_pcm_ac97adc_interrupt(emu10k1_t *emu, unsigned int status)
 {
+#if 0
 	if (status & IPR_ADCBUFHALFFULL) {
 		if (emu->pcm_capture_subchn->runtime->mode == SND_PCM_MODE_STREAM)
 			return;
 	}
+#endif
 	snd_pcm_transfer_done(emu->pcm_capture_subchn);
 }
 
 static void snd_emu10k1_pcm_ac97mic_interrupt(emu10k1_t *emu, unsigned int status)
 {
+#if 0
 	if (status & IPR_MICBUFHALFFULL) {
 		if (emu->pcm_capture_mic_subchn->runtime->mode == SND_PCM_MODE_STREAM)
 			return;
 	}
+#endif
 	snd_pcm_transfer_done(emu->pcm_capture_mic_subchn);
 }
 
 static void snd_emu10k1_pcm_efx_interrupt(emu10k1_t *emu, unsigned int status)
 {
+#if 0
 	if (status & IPR_EFXBUFHALFFULL) {
 		if (emu->pcm_capture_efx_subchn->runtime->mode == SND_PCM_MODE_STREAM)
 			return;
 	}
+#endif
 	snd_pcm_transfer_done(emu->pcm_capture_efx_subchn);
 }
 
@@ -121,7 +127,8 @@ static int capture_sizes[4] = {384, 448, 512, 640};
 
 static unsigned int snd_emu10k1_capture_transfer_size(unsigned int size)
 {
-	int idx, val;
+	int idx;
+	unsigned int val;
 
 	for (idx = 30; idx >= 0; idx--) {
 		val = capture_sizes[idx & 3] * (1 << (idx >> 2));
@@ -133,7 +140,8 @@ static unsigned int snd_emu10k1_capture_transfer_size(unsigned int size)
 
 static unsigned int snd_emu10k1_capture_transfer_reg(unsigned int size)
 {
-	int idx, val;
+	int idx;
+	unsigned int val;
 
 	for (idx = 30; idx >= 0; idx--) {
 		val = capture_sizes[idx & 3] * (1 << (idx >> 2));
