@@ -53,11 +53,11 @@ static void snd_mpu401_uart_timer(unsigned long data)
 	unsigned long flags;
 	mpu401_t *mpu = snd_magic_cast(mpu401_t, (void *)data, );
 
-	spin_lock_irqsave(&mpu->output_lock, flags);
+	spin_lock_irqsave(&mpu->timer_lock, flags);
 	mpu->mode |= MPU401_MODE_TIMER;
 	mpu->timer.expires = 1 + jiffies;
 	add_timer(&mpu->timer);
-	spin_unlock_irqrestore(&mpu->output_lock, flags);
+	spin_unlock_irqrestore(&mpu->timer_lock, flags);
 	if (mpu->rmidi) {
 		if (mpu->mode & MPU401_MODE_INPUT)
 			snd_mpu401_uart_input_read(mpu->rmidi, mpu);
@@ -66,6 +66,33 @@ static void snd_mpu401_uart_timer(unsigned long data)
 	}
 }
 
+static void snd_mpu401_uart_add_timer (mpu401_t *mpu, int cond)
+{
+	unsigned long flags;
+
+	spin_lock_irqsave (&mpu->timer_lock, flags);
+	if ((mpu->mode & MPU401_MODE_TIMER) == 0 && cond) {
+		mpu->timer.data = (unsigned long)mpu;
+		mpu->timer.function = snd_mpu401_uart_timer;
+		mpu->timer.expires = 1 + jiffies;
+		add_timer(&mpu->timer);
+		mpu->mode |= MPU401_MODE_OUTPUT_TIMER;
+	} 
+	spin_unlock_irqrestore (&mpu->timer_lock, flags);
+}
+
+static void snd_mpu401_uart_remove_timer (mpu401_t *mpu)
+{
+	unsigned long flags;
+
+	spin_lock_irqsave (&mpu->timer_lock, flags);
+	if (mpu->mode & MPU401_MODE_TIMER) {
+		mpu->mode &= ~MPU401_MODE_TIMER;
+		del_timer(&mpu->timer);
+	}
+	spin_unlock_irqrestore (&mpu->timer_lock, flags);
+}
+
 /*
 
  */
@@ -111,9 +138,7 @@ static void snd_mpu401_uart_cmd(mpu401_t * mpu, unsigned char cmd, int ack)
 	if (!ok) {
 		snd_printk("snd_mpu401_uart_cmd: 0x%x failed at 0x%x (status = 0x%x, data = 0x%x)\n", cmd, mpu->port, inb(MPU401C(mpu)), inb(MPU401D(mpu)));
 	}
-#if 0
-	snd_printk("snd_mpu401_uart_cmd: 0x%x at 0x%x (status = 0x%x, data = 0x%x)\n", cmd, mpu->port, inb(MPU401C(mpu)), inb(MPU401D(mpu)));
-#endif
+	// snd_printk("snd_mpu401_uart_cmd: 0x%x at 0x%x (status = 0x%x, data = 0x%x)\n", cmd, mpu->port, inb(MPU401C(mpu)), inb(MPU401D(mpu)));
 }
 
 static int snd_mpu401_uart_input_open(snd_rawmidi_t * rmidi)
@@ -122,10 +147,8 @@ static int snd_mpu401_uart_input_open(snd_rawmidi_t * rmidi)
 	mpu401_t *mpu;
 
 	mpu = snd_magic_cast(mpu401_t, rmidi->private_data, -ENXIO);
-#if 0
-	snd_printk("[0x%x] MPU-401 command port - 0x%x\n", MPU401C(mpu), inb(MPU401C(mpu)));
-	snd_printk("[0x%x] MPU-401 data port - 0x%x\n", MPU401D(mpu), inb(MPU401D(mpu)));
-#endif
+	// snd_printk("[0x%x] MPU-401 command port - 0x%x\n", MPU401C(mpu), inb(MPU401C(mpu)));
+	// snd_printk("[0x%x] MPU-401 data port - 0x%x\n", MPU401D(mpu), inb(MPU401D(mpu)));
 	spin_lock_irqsave(&mpu->open_lock, flags);
 	mpu->mode |= MPU401_MODE_INPUT;
 	if (mpu->open_input)
@@ -213,17 +236,10 @@ static void snd_mpu401_uart_input_trigger(snd_rawmidi_t * rmidi, int up)
 			while (max-- > 0)
 				inb(MPU401D(mpu));
 		}
-		if ((mpu->mode & MPU401_MODE_TIMER) == 0 && mpu->irq < 0) {
-			mpu->timer.data = (unsigned long)mpu;
-			mpu->timer.function = snd_mpu401_uart_timer;
-			mpu->timer.expires = 1 + jiffies;
-			add_timer(&mpu->timer);
-		}
-		mpu->mode |= MPU401_MODE_INPUT_TRIGGER |
-			     MPU401_MODE_INPUT_TIMER;
+		snd_mpu401_uart_add_timer(mpu, mpu->irq < 0);
+		mpu->mode |= MPU401_MODE_INPUT_TRIGGER;
 	} else {
-		if ((mpu->mode & MPU401_MODE_TIMER) == MPU401_MODE_INPUT_TIMER)
-			del_timer(&mpu->timer);
+		snd_mpu401_uart_remove_timer (mpu);
 		mpu->mode &= ~(MPU401_MODE_INPUT_TRIGGER | MPU401_MODE_INPUT_TIMER);
 	}
 	spin_unlock_irqrestore(&mpu->input_lock, flags);
@@ -284,10 +300,7 @@ static void snd_mpu401_uart_output_write(snd_rawmidi_t * rmidi, mpu401_t * mpu)
 					outb(byte, MPU401D(mpu));
 					max--;
 				} else {
-					if (mpu->mode & MPU401_MODE_TIMER) {
-						mpu->mode &= ~MPU401_MODE_TIMER;
-						del_timer(&mpu->timer);
-					}
+					snd_mpu401_uart_remove_timer (mpu);
 					status = 0x40;	/* return */
 				}
 			} else {
@@ -308,17 +321,10 @@ static void snd_mpu401_uart_output_trigger(snd_rawmidi_t * rmidi, int up)
 	mpu = snd_magic_cast(mpu401_t, rmidi->private_data, );
 	spin_lock_irqsave(&mpu->output_lock, flags);
 	if (up) {
-		if ((mpu->mode & MPU401_MODE_TIMER) == 0) {
-			mpu->timer.data = (unsigned long)mpu;
-			mpu->timer.function = snd_mpu401_uart_timer;
-			mpu->timer.expires = 1 + jiffies;
-			add_timer(&mpu->timer);
-		}
-		mpu->mode |= MPU401_MODE_OUTPUT_TRIGGER |
-			     MPU401_MODE_OUTPUT_TIMER;
+		snd_mpu401_uart_add_timer(mpu, 1);
+		mpu->mode |= MPU401_MODE_OUTPUT_TRIGGER;
 	} else {
-		if ((mpu->mode & MPU401_MODE_TIMER) == MPU401_MODE_OUTPUT_TIMER)
-			del_timer(&mpu->timer);
+		snd_mpu401_uart_remove_timer(mpu);
 		mpu->mode &= ~(MPU401_MODE_OUTPUT_TRIGGER | MPU401_MODE_OUTPUT_TIMER);
 	}
 	spin_unlock_irqrestore(&mpu->output_lock, flags);
@@ -371,6 +377,7 @@ int snd_mpu401_uart_new(snd_card_t * card, int device,
 	spin_lock_init(&mpu->open_lock);
 	spin_lock_init(&mpu->input_lock);
 	spin_lock_init(&mpu->output_lock);
+	spin_lock_init(&mpu->timer_lock);
 	mpu->hardware = hardware;
 	mpu->port = port;
 	mpu->irq = irq;
