@@ -645,7 +645,7 @@ static int snd_uart16550_register_resources(snd_uart16550_t * uart)
 		spin_unlock_irqrestore(&uart->open_lock, flags);
 		return -EBUSY;
 	}
-	if (uart->irq >= 0) {
+	if (uart->irq_number >= 0) {
 		int possible_numbers[] = {3, 4, 5, 7, 9, 10, 11, 14, 15, -1};
 		snd_printd("snd_uart16550_register_resources requesting irq=%d\n",
 			   uart->irq_number);
