@@ -225,7 +225,7 @@ static int snd_ad1816a_trigger(ad1816a_t *codec, unsigned char what,
 		    	return -EINVAL;
 
 		if (!snd_pcm_playback_data(psubchn) ||
-				!snd_pcm_capture_empty(csubchn))
+		    !snd_pcm_capture_empty(csubchn))
 			return -EINVAL;
 
 		if ((error = snd_pcm_channel_go_pre(psubchn,
@@ -371,11 +371,11 @@ static unsigned int snd_ad1816a_capture_pointer(void *private_data,
 
 void snd_ad1816a_interrupt(snd_pcm_t *pcm, unsigned char status)
 {
-	unsigned long flags;
 	ad1816a_t *codec = snd_magic_cast(ad1816a_t, pcm->private_data, );
 
-	spin_lock_irqsave(&codec->lock, flags);
+	spin_lock(&codec->lock);
 	status = snd_ad1816a_in(codec, AD1816A_INTERRUPT_STATUS);
+	spin_unlock(&codec->lock);
 
 	if (status & AD1816A_PLAYBACK_IRQ_PENDING)
 		snd_pcm_transfer_done(codec->playback_subchn);
@@ -386,8 +386,9 @@ void snd_ad1816a_interrupt(snd_pcm_t *pcm, unsigned char status)
 	if (status & AD1816A_TIMER_IRQ_PENDING)
 		snd_timer_interrupt(codec->timer, codec->timer->sticks);
 
+	spin_lock(&codec->lock);
 	snd_ad1816a_out(codec, AD1816A_INTERRUPT_STATUS, 0x00);
-	spin_unlock_irqrestore(&codec->lock, flags);
+	spin_unlock(&codec->lock);
 }
 
 
@@ -609,7 +610,19 @@ static int snd_ad1816a_probe(ad1816a_t *codec)
 
 	spin_lock_irqsave(&codec->lock, flags);
 
-	codec->version = snd_ad1816a_read(codec, AD1816A_VERSION_ID);
+	switch (codec->version = snd_ad1816a_read(codec, AD1816A_VERSION_ID)) {
+	case 0:
+		codec->hardware = AD1816A_HW_AD1815;
+		break;
+	case 1:
+		codec->hardware = AD1816A_HW_AD18MAX10;
+		break;
+	case 3:
+		codec->hardware = AD1816A_HW_AD1816A;
+		break;
+	default:
+		codec->hardware = AD1816A_HW_AUTO;
+	}
 
 	spin_unlock_irqrestore(&codec->lock, flags);
 	return 0;
@@ -672,10 +685,25 @@ int snd_ad1816a_new_pcm(snd_card_t *card, int device,
 		return error;
 	}
 
-	strcpy(pcm->name, "AD1816A");
+	switch (codec->hardware) {
+	case AD1816A_HW_AD1816A:
+		strcpy(pcm->name, "AD1816A");
+		break;
+	case AD1816A_HW_AD1815:
+		strcpy(pcm->name, "AD1815");
+		break;
+	case AD1816A_HW_AD18MAX10:
+		strcpy(pcm->name, "AD18max10");
+		break;
+	default:
+		strcpy(pcm->name, "AD1816A - unknown");
+
+		snd_ad1816a_printk("Unknown chip version %d:%d.\n",
+			codec->version, codec->hardware);
+	}
 	snd_ad1816a_init(codec);
 
-	if ((error = snd_timer_new(card, "AD1816A", timer_dev, &timer)) < 0) {
+	if ((error = snd_timer_new(card, pcm->name, timer_dev, &timer)) < 0) {
 		snd_device_free(card, pcm);
 
 		return error;
