@@ -601,7 +601,6 @@ static int snd_ad1848_capture_prepare(void *private_data,
 
 void snd_ad1848_interrupt(snd_pcm_t * pcm, unsigned char status)
 {
-	unsigned long flags;
 	ad1848_t *codec = snd_magic_cast(ad1848_t, pcm->private_data, );
 
 #if 0
@@ -614,9 +613,9 @@ void snd_ad1848_interrupt(snd_pcm_t * pcm, unsigned char status)
 		snd_pcm_transfer_done(codec->playback_subchn);
 	if (codec->mode & AD1848_MODE_CAPTURE)
 		snd_pcm_transfer_done(codec->capture_subchn);
-	spin_lock_irqsave(&codec->reg_lock, flags);
+	spin_lock(&codec->reg_lock);
 	outb(0, AD1848P(codec, STATUS));	/* clear global interrupt bit */
-	spin_unlock_irqrestore(&codec->reg_lock, flags);
+	spin_unlock(&codec->reg_lock);
 }
 
 static unsigned int snd_ad1848_playback_pointer(void *private_data,
