@@ -934,7 +934,6 @@ static void snd_cs4231_overrange(cs4231_t *codec)
 
 void snd_cs4231_interrupt(snd_pcm_t * pcm, unsigned char status)
 {
-	unsigned long flags;
 	cs4231_t *codec;
 
 	codec = snd_magic_cast(cs4231_t, pcm->private_data, );
@@ -964,9 +963,9 @@ void snd_cs4231_interrupt(snd_pcm_t * pcm, unsigned char status)
 		}
 	}
 
-	spin_lock_irqsave(&codec->reg_lock, flags);
+	spin_lock(&codec->reg_lock);
 	snd_cs4231_outm(codec, CS4231_IRQ_STATUS, ~CS4231_ALL_IRQS | ~status, 0);
-	spin_unlock_irqrestore(&codec->reg_lock, flags);
+	spin_unlock(&codec->reg_lock);
 }
 
 static unsigned int snd_cs4231_playback_pointer(void *private_data,
@@ -1290,9 +1289,79 @@ static int snd_cs4231_capture_close(void *private_data,
 	return 0;
 }
 
+static void snd_cs4231_suspend(cs4231_t * codec)
+{
+	int reg;
+	unsigned long flags;
+	
+	spin_lock_irqsave(&codec->reg_lock, flags);
+	for (reg = 0; reg < 32; reg++)
+		codec->image[reg] = snd_cs4231_in(codec, reg);
+	spin_unlock_irqrestore(&codec->reg_lock, flags);
+}
+
+static void snd_cs4231_resume(cs4231_t * codec)
+{
+	int reg;
+	unsigned long flags;
+	int timeout;
+	
+	snd_cs4231_mce_up(codec);
+	spin_lock_irqsave(&codec->reg_lock, flags);
+	for (reg = 0; reg < 32; reg++) {
+		switch (reg) {
+		case CS4231_VERSION:
+			break;
+		default:
+			snd_cs4231_out(codec, reg, codec->image[reg]);
+			break;
+		}
+	}
+	spin_unlock_irqrestore(&codec->reg_lock, flags);
+#if 0
+	snd_cs4231_mce_down(codec);
+#else
+	/* The following is a workaround to avoid freeze after resume on TP600E.
+	   This is the first half of copy of snd_cs4231_mce_down(), but doesn't
+	   include rescheduling.  -- iwai
+	   */
+	spin_lock_irqsave(&codec->reg_lock, flags);
+	snd_cs4231_busy_wait(codec);
+	codec->mce_bit &= ~CS4231_MCE;
+	timeout = inb(CS4231P(codec, REGSEL));
+	outb(codec->mce_bit | (timeout & 0x1f), CS4231P(codec, REGSEL));
+	if (timeout == 0x80)
+		snd_printk("snd_cs4231_down [0x%x]: serious init problem - codec still busy\n", codec->port);
+	if ((timeout & CS4231_MCE) == 0 ||
+	    !(codec->hardware & (CS4231_HW_CS4231_MASK | CS4231_HW_CS4232_MASK))) {
+		spin_unlock_irqrestore(&codec->reg_lock, flags);
+		return;
+	}
+	snd_cs4231_busy_wait(codec);
+	return;
+#endif
+}
+
+static int snd_cs4231_pm_callback(struct pm_dev *dev, pm_request_t rqst, void *data)
+{
+	cs4231_t *codec = snd_magic_cast(cs4231_t, dev->data, 0);
+
+	switch (rqst) {
+	case PM_SUSPEND:
+		(*codec->suspend)(codec);
+		break;
+	case PM_RESUME:
+		(*codec->resume)(codec);
+		break;
+	}
+	return 0;
+}
+
 static void snd_cs4231_free(void *private_data)
 {
 	cs4231_t *codec = snd_magic_cast(cs4231_t, private_data, );
+	if (codec->pm_dev)
+		pm_unregister(codec->pm_dev);
 	if (codec->timer)
 		snd_device_free(codec->card, codec->timer);
 	snd_magic_kfree(codec);
@@ -1392,7 +1461,7 @@ int snd_cs4231_new_pcm(snd_card_t * card, int device,
 	case CS4231_HW_INTERWAVE:
 		str = "AMD InterWave";
 		break;
-	case CS4231_HW_OPL3SA:
+	case CS4231_HW_OPL3SA2:
 		str = card->shortname;
 		break;
 	default:
@@ -1408,6 +1477,13 @@ int snd_cs4231_new_pcm(snd_card_t * card, int device,
 	timer->private_data = codec;
 	memcpy(&timer->hw, &snd_cs4231_timer, sizeof(snd_cs4231_timer));
 	codec->timer = timer;
+
+	codec->suspend = snd_cs4231_suspend;
+	codec->resume = snd_cs4231_resume;
+	codec->pm_dev = pm_register(PM_ISA_DEV, 0, snd_cs4231_pm_callback);
+	if (codec->pm_dev)
+		codec->pm_dev->data = codec;
+
 	*rpcm = pcm;
 	return 0;
 }
