@@ -214,6 +214,54 @@ static void snd_cs4236_capture_format(cs4231_t * codec, unsigned char cdfr)
 	spin_unlock_irqrestore(&codec->reg_lock, flags);
 }
 
+static void snd_cs4236_suspend(cs4231_t * codec)
+{
+	int reg;
+	unsigned long flags;
+	
+	spin_lock_irqsave(&codec->reg_lock, flags);
+	for (reg = 0; reg < 32; reg++)
+		codec->image[reg] = snd_cs4231_in(codec, reg);
+	for (reg = 0; reg < 18; reg++)
+		codec->eimage[reg] = snd_cs4236_ext_in(codec, CS4236_I23VAL(reg));
+	for (reg = 2; reg < 9; reg++)
+		codec->cimage[reg] = snd_cs4236_ctrl_in(codec, reg);
+	spin_unlock_irqrestore(&codec->reg_lock, flags);
+}
+
+static void snd_cs4236_resume(cs4231_t * codec)
+{
+	int reg;
+	unsigned long flags;
+	
+	snd_cs4231_mce_up(codec);
+	spin_lock_irqsave(&codec->reg_lock, flags);
+	for (reg = 0; reg < 32; reg++) {
+		switch (reg) {
+		case CS4236_EXT_REG:
+		case CS4231_VERSION:
+		case 27:	/* why? CS4235 - master left */
+		case 29:	/* why? CS4235 - master right */
+			break;
+		default:
+			snd_cs4231_out(codec, reg, codec->image[reg]);
+			break;
+		}
+	}
+	for (reg = 0; reg < 18; reg++)
+		snd_cs4236_ext_out(codec, CS4236_I23VAL(reg), codec->eimage[reg]);
+	for (reg = 2; reg < 9; reg++) {
+		switch (reg) {
+		case 7:
+			break;
+		default:
+			snd_cs4236_ctrl_out(codec, reg, codec->cimage[reg]);
+		}
+	}
+	spin_unlock_irqrestore(&codec->reg_lock, flags);
+	snd_cs4231_mce_down(codec);
+}
+
 int snd_cs4236_new_pcm(snd_card_t * card, int device,
 		       unsigned short port,
 		       unsigned short cport,	/* control port */
@@ -273,6 +321,8 @@ int snd_cs4236_new_pcm(snd_card_t * card, int device,
 	  codec->set_capture_rate = snd_cs4236_xrate;
 	codec->set_playback_format = snd_cs4236_playback_format;
 	codec->set_capture_format = snd_cs4236_capture_format;
+	codec->suspend = snd_cs4236_suspend;
+	codec->resume = snd_cs4236_resume;
 	snd_cs4236_ext_out(codec, CS4236_DAC_MUTE, 0xe0);	/* IFSE enable, digital master mute */
 	*rpcm = pcm;
 	return 0;
