@@ -660,8 +660,8 @@ int snd_es1688_new_pcm(snd_card_t * card, int device,
 		snd_device_free(card, pcm);
 		return -ENOMEM;
 	}
-	codec->reg_lock = SPIN_LOCK_UNLOCKED;
-	codec->mixer_lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&codec->reg_lock);
+	spin_lock_init(&codec->mixer_lock);
 	codec->pcm = pcm;
 	codec->card = pcm->card;
 	codec->port = port;
@@ -1276,15 +1276,14 @@ EXPORT_SYMBOL(snd_es1688_new_mixer);
  *  INIT part
  */
 
-#ifdef MODULE
-
-int __init init_module(void)
+static int __init alsa_es1688_init(void)
 {
 	return 0;
 }
 
-void __exit cleanup_module(void)
+static void __exit alsa_es1688_exit(void)
 {
 }
 
-#endif
+module_init(alsa_es1688_init)
+module_exit(alsa_es1688_exit)
