@@ -1,6 +1,5 @@
 /*
- *  Copyright (c) by Abramo Bagnara
- *  <abbagnara@racine.ra.it>
+ *  Copyright (c) by Abramo Bagnara <abramo@alsa-project.org>
  *  Routines for control of ESS ES18xx chip
  *
  *
@@ -101,10 +100,10 @@ static int snd_es18xx_dsp_command(es18xx_t * codec, unsigned char val)
         for(i = MILLISECOND; i; i--)
                 if ((inb(codec->port + 0x0C) & 0x80) == 0) {
                         outb(val, codec->port + 0x0C);
-                        return 1;
+                        return 0;
                 }
         snd_printk("snd_es18xx_dsp_command: timeout (0x%x)\n", val);
-        return 0;
+        return -EINVAL;
 }
 
 static int snd_es18xx_dsp_get_byte(es18xx_t * codec)
@@ -123,58 +122,99 @@ static int snd_es18xx_dsp_get_byte(es18xx_t * codec)
 static int snd_es18xx_write(es18xx_t * codec,
 			    unsigned char reg, unsigned char data)
 {
+	unsigned long flags;
+	int ret;
+	
+	spin_lock_irqsave(&codec->reg_lock, flags);
+	ret = snd_es18xx_dsp_command(codec, reg);
+	if (ret < 0)
+		goto end;
+	ret = snd_es18xx_dsp_command(codec, data);
+ end:
+	spin_unlock_irqrestore(&codec->reg_lock, flags);
 #ifdef REG_DEBUG
-	snd_printk("Reg %02x := %02x\n", reg, data);
+	snd_printk("Reg %02x set to %02x\n", reg, data);
 #endif
-        if (!snd_es18xx_dsp_command(codec, reg))
-                return 0;
-
-        return snd_es18xx_dsp_command(codec, data);
+	return ret;
 }
 
 static int snd_es18xx_read(es18xx_t *codec, unsigned char reg)
 {
-	int data;
-        /* Read a byte from an extended mode register of ES18xx */
-        if (!snd_es18xx_dsp_command(codec, 0xC0))
-                return -1;
-        if (!snd_es18xx_dsp_command(codec, reg))
-                return -1;
+	unsigned long flags;
+	int ret, data;
+        spin_lock_irqsave(&codec->reg_lock, flags);
+	ret = snd_es18xx_dsp_command(codec, 0xC0);
+	if (ret < 0)
+		goto end;
+        ret = snd_es18xx_dsp_command(codec, reg);
+	if (ret < 0)
+		goto end;
 	data = snd_es18xx_dsp_get_byte(codec);
+	ret = data;
+ end:
+        spin_unlock_irqrestore(&codec->reg_lock, flags);
 #ifdef REG_DEBUG
-	snd_printk("Reg %02x set to %02x\n", reg, data);
+	snd_printk("Reg %02x now is %02x (%d)\n", reg, data, ret);
 #endif
-	return data;
+	return ret;
 }
 
 static int snd_es18xx_bits(es18xx_t *codec, unsigned char reg,
 			   unsigned char set, unsigned char unset)
 {
-        int old = snd_es18xx_read(codec, reg);
-	int new;
-        if (old < 0)
-                return -1;
+        int old, new, ret;
+	unsigned long flags;
+        spin_lock_irqsave(&codec->reg_lock, flags);
+        ret = snd_es18xx_dsp_command(codec, 0xC0);
+	if (ret < 0)
+		goto end;
+        ret = snd_es18xx_dsp_command(codec, reg);
+	if (ret < 0)
+		goto end;
+	old = snd_es18xx_dsp_get_byte(codec);
+	if (old < 0) {
+		ret = old;
+		goto end;
+	}
 	new = (old & ~unset) | set;
-	if (new != old)
-		return snd_es18xx_write(codec, reg, new);
-	return 0;
+	if (new != old) {
+		ret = snd_es18xx_dsp_command(codec, reg);
+		if (ret < 0)
+			goto end;
+		ret = snd_es18xx_dsp_command(codec, new);
+		if (ret < 0)
+			goto end;
+	}
+	ret = new;
+ end:
+#ifdef REG_DEBUG
+	snd_printk("Reg %02x was %02x, set to %02x (%d)\n", reg, old, new, ret);
+#endif
+        spin_unlock_irqrestore(&codec->reg_lock, flags);
+	return ret;
 }
 
 inline void snd_es18xx_mixer_write(es18xx_t * codec,
 			    unsigned char reg, unsigned char data)
 {
+	unsigned long flags;
+        spin_lock_irqsave(&codec->mixer_lock, flags);
+        outb(reg, codec->port + 0x04);
+        outb(data, codec->port + 0x05);
+        spin_unlock_irqrestore(&codec->mixer_lock, flags);
 #ifdef REG_DEBUG
 	snd_printk("Mixer reg %02x set to %02x\n", reg, data);
 #endif
-        outb(reg, codec->port + 0x04);
-        outb(data, codec->port + 0x05);
 }
 
 inline unsigned char snd_es18xx_mixer_read(es18xx_t * codec, unsigned char reg)
 {
-	unsigned char data;
+	unsigned long flags;
+	int data;
+        spin_lock_irqsave(&codec->mixer_lock, flags);
         outb(reg, codec->port + 0x04);
 	data = inb(codec->port + 0x05);
+        spin_unlock_irqrestore(&codec->mixer_lock, flags);
 #ifdef REG_DEBUG
 	snd_printk("Mixer reg %02x now is %02x\n", reg, data);
 #endif
@@ -184,13 +224,15 @@ inline unsigned char snd_es18xx_mixer_read(es18xx_t * codec, unsigned char reg)
 static inline int snd_es18xx_mixer_bits(es18xx_t *codec, unsigned char reg,
 					unsigned char set, unsigned char unset)
 {
-	unsigned char old;
-	unsigned char new;
+	int old, new;
+	unsigned long flags;
+        spin_lock_irqsave(&codec->mixer_lock, flags);
         outb(reg, codec->port + 0x04);
 	old = inb(codec->port + 0x05);
 	new = (old & ~unset) | set;
 	if (new != old)
 		outb(new, codec->port + 0x05);
+        spin_unlock_irqrestore(&codec->mixer_lock, flags);
 #ifdef REG_DEBUG
 	snd_printk("Mixer reg %02x was %02x, set to %02x\n", reg, old, new);
 #endif
@@ -200,15 +242,15 @@ static inline int snd_es18xx_mixer_bits(es18xx_t *codec, unsigned char reg,
 static inline int snd_es18xx_mixer_writable(es18xx_t *codec, unsigned char reg,
 					    unsigned char mask)
 {
-	unsigned char old;
-	unsigned char expected;
-	unsigned char new;
+	int old, expected, new;
+	unsigned long flags;
+        spin_lock_irqsave(&codec->mixer_lock, flags);
         outb(reg, codec->port + 0x04);
 	old = inb(codec->port + 0x05);
 	expected = old ^ mask;
 	outb(expected, codec->port + 0x05);
 	new = inb(codec->port + 0x05);
-
+        spin_unlock_irqrestore(&codec->mixer_lock, flags);
 #ifdef REG_DEBUG
 	snd_printk("Mixer reg %02x was %02x, set to %02x, now is %02x\n", reg, old, expected, new);
 #endif
@@ -227,6 +269,8 @@ static unsigned char snd_es18xx_config_read(es18xx_t *codec, unsigned char reg)
 static void snd_es18xx_config_write(es18xx_t *codec, 
 				    unsigned char reg, unsigned char data)
 {
+	/* No need for spinlocks, this function is used only in
+	   otherwise protected init code */
 	outb(reg, codec->ctrl_port);
 	outb(data, codec->ctrl_port+1);
 #ifdef REG_DEBUG
@@ -257,9 +301,6 @@ static int snd_es18xx_reset_fifo(es18xx_t * codec)
 static int snd_es18xx_initialize(es18xx_t * codec)
 {
 	int mask = 0;
-	unsigned long flags;
-
-        spin_lock_irqsave(&codec->reg_lock, flags);
 
         /* enable extended mode */
         snd_es18xx_dsp_command(codec, 0xC6);
@@ -318,7 +359,6 @@ static int snd_es18xx_initialize(es18xx_t * codec)
 			irqmask = 3;
 			break;
 		default:
-			spin_unlock_irqrestore(&codec->reg_lock, flags);
 			snd_printk("es18xx: invalid irq %i\n", codec->irq);
 			return -ENODEV;
 		}
@@ -333,7 +373,6 @@ static int snd_es18xx_initialize(es18xx_t * codec)
 			dma1mask = 3;
 			break;
 		default:
-			spin_unlock_irqrestore(&codec->reg_lock, flags);
 			snd_printk("es18xx: invalid dma1 %i\n", codec->dma1);
 			return -ENODEV;
 		}
@@ -351,7 +390,6 @@ static int snd_es18xx_initialize(es18xx_t * codec)
 			dma2mask = 3;
 			break;
 		default:
-			spin_unlock_irqrestore(&codec->reg_lock, flags);
 			snd_printk("es18xx: invalid dma2 %i\n", codec->dma2);
 			return -ENODEV;
 		}
@@ -406,21 +444,15 @@ static int snd_es18xx_initialize(es18xx_t * codec)
 	snd_es18xx_dsp_command(codec, 0xD1);
 #endif
 
-        spin_unlock_irqrestore(&codec->reg_lock, flags);
-
         return 0;
 }
 
 static int snd_es18xx_identify(es18xx_t * codec)
 {
 	int hi,lo;
-        unsigned long flags;
-
-        spin_lock_irqsave(&codec->reg_lock, flags);
 
 	/* reset */
 	if (snd_es18xx_reset(codec) < 0) {
-		spin_unlock_irqrestore(&codec->reg_lock, flags);
                 snd_printk("snd_es18xx_reset at 0x%x failed!!!\n", codec->port);
 		return -ENODEV;
 	}
@@ -428,25 +460,20 @@ static int snd_es18xx_identify(es18xx_t * codec)
 	snd_es18xx_dsp_command(codec, 0xe7);
 	hi = snd_es18xx_dsp_get_byte(codec);
 	if (hi < 0) {
-		spin_unlock_irqrestore(&codec->reg_lock, flags);
 		return hi;
 	}
 	lo = snd_es18xx_dsp_get_byte(codec);
 	if ((lo & 0xf0) != 0x80) {
-		spin_unlock_irqrestore(&codec->reg_lock, flags);
 		return -ENODEV;
 	}
 	if (hi == 0x48) {
-		spin_unlock_irqrestore(&codec->reg_lock, flags);
 		codec->version = 0x488;
 		return 0;
 	}
 	if (hi != 0x68) {
-		spin_unlock_irqrestore(&codec->reg_lock, flags);
 		return -ENODEV;
 	}
 	if ((lo & 0x0f) < 8) {
-		spin_unlock_irqrestore(&codec->reg_lock, flags);
 		codec->version = 0x688;
 		return 0;
 	}
@@ -455,7 +482,6 @@ static int snd_es18xx_identify(es18xx_t * codec)
 	hi = inb(codec->port + 0x05);
 	lo = inb(codec->port + 0x05);
 	if (hi != lo) {
-		spin_unlock_irqrestore(&codec->reg_lock, flags);
 		codec->version = hi << 8 | lo;
 		codec->ctrl_port = inb(codec->port + 0x05) << 8;
 		codec->ctrl_port += inb(codec->port + 0x05);
@@ -478,7 +504,6 @@ static int snd_es18xx_identify(es18xx_t * codec)
 	}
 	else
 		codec->version = 0x1688;
-        spin_unlock_irqrestore(&codec->reg_lock, flags);
 	return 0;
 }
 
@@ -627,15 +652,12 @@ static int snd_es18xx_capture_ioctl(void *private_data,
 static int snd_es18xx_playback1_prepare(es18xx_t *codec,
 					snd_pcm_subchn_t *subchn)
 {
-        unsigned long flags;
 	snd_pcm_runtime_t *runtime = subchn->runtime;
 	unsigned int size = snd_pcm_lib_transfer_size(subchn);
 	unsigned int count = snd_pcm_lib_transfer_fragment(subchn);
 
 	codec->p_a_dma_size = size;
 
-        spin_lock_irqsave(&codec->mixer_lock, flags);
-
         snd_es18xx_set_rate(codec, runtime->format.rate, DAC2, 1);
 
         /* Transfer Count Reload */
@@ -651,8 +673,6 @@ static int snd_es18xx_playback1_prepare(es18xx_t *codec,
 			      0x07);
 
 
-        spin_unlock_irqrestore(&codec->mixer_lock, flags);
-
         /* Set DMA controller */
         snd_dma_program(codec->dma2, runtime->dma_area->buf, size, DMA_MODE_WRITE | DMA_AUTOINIT);
 
@@ -663,8 +683,6 @@ static int snd_es18xx_playback1_trigger(es18xx_t *codec,
 					snd_pcm_subchn_t * subchn,
 					int cmd)
 {
-        unsigned long flags;
-
         if (cmd == SND_PCM_TRIGGER_GO) {
 		if (codec->active & DAC2)
 			return 0;
@@ -677,7 +695,6 @@ static int snd_es18xx_playback1_trigger(es18xx_t *codec,
 		return -EINVAL;
 	}
 
-	spin_lock_irqsave(&codec->reg_lock, flags);
 	if (cmd == SND_PCM_TRIGGER_GO) {	
                 /* Start DMA */
 		if (codec->dma2 >= 4)
@@ -709,14 +726,12 @@ static int snd_es18xx_playback1_trigger(es18xx_t *codec,
 #endif
         }
 
-        spin_unlock_irqrestore(&codec->reg_lock, flags);
 	return 0;
 }
 
 static int snd_es18xx_capture_prepare(void *private_data,
 				      snd_pcm_subchn_t *subchn)
 {
-        unsigned long flags;
         es18xx_t *codec = snd_magic_cast(es18xx_t, private_data, -ENXIO);
 	snd_pcm_runtime_t *runtime = subchn->runtime;
 	unsigned int size = snd_pcm_lib_transfer_size(subchn);
@@ -724,8 +739,6 @@ static int snd_es18xx_capture_prepare(void *private_data,
 
 	codec->c_a_dma_size = size;
 
-        spin_lock_irqsave(&codec->reg_lock, flags);
-
 	snd_es18xx_reset_fifo(codec);
 
         /* Set stereo/mono */
@@ -750,8 +763,6 @@ static int snd_es18xx_capture_prepare(void *private_data,
                          (snd_pcm_format_width(runtime->format.format) == 16 ? 0x04 : 0x00) |
                          (snd_pcm_format_unsigned(runtime->format.format) ? 0x00 : 0x20));
 
-        spin_unlock_irqrestore(&codec->reg_lock, flags);
-
         /* Set DMA controler */
         snd_dma_program(codec->dma1, runtime->dma_area->buf, size, DMA_MODE_READ | DMA_AUTOINIT);
 
@@ -763,7 +774,6 @@ static int snd_es18xx_capture_trigger(void *private_data,
 				      int cmd)
 {
         es18xx_t *codec = snd_magic_cast(es18xx_t, private_data, -ENXIO);
-        unsigned long flags;
 
         if (cmd == SND_PCM_TRIGGER_GO) {
 		if (codec->active & ADC1)
@@ -777,29 +787,24 @@ static int snd_es18xx_capture_trigger(void *private_data,
 		return -EINVAL;
 	}
 
-	spin_lock_irqsave(&codec->reg_lock, flags);
 	if (cmd == SND_PCM_TRIGGER_GO)
                 /* Start DMA */
                 snd_es18xx_write(codec, 0xB8, 0x0f);
         else
                 /* Stop DMA */
                 snd_es18xx_write(codec, 0xB8, 0x00);
-        spin_unlock_irqrestore(&codec->reg_lock, flags);
 	return 0;
 }
 
 static int snd_es18xx_playback2_prepare(es18xx_t *codec,
 					snd_pcm_subchn_t *subchn)
 {
-        unsigned long flags;
 	snd_pcm_runtime_t *runtime = subchn->runtime;
 	unsigned int size = snd_pcm_lib_transfer_size(subchn);
 	unsigned int count = snd_pcm_lib_transfer_fragment(subchn);
 
 	codec->p_b_dma_size = size;
 
-        spin_lock_irqsave(&codec->reg_lock, flags);
-
 	snd_es18xx_reset_fifo(codec);
 
         /* Set stereo/mono */
@@ -822,8 +827,6 @@ static int snd_es18xx_playback2_prepare(es18xx_t *codec,
                          (snd_pcm_format_width(runtime->format.format) == 16 ? 0x04 : 0x00) |
                          (snd_pcm_format_unsigned(runtime->format.format) ? 0x00 : 0x20));
 
-        spin_unlock_irqrestore(&codec->reg_lock, flags);
-
         /* Set DMA controler */
         snd_dma_program(codec->dma1, runtime->dma_area->buf, size, DMA_MODE_WRITE | DMA_AUTOINIT);
 
@@ -834,8 +837,6 @@ static int snd_es18xx_playback2_trigger(es18xx_t *codec,
 					snd_pcm_subchn_t *subchn,
 					int cmd)
 {
-        unsigned long flags;
-
         if (cmd == SND_PCM_TRIGGER_GO) {
 		if (codec->active & DAC1)
 			return 0;
@@ -848,7 +849,6 @@ static int snd_es18xx_playback2_trigger(es18xx_t *codec,
 		return -EINVAL;
 	}
 
-	spin_lock_irqsave(&codec->reg_lock, flags);
 	if (cmd == SND_PCM_TRIGGER_GO) {
                 /* Start DMA */
                 snd_es18xx_write(codec, 0xB8, 0x05);
@@ -869,7 +869,6 @@ static int snd_es18xx_playback2_trigger(es18xx_t *codec,
                 snd_es18xx_dsp_command(codec, 0xD3);
 #endif
         }
-        spin_unlock_irqrestore(&codec->reg_lock, flags);
 	return 0;
 }
 
@@ -1161,11 +1160,9 @@ int snd_es18xx_new_device(snd_card_t * card,
 static int snd_es18xx_mixer_volume(snd_kmixer_element_t *element, int w_flag, int *voices, int reg)
 {
 	es18xx_t * codec = snd_magic_cast(es18xx_t, element->private_data, -ENXIO);
-        unsigned long flags;
         int change = 0;
         unsigned char oval, nval;
 
-        spin_lock_irqsave(&codec->mixer_lock, flags);
 	if (reg >= 0xa0) {
 		oval = snd_es18xx_read(codec, reg);
 	} else {
@@ -1184,7 +1181,6 @@ static int snd_es18xx_mixer_volume(snd_kmixer_element_t *element, int w_flag, in
 			}
 		}
         }
-        spin_unlock_irqrestore(&codec->mixer_lock, flags);
         return change;
 }
 
@@ -1193,11 +1189,9 @@ static int snd_es18xx_mixer_imux(snd_kmixer_element_t *element,
 				 snd_kmixer_element_t **melement)
 {
 	es18xx_t * codec = snd_magic_cast(es18xx_t, element->private_data, -ENXIO);
-	unsigned long flags;
 	unsigned char reg, oval, nval, mask;
 	int change = 0;
 
-	spin_lock_irqsave(&codec->mixer_lock, flags);
 	reg = snd_es18xx_mixer_read(codec, 0x1c);
 	if (codec->caps & ES18XX_MUTEREC)
 		mask = 0x17;
@@ -1249,7 +1243,6 @@ static int snd_es18xx_mixer_imux(snd_kmixer_element_t *element,
 #endif
 		}
 	}	
-	spin_unlock_irqrestore(&codec->mixer_lock, flags);
 	return change;
 }
 
@@ -1258,11 +1251,9 @@ static int snd_es18xx_mixer_recmon(snd_kmixer_element_t *element,
 				   snd_kmixer_element_t **melement)
 {
 	es18xx_t * codec = snd_magic_cast(es18xx_t, element->private_data, -ENXIO);
-	unsigned long flags;
 	unsigned char reg, oval, nval;
 	int change = 0;
 
-	spin_lock_irqsave(&codec->mixer_lock, flags);
 	reg = snd_es18xx_read(codec, 0xa8);
 	oval = reg & 0x08;
 	if (w_flag) {
@@ -1287,7 +1278,6 @@ static int snd_es18xx_mixer_recmon(snd_kmixer_element_t *element,
 			*melement = NULL;
 		}
 	}	
-	spin_unlock_irqrestore(&codec->mixer_lock, flags);
 	return change;
 }
 
@@ -1379,11 +1369,9 @@ static int snd_es18xx_mixer_igain_v(snd_kmixer_element_t *element, int w_flag, i
 static int snd_es18xx_mixer_output_v(snd_kmixer_element_t *element, int w_flag, int *voices)
 {
 	es18xx_t * codec = snd_magic_cast(es18xx_t, element->private_data, -ENXIO);
-        unsigned long flags;
         int change = 0;
         unsigned char oleft, oright;
 
-        spin_lock_irqsave(&codec->mixer_lock, flags);
         oleft = snd_es18xx_mixer_read(codec, 0x60) & 0x3f;
         oright = snd_es18xx_mixer_read(codec, 0x62) & 0x3f;
         if (!w_flag) {
@@ -1399,17 +1387,14 @@ static int snd_es18xx_mixer_output_v(snd_kmixer_element_t *element, int w_flag,
 			change = 1;
 		}
         }
-        spin_unlock_irqrestore(&codec->mixer_lock, flags);
         return change;
 }
 
 static int snd_es18xx_mixer_output_s(snd_kmixer_element_t *element, int w_flag, unsigned int *bitmap)
 {
 	es18xx_t * codec = snd_magic_cast(es18xx_t, element->private_data, -ENXIO);
-        unsigned long flags;
         int change = 0;
 	int oleft, oright;
-        spin_lock_irqsave(&codec->mixer_lock, flags);
 	oleft = !(snd_es18xx_mixer_read(codec, 0x60) & 0x40);
 	oright = !(snd_es18xx_mixer_read(codec, 0x62) & 0x40);
 	
@@ -1430,18 +1415,15 @@ static int snd_es18xx_mixer_output_s(snd_kmixer_element_t *element, int w_flag,
 		}
 		
 	}
-        spin_unlock_irqrestore(&codec->mixer_lock, flags);
         return change;
 }
 
 static int snd_es18xx_mixer_e3d(snd_kmixer_element_t *element, int w_flag, struct snd_mixer_element_3d_effect1 *effect1)
 {
 	es18xx_t * codec = snd_magic_cast(es18xx_t, element->private_data, -ENXIO);
-        unsigned long flags;
         int change = 0;
-        unsigned int osw, oval;
+        int osw, oval;
 	
-        spin_lock_irqsave(&codec->mixer_lock, flags);
         osw = !!(snd_es18xx_mixer_read(codec, 0x50) & 0x0c);
         oval = snd_es18xx_mixer_read(codec, 0x52) & 0x3f;
 	if (!w_flag) {
@@ -1458,17 +1440,14 @@ static int snd_es18xx_mixer_e3d(snd_kmixer_element_t *element, int w_flag, struc
 		}
 	}
 
-        spin_unlock_irqrestore(&codec->mixer_lock, flags);
         return change;
 }
 
 static int snd_es18xx_mixer_micpre_v(snd_kmixer_element_t *element, int w_flag, int *voices)
 {
 	es18xx_t * codec = snd_magic_cast(es18xx_t, element->private_data, -ENXIO);
-        unsigned long flags;
         int change = 0;
 	int old;
-        spin_lock_irqsave(&codec->mixer_lock, flags);
 	switch (codec->version) {
 	case 0x1869:
 	case 0x1879:
@@ -1497,18 +1476,15 @@ static int snd_es18xx_mixer_micpre_v(snd_kmixer_element_t *element, int w_flag,
 			change = 1;
 		}
 	}
-        spin_unlock_irqrestore(&codec->mixer_lock, flags);
         return change;
 }
 
 static int snd_es18xx_mixer_speaker_v(snd_kmixer_element_t *element, int w_flag, int *voices)
 {
 	es18xx_t * codec = snd_magic_cast(es18xx_t, element->private_data, -ENXIO);
-        unsigned long flags;
         int change = 0;
         unsigned char oval, nval;
 
-        spin_lock_irqsave(&codec->mixer_lock, flags);
 	oval = snd_es18xx_mixer_read(codec, 0x3c);
         if (!w_flag) {
                 voices[0] = oval & 0x07;
@@ -1518,7 +1494,6 @@ static int snd_es18xx_mixer_speaker_v(snd_kmixer_element_t *element, int w_flag,
 			snd_es18xx_mixer_write(codec, 0x3c, nval);
 		}
         }
-        spin_unlock_irqrestore(&codec->mixer_lock, flags);
         return change;
 }
 
