@@ -545,7 +545,6 @@ static void snd_opti93x_overrange(opti93x_t *codec)
 
 void snd_opti93x_interrupt(snd_pcm_t *pcm, unsigned char status)
 {
-	unsigned long flags;
 	opti93x_t *codec;
 
 	codec = snd_magic_cast(opti93x_t, pcm->private_data, );
@@ -560,9 +559,9 @@ void snd_opti93x_interrupt(snd_pcm_t *pcm, unsigned char status)
 		snd_pcm_transfer_done(codec->capture_subchn);
 	}
 
-	spin_lock_irqsave(&codec->lock, flags);
+	spin_lock(&codec->lock);
 	outb(0x00, OPTi93X_PORT(codec, STATUS));
-	spin_unlock_irqrestore(&codec->lock, flags);
+	spin_unlock(&codec->lock);
 }
 
 
