@@ -106,7 +106,7 @@ MODULE_PARM_DESC(osrun_time, "how many seconds to wait for the ICS2115 OS");
  *	This sucks, hopefully it'll get standardised
  */
  
-#if defined(__alpha__)
+#if defined(__alpha__) || defined(__powerpc__)
 #ifdef __SMP__
 #define LOOPS_PER_SEC cpu_data[smp_processor_id()].loops_per_sec
 #else
@@ -1353,6 +1353,7 @@ wavefront_find_free_sample (snd_wavefront_t *dev)
 	return -1;
 }
 
+#if 0
 static int 
 wavefront_find_free_patch (snd_wavefront_t *dev)
 
@@ -1367,6 +1368,7 @@ wavefront_find_free_patch (snd_wavefront_t *dev)
 	snd_printk (LOGNAME "no free patch slots!\n");
 	return -1;
 }
+#endif
 
 static int
 wavefront_load_patch (snd_wavefront_t *dev, const char *addr)
@@ -2265,7 +2267,7 @@ snd_wavefront_detect (snd_wavefront_card_t *card)
 		if (!wf_raw) {
 			return 0;
 		} else {
-			snd_printk (LOGNAME "reloading firmware anyway.\n");
+			snd_printk (LOGNAME "reloading firmware as you requested.\n");
 			dev->israw = 1;
 		}
 
