@@ -1019,15 +1019,14 @@ EXPORT_SYMBOL(snd_wavefront_fx_ioctl);
 EXPORT_SYMBOL(snd_wavefront_fx_open);
 EXPORT_SYMBOL(snd_wavefront_fx_release);
 
-#ifdef MODULE
-
-int __init init_module(void)
+static int __init alsa_wavefront_fx_init(void)
 {
 	return 0;
 }
 
-void __exit cleanup_module(void)
+static void __exit alsa_wavefront_fx_exit(void)
 {
 }
 
-#endif
+module_init(alsa_wavefront_fx_init)
+module_exit(alsa_wavefront_fx_exit)
