@@ -913,16 +913,15 @@ void snd_cs461x_interrupt(cs461x_t *codec)
 	}
 	if ((status & HISR_MIDI) && codec->rmidi) {
 		unsigned char c;
-		unsigned long flags;
 		
-		spin_lock_irqsave(&codec->reg_lock, flags);
+		spin_lock(&codec->reg_lock);
 		while ((snd_cs461x_peekBA0(codec, BA0_MIDSR) & MIDSR_RBE) == 0) {
 			c = snd_cs461x_peekBA0(codec, BA0_MIDRP);
 			if ((codec->midcr & MIDCR_RIE) == 0)
 				continue;
-			spin_unlock_irqrestore(&codec->reg_lock, flags);
+			spin_unlock(&codec->reg_lock);
 			snd_rawmidi_receive(codec->rmidi, &c, 1);
-			spin_lock_irqsave(&codec->reg_lock, flags);
+			spin_lock(&codec->reg_lock);
 		}
 		while ((snd_cs461x_peekBA0(codec, BA0_MIDSR) & MIDSR_TBF) == 0) {
 			if ((codec->midcr & MIDCR_TIE) == 0)
@@ -934,7 +933,7 @@ void snd_cs461x_interrupt(cs461x_t *codec)
 			}
 			snd_cs461x_pokeBA0(codec, BA0_MIDWP, c);
 		}
-		spin_unlock_irqrestore(&codec->reg_lock, flags);
+		spin_unlock(&codec->reg_lock);
 	}
 	/*
 	 *  EOI to the PCI part....reenables interrupts
@@ -946,7 +945,7 @@ static snd_pcm_hardware_t snd_cs461x_playback =
 {
 	SND_PCM_CHNINFO_MMAP |
 #ifdef ACCEPT_VALID
-	SND_PCM_CHNINFO_VALID |		/* NOT TRUE!!! OSS REQUIRES IT */
+	SND_PCM_CHNINFO_MMAP_VALID |	/* NOT TRUE!!! OSS REQUIRES IT */
 #endif
 	SND_PCM_CHNINFO_BLOCK | SND_PCM_CHNINFO_INTERLEAVE |
 	SND_PCM_CHNINFO_BLOCK_TRANSFER,		/* flags */
@@ -971,7 +970,7 @@ static snd_pcm_hardware_t snd_cs461x_capture =
 {
 	SND_PCM_CHNINFO_MMAP |
 #ifdef ACCEPT_VALID
-	SND_PCM_CHNINFO_VALID |		/* NOT TRUE!!! OSS REQUIRES IT */
+	SND_PCM_CHNINFO_MMAP_VALID |	/* NOT TRUE!!! OSS REQUIRES IT */
 #endif
 	SND_PCM_CHNINFO_BLOCK | SND_PCM_CHNINFO_INTERLEAVE |
 	SND_PCM_CHNINFO_BLOCK_TRANSFER,		/* flags */
