@@ -154,7 +154,7 @@ static void snd_es1370_codec_write(void *private_data,
 			return;
 		}
 		spin_unlock_irqrestore(&ensoniq->reg_lock, flags);
-		current->state = TASK_INTERRUPTIBLE;
+		set_current_state(TASK_INTERRUPTIBLE);
 		time -= schedule_timeout(1) ? 1 : 0;
 	} while (time > 0);
 	snd_printk("es1370: codec write timeout, status = 0x%x\n", inl(ES_REG(ensoniq, STATUS)));
@@ -1698,13 +1698,12 @@ int snd_ensoniq_midi(ensoniq_t * ensoniq, int device, snd_rawmidi_t **rrawmidi)
 void snd_ensoniq_interrupt(ensoniq_t * ensoniq)
 {
 	unsigned int status, sctrl;
-	unsigned long flags;
 
 	status = inl(ES_REG(ensoniq, STATUS));
 	if (!(status & ES_INTR))
 		return;
 
-	spin_lock_irqsave(&ensoniq->reg_lock, flags);
+	spin_lock(&ensoniq->reg_lock);
 	sctrl = ensoniq->sctrl;
 	if (status & ES_DAC1)
 		sctrl &= ~ES_P1_INT_EN;
@@ -1714,7 +1713,7 @@ void snd_ensoniq_interrupt(ensoniq_t * ensoniq)
 		sctrl &= ~ES_R1_INT_EN;
 	outl(sctrl, ES_REG(ensoniq, SERIAL));
 	outl(ensoniq->sctrl, ES_REG(ensoniq, SERIAL));
-	spin_unlock_irqrestore(&ensoniq->reg_lock, flags);
+	spin_unlock(&ensoniq->reg_lock);
 
 	if (ensoniq->rmidi) {
 		if (status & ES_UART)
