@@ -1599,9 +1599,7 @@ void snd_solo_midi(es1938_t * solo, mpu401_t * mpu)
 void snd_solo_interrupt(es1938_t * solo)
 {
 	unsigned char status, audiostatus;
-	unsigned long flags;
 
-	spin_lock_irqsave(&solo->reg_lock, flags);
 	
 	status = inb(SLIO_REG(solo, IRQCONTROL));
 #if 0
@@ -1634,15 +1632,16 @@ void snd_solo_interrupt(es1938_t * solo)
 		printk("Solodebug - AUDIO channel 2 DMAC DMA base: %u\n", inl(SLIO_REG(solo, AUDIO2DMAADDR)));
 
 #endif
-			if (solo->pcm) {
+		if (solo->pcm) {
 			/* clear irq */
+			spin_lock(&solo->reg_lock);
 			snd_solo_mixer_out(solo, ESSSB_IREG_AUDIO2CONTROL2, 0x80, 0);
+			spin_unlock(&solo->reg_lock);
 			snd_pcm_transfer_done(solo->playback2_subchn);
 		}
 	}
 
 	outb(solo->irqmask, SLIO_REG(solo, IRQCONTROL));
-	spin_unlock_irqrestore(&solo->reg_lock, flags);
 }
 
 EXPORT_SYMBOL(snd_solo_create);
