@@ -106,11 +106,10 @@
    * Debug ?  *
    ************/
 
-#define ESM_EDEBUG		/* Output if errors occur */
-#define ESM_DDEBUG		/* Output on important locations */
-/*#define ESM_IDEBUG*//* Interrupt Debugging - Much Output */
-/*#define ESM_CDEBUG*//* AC97 Codec Debugging - Also much output */
-/*#define ESM_DEBUGIO*//* IO Debug - Very much output */
+#ifdef CONFIG_SND_DEBUG
+ #define ESM_DDEBUG		/* Output on important locations */
+ /*#define ESM_IDEBUG*//* Interrupt Debugging - Much Output */
+#endif
 
 /* *********
    * Hacks *
@@ -123,67 +122,6 @@
 static const unsigned sample_size[] = { 1, 2, 2, 4 };
 static const unsigned sample_shift[] = { 0, 1, 1, 2 };
 
-/* ***************
-   * IO Routines *
-   ***************/
-
-#ifdef ESM_DEBUGIO
-
-#define ES_OUTB dbg_outb
-#define ES_OUTW dbg_outw
-#define ES_OUTL dbg_outl
-#define ES_INB dbg_inb
-#define ES_INW dbg_inw
-#define ES_INL dbg_inl
-
-static void dbg_outb(u8 val, int port)
-{
-	snd_printk("outb: 0x%x, 0x%x\n", val, port);
-	outb(val, port);
-}
-
-static void dbg_outw(u16 val, int port)
-{
-	snd_printk("outw: 0x%x, 0x%x\n", val, port);
-	outw(val, port);
-}
-
-static void dbg_outl(u32 val, int port)
-{
-	snd_printk("outl: 0x%x, 0x%x\n", val, port);
-	outl(val, port);
-}
-
-static u8 dbg_inb(int port)
-{
-	u8 val = inb(port);
-	snd_printk("inb: 0x%x, 0x%x\n", val, port);
-	return val;
-}
-
-static u16 dbg_inw(int port)
-{
-	u16 val = inw(port);
-	snd_printk("inw: 0x%x, 0x%x\n", val, port);
-	return val;
-}
-
-static u32 dbg_inl(int port)
-{
-	u32 val = inl(port);
-	snd_printk("inl: 0x%x, 0x%x\n", val, port);
-	return val;
-}
-
-#else
-#define ES_OUTB outb
-#define ES_OUTW outw
-#define ES_OUTL outl
-#define ES_INL inl
-#define ES_INB inb
-#define ES_INW inw
-#endif
-
 /* *********************
    * Low Level Funcs!  *
    *********************/
@@ -195,8 +133,8 @@ static void maestro_write(es1968_t * esm, u16 reg, u16 data)
 
 	spin_lock_irqsave(&esm->reg_lock, flags);
 
-	ES_OUTW(reg, ioaddr + ESM_INDEX);
-	ES_OUTW(data, ioaddr + ESM_DATA);
+	outw(reg, ioaddr + ESM_INDEX);
+	outw(data, ioaddr + ESM_DATA);
 	esm->maestro_map[reg] = data;
 
 	spin_unlock_irqrestore(&esm->reg_lock, flags);
@@ -206,8 +144,8 @@ static void __maestro_write(es1968_t * esm, u16 reg, u16 data)
 {
 	long ioaddr = esm->io_port;
 
-	ES_OUTW(reg, ioaddr + ESM_INDEX);
-	ES_OUTW(data, ioaddr + ESM_DATA);
+	outw(reg, ioaddr + ESM_INDEX);
+	outw(data, ioaddr + ESM_DATA);
 	esm->maestro_map[reg] = data;
 }
 
@@ -221,8 +159,8 @@ static u16 maestro_read(es1968_t * esm, u16 reg)
 		spin_lock_irqsave(&esm->reg_lock, flags);
 
 
-		ES_OUTW(reg, ioaddr + ESM_INDEX);
-		esm->maestro_map[reg] = ES_INW(ioaddr + ESM_DATA);
+		outw(reg, ioaddr + ESM_INDEX);
+		esm->maestro_map[reg] = inw(ioaddr + ESM_DATA);
 
 		spin_unlock_irqrestore(&esm->reg_lock, flags);
 	}
@@ -234,8 +172,8 @@ static u16 __maestro_read(es1968_t * esm, u16 reg)
 	long ioaddr = esm->io_port;
 
 	if (READABLE_MAP & (1 << reg)) {
-		ES_OUTW(reg, ioaddr + ESM_INDEX);
-		esm->maestro_map[reg] = ES_INW(ioaddr + ESM_DATA);
+		outw(reg, ioaddr + ESM_INDEX);
+		esm->maestro_map[reg] = inw(ioaddr + ESM_DATA);
 	}
 	return esm->maestro_map[reg];
 }
@@ -251,21 +189,17 @@ static void snd_es1968_codec_write(void *private_data,
 
 	/* Wait for the codec bus to be free */
 	for (i = 0; i < 10000; i++) {
-		if (!(ES_INB(esm->io_port + AC97_STATUS) & 1))
+		if (!(inb(esm->io_port + AC97_STATUS) & 1))
 			break;
 	}
 
 	/* Write the bus */
-	ES_OUTW(val, esm->io_port + AC97_DATA);
+	outw(val, esm->io_port + AC97_DATA);
 	mdelay(1);
-	ES_OUTB(reg, esm->io_port + AC97_INDEX);
+	outb(reg, esm->io_port + AC97_INDEX);
 	mdelay(1);
 
 	spin_unlock_irqrestore(&esm->reg_lock, flags);
-
-#ifdef ESM_CDEBUG
-	snd_printk("snd_es1968_codec_write: reg:%X Val:%X\n", reg, val);
-#endif
 }
 
 static unsigned short snd_es1968_codec_read(void *private_data,
@@ -282,27 +216,25 @@ static unsigned short snd_es1968_codec_read(void *private_data,
 	/* Wait for the codec bus to be free */
 
 	for (i = 0; i < 10000; i++) {
-		if (!(ES_INB(esm->io_port + AC97_INDEX) & 1))
+		if (!(inb(esm->io_port + AC97_INDEX) & 1))
 			break;
 	}
 
-	ES_OUTB(reg | 0x80, esm->io_port + AC97_INDEX);
+	outb(reg | 0x80, esm->io_port + AC97_INDEX);
 	mdelay(1);
 
-	while (ES_INB(esm->io_port + AC97_INDEX) & 1) {
+	while (inb(esm->io_port + AC97_INDEX) & 1) {
 		sanity--;
 		if (!sanity) {
-			snd_printk("esm: ac97 codec timeout.\n");
+			snd_printk("maestro: ac97 codec timeout.\n");
 			spin_unlock_irqrestore(&esm->reg_lock, flags);
 			return 0;
 		}
 	}
-	data = ES_INW(esm->io_port + AC97_DATA);
+	data = inw(esm->io_port + AC97_DATA);
 	mdelay(1);
 	spin_unlock_irqrestore(&esm->reg_lock, flags);
-#ifdef ESM_CDEBUG
-	snd_printk("snd_es1968_codec_read: reg:%X Val:%x\n", reg, data);
-#endif
+
 	return data;
 }
 
@@ -338,7 +270,7 @@ static void apu_set_register(es1968_t * esm, u16 channel, u8 reg, u16 data)
 
 	if (channel >= NR_APUS) {
 #ifdef ESM_EDEBUG
-		snd_printk("BAD CHANNEL %d.\n", channel);
+		snd_printk("maestro: BAD CHANNEL %d (Please report this!).\n", channel);
 #endif
 		return;
 	}
@@ -360,7 +292,7 @@ static u16 apu_get_register(es1968_t * esm, u16 channel, u8 reg)
 
 	if (channel >= NR_APUS) {
 #ifdef ESM_EDEBUG
-		snd_printk("BAD CHANNEL %d.\n", channel);
+		snd_printk("maestro: BAD CHANNEL %d (Please report this!).\n", channel);
 #endif
 		return 0;
 	}
@@ -384,8 +316,8 @@ static void assp_set_register(es1968_t * esm, u32 reg, u32 value)
 
 	spin_lock_irqsave(&esm->reg_lock, flags);
 
-	ES_OUTL(reg, esm->io_port + ASSP_INDEX);
-	ES_OUTL(value, esm->io_port + ASSP_DATA);
+	outl(reg, esm->io_port + ASSP_INDEX);
+	outl(value, esm->io_port + ASSP_DATA);
 
 	spin_unlock_irqrestore(&esm->reg_lock, flags);
 }
@@ -414,23 +346,12 @@ static void wave_set_register(es1968_t * esm, u16 reg, u16 value)
 
 	spin_lock_irqsave(&esm->reg_lock, flags);
 
-	ES_OUTW(reg, ioaddr + WC_INDEX);
-	ES_OUTW(value, ioaddr + WC_DATA);
+	outw(reg, ioaddr + WC_INDEX);
+	outw(value, ioaddr + WC_DATA);
 
 	spin_unlock_irqrestore(&esm->reg_lock, flags);
 }
 
-#if 0
-static void __wave_set_register(es1968_t * esm, u16 reg, u16 value)
-{
-	long ioaddr = esm->io_port;
-
-	ES_OUTW(reg, ioaddr + WC_INDEX);
-	ES_OUTW(value, ioaddr + WC_DATA);
-}
-
-#endif
-
 static u16 wave_get_register(es1968_t * esm, u16 reg)
 {
 	long ioaddr = esm->io_port;
@@ -439,28 +360,14 @@ static u16 wave_get_register(es1968_t * esm, u16 reg)
 
 	spin_lock_irqsave(&esm->reg_lock, flags);
 
-	ES_OUTW(reg, ioaddr + WC_INDEX);
-	value = ES_INW(ioaddr + WC_DATA);
+	outw(reg, ioaddr + WC_INDEX);
+	value = inw(ioaddr + WC_DATA);
 
 	spin_unlock_irqrestore(&esm->reg_lock, flags);
 
 	return value;
 }
 
-#if 0
-static u16 __wave_get_register(es1968_t * esm, u16 reg)
-{
-	long ioaddr = esm->io_port;
-	u16 value;
-
-	ES_OUTW(reg, ioaddr + WC_INDEX);
-	value = ES_INW(ioaddr + WC_DATA);
-
-	return value;
-}
-
-#endif
-
 /* *******************
    * Bob the Timer!  *
    *******************/
@@ -477,7 +384,6 @@ static void esm_bob_stop(es1968_t * esm)
 	maestro_write(esm, 0x17, reg);
 }
 
-#define ESS_SYSCLK	50000000
 static void esm_bob_start(es1968_t * esm)
 {
 	int prescale;
@@ -593,8 +499,8 @@ static u32 compute_rate(es1968_t * esm, u32 freq)
 		break;
 	default:
 		clock = ESM_FREQ_ESM2E;
-#ifdef ESM_EDBUG
-		snd_printk("compute_rate: Wrong Soundcard Type!\n");
+#ifdef ESM_EDEBUG
+		snd_printk("maestro: wrong typ in compute_rate (please report!)\n");
 #endif
 	}
 
@@ -637,7 +543,7 @@ static void set_dac_rate(esschanp_t * es, unsigned rate)
 	if (rate < 4000)
 		rate = 4000;
 
-	if (!(es->fmt & ESS_CFMT_16BIT) && !(es->fmt & ESS_CFMT_STEREO))
+	if (!(es->fmt & ESS_FMT_16BIT) && !(es->fmt & ESS_FMT_STEREO))
 		rate >>= 1;
 
 	freq = compute_rate(es->card, rate);
@@ -663,9 +569,6 @@ static void set_adc_rate(esschanc_t * es, unsigned rate)
 	if (rate < 4000)
 		rate = 4000;
 
-	if (es->fmt & ESS_CFMT_STEREO)
-		rate >>= 1;
-
 	freq = compute_rate(es->card, rate);
 
 	/* Load the frequency, turn on 6dB */
@@ -703,7 +606,7 @@ extern void stop_dac(esschanp_t * es)
 	apu_set_register(es->card, es->apu[0], 0,
 			 apu_get_register(es->card, es->apu[0],
 					  0) & 0xFF0F);
-	if (es->fmt & ESS_CFMT_STEREO)
+	if (es->fmt & ESS_FMT_STEREO)
 		apu_set_register(es->card, es->apu[1], 0,
 				 apu_get_register(es->card, es->apu[1],
 						  0) & 0xFF0F);
@@ -745,7 +648,7 @@ static void start_dac(esschanp_t * es)
 		apu_set_register(es->card, es->apu[0], 0,
 				 (apu_get_register(es->card, es->apu[0], 0)
 				  & 0xFF0F) | es->apu_mode[0]);
-		if (es->fmt & ESS_CFMT_STEREO)
+		if (es->fmt & ESS_FMT_STEREO)
 			apu_set_register(es->card, es->apu[1], 0,
 					 (apu_get_register(es->card,
 							   es->apu[1],
@@ -768,7 +671,7 @@ static void start_adc(esschanc_t * es)
 			 (apu_get_register(es->card, es->apu[2], 0) &
 			  0xFF0F) | es->apu_mode[2]);
 
-	if (es->fmt & ESS_CFMT_STEREO) {
+	if (es->fmt & ESS_FMT_STEREO) {
 		apu_set_register(es->card, es->apu[1], 0,
 				 (apu_get_register(es->card, es->apu[0], 0)
 				  & 0xFF0F) | es->apu_mode[0]);
@@ -790,8 +693,7 @@ static void set_base_registers(es1968_t * esm, void *vaddr)
 #endif
 }
 
-static void ess_play_setup(esschanp_t * es, int mode, u32 rate,
-			   void *buffer)
+static void ess_play_setup(esschanp_t * es, u32 rate, void *buffer)
 {
 	u32 pa;
 	u32 tmpval;
@@ -801,14 +703,10 @@ static void ess_play_setup(esschanp_t * es, int mode, u32 rate,
 	unsigned long flags;
 	es1968_t *esm = es->card;
 
-	es->fmt = mode;
-
-	spin_lock_irqsave(&esm->reg_lock, flags);
-
 	/* all maestro sizes are in 16bit words */
 	size >>= 1;
 
-	if (mode & ESS_CFMT_STEREO) {
+	if (es->fmt & ESS_FMT_STEREO) {
 		high_apu++;
 		size >>= 1;
 	}
@@ -818,9 +716,9 @@ static void ess_play_setup(esschanp_t * es, int mode, u32 rate,
 
 		tmpval = (pa - 0x10) & 0xFFF8;
 
-		if (!(mode & ESS_CFMT_16BIT))
+		if (!(es->fmt & ESS_FMT_16BIT))
 			tmpval |= 4;	/* 8bit */
-		if (mode & ESS_CFMT_STEREO)
+		if (es->fmt & ESS_FMT_STEREO)
 			tmpval |= 2;	/* stereo */
 
 		/* set the wavecache control reg */
@@ -837,7 +735,7 @@ static void ess_play_setup(esschanp_t * es, int mode, u32 rate,
 
 		pa |= 0x00400000;	/* System RAM (Bit 22) */
 
-		if ((mode & ESS_CFMT_STEREO) && (mode & ESS_CFMT_16BIT)) {
+		if ((es->fmt & ESS_FMT_STEREO) && (es->fmt & ESS_FMT_16BIT)) {
 			/* Enable stereo */
 			if (!channel)
 				pa |= 0x00800000;	/* (Bit 23) */
@@ -865,8 +763,8 @@ static void ess_play_setup(esschanp_t * es, int mode, u32 rate,
 		if (channel) {
 			apu_set_register(esm, es->apu[channel], 7,
 					 size - 1);
-		} else if (!(mode & ESS_CFMT_16BIT)
-			   || !(mode & ESS_CFMT_STEREO)) {
+		} else if (!(es->fmt & ESS_FMT_16BIT)
+			   || !(es->fmt & ESS_FMT_STEREO)) {
 			apu_set_register(esm, es->apu[channel], 7,
 					 size - 1);
 		} else
@@ -883,12 +781,12 @@ static void ess_play_setup(esschanp_t * es, int mode, u32 rate,
 		/* dma on, no envelopes, filter to all 1s) */
 		apu_set_register(esm, es->apu[channel], 0, 0x400F);
 
-		if (mode & ESS_CFMT_16BIT)
+		if (es->fmt & ESS_FMT_16BIT)
 			es->apu_mode[channel] = 0x10;
 		else
 			es->apu_mode[channel] = 0x30;
 
-		if (mode & ESS_CFMT_STEREO) {
+		if (es->fmt & ESS_FMT_STEREO) {
 			/* set panning: left or right */
 			/* Check: different panning. On my Canyon 3D Chipset the
 			   Channels are swapped. I don't know, about the output
@@ -901,37 +799,36 @@ static void ess_play_setup(esschanp_t * es, int mode, u32 rate,
 			apu_set_register(esm, es->apu[channel], 10,
 					 0x8F08);
 	}
+
+	spin_lock_irqsave(&esm->reg_lock, flags);
 	/* clear WP interupts */
-	ES_OUTW(1, esm->io_port + 0x04);
+	outw(1, esm->io_port + 0x04);
 	/* enable WP ints */
-	ES_OUTW(ES_INW(esm->io_port + 0x18) | 4, esm->io_port + 0x18);
+	outw(inw(esm->io_port + 0x18) | 4, esm->io_port + 0x18);
+	spin_unlock_irqrestore(&esm->reg_lock, flags);
 
 	set_dac_rate(es, rate);
-	spin_unlock_irqrestore(&esm->reg_lock, flags);
 }
 
-static void ess_rec_setup(esschanc_t * es, int mode, u32 rate,
-			  void *buffer)
+static void ess_rec_setup(esschanc_t * es, u32 rate, void *buffer)
 {
 	int apu_step = 2;
 	int channel;
         int size=es->transs;
+	int i;
 	unsigned long flags;
         es1968_t *esm = es->card;
 
-	snd_printk
+	snd_printd
 	    ("maestro: ess_rec_setup: mode=%d rate=%d buf=0x%p len=%d.\n",
-	     mode, rate, buffer, size);
-
-	spin_lock_irqsave(&esm->reg_lock, flags);
+	     es->fmt, rate, buffer, size);
 
 	/* all maestro sizes are in 16bit words */
 	size >>= 1;
 
 	/* we're given the full size of the buffer, but
 	   in stereo each channel will only use its half */
-	if (mode & ESS_CFMT_STEREO) {
-		snd_printk("RecStereo Mode!\n");
+	if (es->fmt & ESS_FMT_STEREO) {
 		size >>= 1;
 		apu_step = 1;
 	}
@@ -956,17 +853,19 @@ static void ess_rec_setup(esschanc_t * es, int mode, u32 rate,
 			if (!(channel & 0x01)) {
 				pa = virt_to_bus(es->mixbuf);
 			} else {
-				pa = virt_to_bus(es->mixbuf + (size * 2));
+				pa = virt_to_bus(es->mixbuf + size * 2);
 			}
 
 			/* we source from a 'magic' apu */
-			bsize = size;	/* half of this channels alloc, in words */
+			bsize = size >> 1;/* half of this channels alloc, in words */
 			route = 0x14 /*+ es->apu[channel - 2] */ ;	/* parallel in crap, see maestro reg 0xC [8-11] */
 			es->apu_mode[channel] = 0x90;	/* Input Mixer */
+#ifdef ESM_DDEBUG
 			snd_printk
 			    ("Set Input Mixer: Apu:%d Mode:%x Route:%x\n",
 			     es->apu[channel], es->apu_mode[channel],
 			     route);
+#endif
 		} else {
 			/* we're a rate converter taking
 			   input from the input apus and outputing it to
@@ -976,31 +875,31 @@ static void ess_rec_setup(esschanc_t * es, int mode, u32 rate,
 			} else {
 				/* right channel records its split half.
 				   *2 accomodates for rampant shifting earlier */
-#if 1
-				pa = virt_to_bus(buffer);
-#else
 				pa = virt_to_bus(buffer + size * 2);
-#endif
 			}
 
 			es->apu_mode[channel] = 0xB0;	/* Sample Rate Converter */
 
-			bsize = size * 2;
+			bsize = size;
 			/* get input from inputing apu */
 			route = es->apu[channel + 2];
+#ifdef ESM_DDEBUG
 			snd_printk
 			    ("Set Rate Converter: Apu:%d Mode:%x Route:%x\n",
 			     es->apu[channel], es->apu_mode[channel],
 			     route);
+#endif
 		}
 
+#ifdef ESM_DDEBUG
 		snd_printk("maestro: ess_rec_setup: getting pa 0x%x from %d\n", pa, channel);
+#endif
 
 		/* set the wavecache control reg */
 		tmpval = (pa - 0x10) & 0xFFF8;
-		if (!(mode & ESS_CFMT_16BIT))
+		if (!(es->fmt & ESS_FMT_16BIT))
 			tmpval |= 4;
-		if (mode & ESS_CFMT_STEREO)
+		if (es->fmt & ESS_FMT_STEREO)
 			tmpval |= 2;
 		wave_set_register(esm, es->apu[channel] << 3, tmpval);
 
@@ -1014,26 +913,20 @@ static void ess_rec_setup(esschanc_t * es, int mode, u32 rate,
 			es->base = pa & 0xFFFF;
 
 		pa |= 0x00400000;	/* bit 22 -> System RAM */
-		if (mode & ESS_CFMT_STEREO) {
-			if (channel == 1)
-				pa |= 0x00800000;	/* Stereo */
-			pa >>= 1;
-		}
 
+#ifdef ESM_DDEBUG
 		snd_printk
 		    ("maestro: ess_rec_setup: APU[%d] pa = 0x%x size = 0x%x route = 0x%x\n",
 		     es->apu[channel], pa, bsize, route);
-
-		/* Disable APU */
-		apu_set_register(esm, es->apu[channel], 0, 0x0000);
+#endif
+                     
+                /* Begin loading the APU */
+                for (i=0;i<15;i++)
+                   	apu_set_register(esm,es->apu[channel],i,0x0000);
 
 		/* need to enable subgroups.. and we should probably
 		   have different groups for different /dev/dsps..  */
-#if 0
 		apu_set_register(esm, es->apu[channel], 2, 0x8);
-#else
-		apu_set_register(esm, es->apu[channel], 2, 0x0000);
-#endif
 
 		/* Load the buffer into the wave engine */
 		apu_set_register(esm, es->apu[channel], 4,
@@ -1044,7 +937,7 @@ static void ess_rec_setup(esschanc_t * es, int mode, u32 rate,
 				 (pa + bsize) & 0xFFFF);
 
 #if 1
-		if (!(mode & ESS_CFMT_16BIT) || !(mode & ESS_CFMT_STEREO)) {
+		if ( es->fmt & ESS_FMT_STEREO ) {
 			apu_set_register(esm, es->apu[channel], 7,
 					 bsize - 1);
 		} else
@@ -1066,14 +959,15 @@ static void ess_rec_setup(esschanc_t * es, int mode, u32 rate,
 		apu_set_register(esm, es->apu[channel], 0, 0x400F);
 	}
 
+	spin_lock_irqsave(&esm->reg_lock, flags);
 	/* clear WP interupts */
-	ES_OUTW(1, esm->io_port + 0x04);
+	outw(1, esm->io_port + 0x04);
 	/* enable WP ints */
-	ES_OUTW(ES_INW(esm->io_port + 0x18) | 4, esm->io_port + 0x18);
+	outw(inw(esm->io_port + 0x18) | 4, esm->io_port + 0x18);
+	spin_unlock_irqrestore(&esm->reg_lock, flags);
 
 	/* let 'er rip */
 	set_adc_rate(es, rate);
-	spin_unlock_irqrestore(&esm->reg_lock, flags);
 }
 
 /*******************
@@ -1103,7 +997,6 @@ static int snd_es1968_playback_prepare(void *private_data,
 	esschanp_t *es = snd_magic_cast(esschanp_t, runtime->private_data, -ENXIO);
 	unsigned int realrate;
 	char *buffer;
-	int fmt;
 
 	es->transs = snd_pcm_lib_transfer_size(subchn);
 	es->transf = snd_pcm_lib_transfer_fragment(subchn);
@@ -1111,21 +1004,21 @@ static int snd_es1968_playback_prepare(void *private_data,
 	realrate = runtime->format.rate;
 	buffer = runtime->dma_area->buf;
 
-	fmt = 0;
+	es->fmt = 0;
 	if (snd_pcm_format_width(runtime->format.format) == 16)
-		fmt |= ESS_CFMT_16BIT;
+		es->fmt |= ESS_FMT_16BIT;
 	if (runtime->format.voices > 1)
-		fmt |= ESS_CFMT_STEREO;
+		es->fmt |= ESS_FMT_STEREO;
 
 	stop_dac(es);
-	ess_play_setup(es, fmt, realrate, buffer);
+	ess_play_setup(es, realrate, buffer);
 
 #ifdef ESM_DDEBUG
 	snd_printk("snd_es1968_playback_prepare Voices:%d Mode:%d!\n",
 		   runtime->format.voices,
 		   snd_pcm_format_width(runtime->format.format));
 	snd_printk("Fmt: %d Rate: %d Buffer: %p Size: %d Fragment: %d\n",
-		   fmt, realrate, buffer, es->transs, es->transf);
+		   es->fmt, realrate, buffer, es->transs, es->transf);
 #endif
 
 	return 0;
@@ -1138,7 +1031,6 @@ static int snd_es1968_capture_prepare(void *private_data,
 	esschanc_t *es = snd_magic_cast(esschanc_t, runtime->private_data, -ENXIO);
 	unsigned int realrate;
 	char *buffer;
-	int fmt;
 
 	es->transs = snd_pcm_lib_transfer_size(subchn);
 	es->transf = snd_pcm_lib_transfer_fragment(subchn);
@@ -1146,21 +1038,21 @@ static int snd_es1968_capture_prepare(void *private_data,
 	realrate = runtime->format.rate;
 	buffer = runtime->dma_area->buf;
 
-	fmt = 0;
+	es->fmt = 0;
 	if (snd_pcm_format_width(runtime->format.format) == 16)
-		fmt |= ESS_CFMT_16BIT;
+		es->fmt |= ESS_FMT_16BIT;
 	if (runtime->format.voices > 1)
-		fmt |= ESS_CFMT_STEREO;
+		es->fmt |= ESS_FMT_STEREO;
 
 	stop_adc(es);
-	ess_rec_setup(es, fmt, realrate, buffer);
+	ess_rec_setup(es, realrate, buffer);
 
 #ifdef ESM_DDEBUG
 	snd_printk("snd_es1968_capture_prepare Voices:%d Mode:%d!\n",
 		   runtime->format.voices,
 		   snd_pcm_format_width(runtime->format.format));
 	snd_printk("Fmt: %d Rate: %d Buffer: %p Size: %d Fragment: %d\n",
-		   fmt, realrate, buffer, es->transs, es->transf);
+		   es->fmt, realrate, buffer, es->transs, es->transf);
 #endif
 
 	return 0;
@@ -1216,8 +1108,8 @@ static unsigned int snd_es1968_playback_pointer(void *private_data,
 
 	ptr = get_dmaa(es);
 
-	if ((es->fmt & ESS_CFMT_MASK) ==
-	    (ESS_CFMT_STEREO | ESS_CFMT_16BIT)) ptr <<= 1;
+	if ( (es->fmt & ESS_FMT_STEREO) && (es->fmt & ESS_FMT_16BIT) )
+           ptr <<= 1;
 
 	return (subchn->runtime->buf_position + es->count) % es->transs;
 }
@@ -1230,14 +1122,59 @@ static unsigned int snd_es1968_capture_pointer(void *private_data,
 
 	ptr = get_dmac(es);
 
-#if 1
-	if ((es->fmt & ESS_CFMT_MASK) ==
-	    (ESS_CFMT_STEREO | ESS_CFMT_16BIT)) ptr <<= 1;
-#endif
+	if ( (es->fmt & ESS_FMT_STEREO) && (es->fmt & ESS_FMT_16BIT) )
+           ptr <<= 1;
 
 	return (subchn->runtime->buf_position + es->count) % es->transs;
 }
 
+#if 0
+#if 0
+static int snd_es1968_capture_memcpy(snd_pcm_substream_t *substream, int voice, unsigned int pos,
+   					 void *buf, size_t count)
+{
+   	unsigned char *combbuf;
+       	unsigned char *so,*left,*right;
+        int i;
+   
+	if (substream->runtime->format.voices > 1) {
+           	if ( !(combbuf=snd_kmalloc (count,GFP_KERNEL)) )
+                 return -ENOMEM;
+
+	       so = combbuf;
+	       left = substream->runtime->dma_area->buf + pos;
+               right = substream->runtime->dma_area->buf + (substream->runtime->dma_area->size/2) + pos;
+
+               for(i=count/4; i ; i--) {
+                  (*(so+2)) = *(right++);
+                  (*(so+3)) = *(right++);
+                  (*so) = *(left++);
+                  (*(so+1)) = *(left++);
+                  so+=4;
+               }
+               
+               i=copy_to_user (buf,combbuf,count);
+               
+               snd_kfree(combbuf);
+               
+               return i;
+        } else {
+               return copy_to_user (buf,substream->runtime->dma_area->buf+pos,count);
+        }
+}
+#else
+static int snd_es1968_capture_memcpy(snd_pcm_substream_t *substream, int voice, unsigned int pos,
+   					 void *buf, size_t count)
+{
+   	if (voice==1)
+          return copy_to_user (buf,substream->runtime->dma_area->buf
+           + (substream->runtime->dma_area->size/2) + pos,count);
+        else
+          return copy_to_user (buf,substream->runtime->dma_area->buf+pos,count);
+}
+#endif
+#endif
+
 static snd_pcm_hardware_t snd_es1968_playback = {
 	SND_PCM_CHNINFO_MMAP | SND_PCM_CHNINFO_STREAM |
 	    SND_PCM_CHNINFO_BLOCK | SND_PCM_CHNINFO_INTERLEAVE |
@@ -1266,7 +1203,7 @@ static snd_pcm_hardware_t snd_es1968_capture = {
 	    SND_PCM_CHNINFO_BLOCK_TRANSFER
 	    /*SND_PCM_CHNINFO_MMAP_VALID */ ,
 	/* flags */
-	SND_PCM_FMT_U8 | SND_PCM_FMT_S16_LE,	/* hardware formats */
+	/*SND_PCM_FMT_U8 |*/ SND_PCM_FMT_S16_LE,	/* hardware formats */
 	SND_PCM_RATE_CONTINUOUS | SND_PCM_RATE_8000_48000,	/* supported Rate */
 	4000,			/* min. rate */
 	48000,			/* max. rate */
@@ -1293,7 +1230,7 @@ static void snd_es1968_pcmp_free_subchn(void *private_data)
 		/* Free APUs */
 		esm->apu[es->apu[0]] = free;
 		esm->apu[es->apu[1]] = free;
-		snd_kfree(es);
+		snd_magic_kfree(es);
 	}
 }
 
@@ -1309,7 +1246,7 @@ static void snd_es1968_pcmc_free_subchn(void *private_data)
 		esm->apu[es->apu[1]] = free;
 		esm->apu[es->apu[2]] = free;
 		esm->apu[es->apu[3]] = free;
-		snd_kfree(es);
+		snd_magic_kfree(es);
 	}
 }
 
@@ -1429,7 +1366,7 @@ void snd_es1968_back_dmabuf(es1968_t * esm, char *buf)
 	} else {
 		o->next = p->next;
 	}
-	snd_kfree(esd);
+	snd_magic_kfree(esd);
 	return;
 }
 
@@ -1909,70 +1846,70 @@ static void snd_es1968_ac97_reset(es1968_t * esm)
 	unsigned short w;
 	unsigned int vend;
 
-	ES_OUTW(ES_INW(ioaddr + 0x38) & 0xfffc, ioaddr + 0x38);
-	ES_OUTW(ES_INW(ioaddr + 0x3a) & 0xfffc, ioaddr + 0x3a);
-	ES_OUTW(ES_INW(ioaddr + 0x3c) & 0xfffc, ioaddr + 0x3c);
+	outw(inw(ioaddr + 0x38) & 0xfffc, ioaddr + 0x38);
+	outw(inw(ioaddr + 0x3a) & 0xfffc, ioaddr + 0x3a);
+	outw(inw(ioaddr + 0x3c) & 0xfffc, ioaddr + 0x3c);
 
 	/* reset the first codec */
-	ES_OUTW(0x0000, ioaddr + 0x36);
-	save_68 = ES_INW(ioaddr + 0x68);
+	outw(0x0000, ioaddr + 0x36);
+	save_68 = inw(ioaddr + 0x68);
 	pci_read_config_word(esm->pci, 0x58, &w);	/* something magical with gpio and bus arb. */
 	pci_read_config_dword(esm->pci, PCI_SUBSYSTEM_VENDOR_ID, &vend);
 	if (w & 1)
 		save_68 |= 0x10;
-	ES_OUTW(0xfffe, ioaddr + 0x64);	/* tickly gpio 0.. */
-	ES_OUTW(0x0001, ioaddr + 0x68);
-	ES_OUTW(0x0000, ioaddr + 0x60);
+	outw(0xfffe, ioaddr + 0x64);	/* tickly gpio 0.. */
+	outw(0x0001, ioaddr + 0x68);
+	outw(0x0000, ioaddr + 0x60);
 	udelay(20);
-	ES_OUTW(0x0001, ioaddr + 0x60);
+	outw(0x0001, ioaddr + 0x60);
 	mdelay(20);
 
-	ES_OUTW(save_68 | 0x1, ioaddr + 0x68);	/* now restore .. */
-	ES_OUTW((ES_INW(ioaddr + 0x38) & 0xfffc) | 0x1, ioaddr + 0x38);
-	ES_OUTW((ES_INW(ioaddr + 0x3a) & 0xfffc) | 0x1, ioaddr + 0x3a);
-	ES_OUTW((ES_INW(ioaddr + 0x3c) & 0xfffc) | 0x1, ioaddr + 0x3c);
+	outw(save_68 | 0x1, ioaddr + 0x68);	/* now restore .. */
+	outw((inw(ioaddr + 0x38) & 0xfffc) | 0x1, ioaddr + 0x38);
+	outw((inw(ioaddr + 0x3a) & 0xfffc) | 0x1, ioaddr + 0x3a);
+	outw((inw(ioaddr + 0x3c) & 0xfffc) | 0x1, ioaddr + 0x3c);
 
 	/* now the second codec */
-	ES_OUTW(0x0000, ioaddr + 0x36);
-	ES_OUTW(0xfff7, ioaddr + 0x64);
-	save_68 = ES_INW(ioaddr + 0x68);
-	ES_OUTW(0x0009, ioaddr + 0x68);
-	ES_OUTW(0x0001, ioaddr + 0x60);
+	outw(0x0000, ioaddr + 0x36);
+	outw(0xfff7, ioaddr + 0x64);
+	save_68 = inw(ioaddr + 0x68);
+	outw(0x0009, ioaddr + 0x68);
+	outw(0x0001, ioaddr + 0x60);
 	udelay(20);
-	ES_OUTW(0x0009, ioaddr + 0x60);
+	outw(0x0009, ioaddr + 0x60);
 	mdelay(500);		/* .. ouch.. */
-	ES_OUTW(ES_INW(ioaddr + 0x38) & 0xfffc, ioaddr + 0x38);
-	ES_OUTW(ES_INW(ioaddr + 0x3a) & 0xfffc, ioaddr + 0x3a);
-	ES_OUTW(ES_INW(ioaddr + 0x3c) & 0xfffc, ioaddr + 0x3c);
+	outw(inw(ioaddr + 0x38) & 0xfffc, ioaddr + 0x38);
+	outw(inw(ioaddr + 0x3a) & 0xfffc, ioaddr + 0x3a);
+	outw(inw(ioaddr + 0x3c) & 0xfffc, ioaddr + 0x3c);
 
 #if 0				/* the loop here needs to be much better if we want it.. */
 	snd_printk("trying software reset\n");
 	/* try and do a software reset */
-	ES_OUTB(0x80 | 0x7c, ioaddr + 0x30);
+	outb(0x80 | 0x7c, ioaddr + 0x30);
 	for (w = 0;; w++) {
-		if ((ES_INW(ioaddr + 0x30) & 1) == 0) {
-			if (ES_INB(ioaddr + 0x32) != 0)
+		if ((inw(ioaddr + 0x30) & 1) == 0) {
+			if (inb(ioaddr + 0x32) != 0)
 				break;
 
-			ES_OUTB(0x80 | 0x7d, ioaddr + 0x30);
-			if (((ES_INW(ioaddr + 0x30) & 1) == 0)
-			    && (ES_INB(ioaddr + 0x32) != 0))
+			outb(0x80 | 0x7d, ioaddr + 0x30);
+			if (((inw(ioaddr + 0x30) & 1) == 0)
+			    && (inb(ioaddr + 0x32) != 0))
 				break;
-			ES_OUTB(0x80 | 0x7f, ioaddr + 0x30);
-			if (((ES_INW(ioaddr + 0x30) & 1) == 0)
-			    && (ES_INB(ioaddr + 0x32) != 0))
+			outb(0x80 | 0x7f, ioaddr + 0x30);
+			if (((inw(ioaddr + 0x30) & 1) == 0)
+			    && (inb(ioaddr + 0x32) != 0))
 				break;
 		}
 
 		if (w > 10000) {
-			ES_OUTB(ES_INB(ioaddr + 0x37) | 0x08, ioaddr + 0x37);	/* do a software reset */
+			outb(inb(ioaddr + 0x37) | 0x08, ioaddr + 0x37);	/* do a software reset */
 			mdelay(500);	/* oh my.. */
-			ES_OUTB(ES_INB(ioaddr + 0x37) & ~0x08,
+			outb(inb(ioaddr + 0x37) & ~0x08,
 				ioaddr + 0x37);
 			udelay(1);
-			ES_OUTW(0x80, ioaddr + 0x30);
+			outw(0x80, ioaddr + 0x30);
 			for (w = 0; w < 10000; w++) {
-				if ((ES_INW(ioaddr + 0x30) & 1) == 0)
+				if ((inw(ioaddr + 0x30) & 1) == 0)
 					break;
 			}
 		}
@@ -1980,9 +1917,9 @@ static void snd_es1968_ac97_reset(es1968_t * esm)
 #endif
 	if (vend == NEC_VERSA_SUBID1 || vend == NEC_VERSA_SUBID2) {
 		/* turn on external amp? */
-		ES_OUTW(0xf9ff, ioaddr + 0x64);
-		ES_OUTW(ES_INW(ioaddr + 0x68) | 0x600, ioaddr + 0x68);
-		ES_OUTW(0x0209, ioaddr + 0x60);
+		outw(0xf9ff, ioaddr + 0x64);
+		outw(inw(ioaddr + 0x68) | 0x600, ioaddr + 0x68);
+		outw(0x0209, ioaddr + 0x60);
 	}
 }
 
@@ -2027,45 +1964,45 @@ static void snd_es1968_ringbus_setup(es1968_t * esm)
 
 	/* Ring Bus Control A */
 
-	n = ES_INL(iobase + 0x34);
+	n = inl(iobase + 0x34);
 	n &= ~0xF000;
 	n |= 12 << 12;		/* Direct Sound, Stereo */
-	ES_OUTL(n, iobase + 0x34);
+	outl(n, iobase + 0x34);
 
-	n = ES_INL(iobase + 0x34);
+	n = inl(iobase + 0x34);
 	n &= ~0x0F00;		/* Modem off */
-	ES_OUTL(n, iobase + 0x34);
+	outl(n, iobase + 0x34);
 
-	n = ES_INL(iobase + 0x34);
+	n = inl(iobase + 0x34);
 	n &= ~0x00F0;
 	n |= 9 << 4;		/* DAC, Stereo */
-	ES_OUTL(n, iobase + 0x34);
+	outl(n, iobase + 0x34);
 
-	n = ES_INL(iobase + 0x34);
+	n = inl(iobase + 0x34);
 	n &= ~0x000F;		/* ASSP off */
-	ES_OUTL(n, iobase + 0x34);
+	outl(n, iobase + 0x34);
 
-	n = ES_INL(iobase + 0x34);
+	n = inl(iobase + 0x34);
 	n |= (1 << 29);		/* Enable ring bus */
-	ES_OUTL(n, iobase + 0x34);
+	outl(n, iobase + 0x34);
 
-	n = ES_INL(iobase + 0x34);
+	n = inl(iobase + 0x34);
 	n |= (1 << 28);		/* Enable serial bus */
-	ES_OUTL(n, iobase + 0x34);
+	outl(n, iobase + 0x34);
 
-	n = ES_INL(iobase + 0x34);
+	n = inl(iobase + 0x34);
 	n &= ~0x00F00000;	/* MIC off */
-	ES_OUTL(n, iobase + 0x34);
+	outl(n, iobase + 0x34);
 
-	n = ES_INL(iobase + 0x34);
+	n = inl(iobase + 0x34);
 	n &= ~0x000F0000;	/* I2S off */
-	ES_OUTL(n, iobase + 0x34);
+	outl(n, iobase + 0x34);
 
 	/* Ring Bus Control B */
 
-	n = ES_INL(iobase + 0x38);
+	n = inl(iobase + 0x38);
 	n &= ~RINGB_EN_SPDIF;	/* SPDIF off */
-	ES_OUTL(n, iobase + 0x38);
+	outl(n, iobase + 0x38);
 
 	/* Enable IRQ's */
 
@@ -2074,16 +2011,16 @@ static void snd_es1968_ringbus_setup(es1968_t * esm)
 	else
 		w = ESM_HIRQ_DSIE;
 
-	ES_OUTW(w, esm->io_port + ESM_PORT_HOST_IRQ);
+	outw(w, esm->io_port + ESM_PORT_HOST_IRQ);
 }
 
 static void snd_es1968_reset(es1968_t * esm)
 {
 	/* Reset */
-	ES_OUTW(ESM_RESET_MAESTRO | ESM_RESET_DIRECTSOUND,
+	outw(ESM_RESET_MAESTRO | ESM_RESET_DIRECTSOUND,
 		esm->io_port + ESM_PORT_HOST_IRQ);
 	udelay(10);
-	ES_OUTW(0x0000, esm->io_port + ESM_PORT_HOST_IRQ);
+	outw(0x0000, esm->io_port + ESM_PORT_HOST_IRQ);
 	udelay(10);
 }
 
@@ -2092,6 +2029,12 @@ static void snd_es1968_reset(es1968_t * esm)
 void esmst_set(es1968_t * s);
 #endif
 
+int snd_es1968_free(es1968_t * esm)
+{
+	snd_magic_kfree(esm);
+	return 0;
+}
+
 int snd_es1968_create(snd_card_t * card,
 		      struct pci_dev *pci,
 		      snd_dma_t * dma1ptr,
@@ -2100,8 +2043,13 @@ int snd_es1968_create(snd_card_t * card,
 		      int gesbuf, int pcmp, int pcmc, es1968_t ** resm)
 {
 	es1968_t *esm;
-	int i;
+	int i, err;
 	u16 w;
+	static snd_device_ops_t ops = {
+		(snd_dev_free_t *)snd_es1968_free,
+		NULL,
+		NULL
+	};
 
 	*resm = NULL;
 
@@ -2139,6 +2087,9 @@ int snd_es1968_create(snd_card_t * card,
 	esm->firstbuf = NULL;
 	esm->bufs = NULL;
 
+	/* just to be sure */
+	pci_set_master(pci);
+
 	/* PCI Config Regs */
 
 #ifdef ESM_DDEBUG
@@ -2224,19 +2175,19 @@ int snd_es1968_create(snd_card_t * card,
 	/* it appears some maestros (dell 7500) only work if these are set,
 	   regardless of wether we use the assp or not. */
 
-	ES_OUTB(0, esm->io_port + ASSP_CONTROL_B);
-	ES_OUTB(3, esm->io_port + ASSP_CONTROL_A);	/* M: Reserved bits... */
-	ES_OUTB(0, esm->io_port + ASSP_CONTROL_C);	/* M: Disable ASSP, ASSP IRQ's and FM Port */
+	outb(0, esm->io_port + ASSP_CONTROL_B);
+	outb(3, esm->io_port + ASSP_CONTROL_A);	/* M: Reserved bits... */
+	outb(0, esm->io_port + ASSP_CONTROL_C);	/* M: Disable ASSP, ASSP IRQ's and FM Port */
 
 	for (i = 0; i < 16; i++) {
 		/* Write 0 into the buffer area 0x1E0->1EF */
-		ES_OUTW(0x01E0 + i, esm->io_port + WC_INDEX);
-		ES_OUTW(0x0000, esm->io_port + WC_DATA);
+		outw(0x01E0 + i, esm->io_port + WC_INDEX);
+		outw(0x0000, esm->io_port + WC_DATA);
 
 		/* The 1.10 test program seem to write 0 into the buffer area
 		 * 0x1D0-0x1DF too.*/
-		ES_OUTW(0x01D0 + i, esm->io_port + WC_INDEX);
-		ES_OUTW(0x0000, esm->io_port + WC_DATA);
+		outw(0x01D0 + i, esm->io_port + WC_INDEX);
+		outw(0x0000, esm->io_port + WC_DATA);
 	}
 	wave_set_register(esm, IDR7_WAVE_ROMRAM,
 			  (wave_get_register
@@ -2272,7 +2223,7 @@ int snd_es1968_create(snd_card_t * card,
 	/* Wave cache control on - test off, sg off, 
 	   enable, enable extra chans 1Mb */
 
-	w = ES_INW(esm->io_port + WC_CONTROL);
+	w = inw(esm->io_port + WC_CONTROL);
 
 	w &= ~0xFA00;		/* Seems to be reserved? I don't know */
 	w |= 0xA000;		/* reserved... I don't know */
@@ -2287,7 +2238,7 @@ int snd_es1968_create(snd_card_t * card,
 	/* Bit 1 is reserved */
 	w &= ~0x0001;		/* Test Mode off */
 
-	ES_OUTW(w, esm->io_port + WC_CONTROL);
+	outw(w, esm->io_port + WC_CONTROL);
 
 	/* Now clear the APU control ram */
 	for (i = 0; i < NR_APUS; i++) {
@@ -2302,18 +2253,16 @@ int snd_es1968_create(snd_card_t * card,
 	esmst_set(esm);
 #endif
 
+	if ((err = snd_device_new(card, SND_DEV_LOWLEVEL, esm, 0, &ops, NULL)) < 0) {
+		snd_es1968_free(esm);
+		return err;
+	}
+
 	*resm = esm;
 
 	return 0;
 }
 
-int snd_es1968_free(es1968_t * esm)
-{
-	snd_kfree(esm);
-
-	return 0;
-}
-
 /* *************
    * Midi Part *
    *************/
@@ -2353,8 +2302,8 @@ static void ess_update_ptrp(snd_pcm_subchn_t * subchn)
 			spin_lock(&es->reg_lock);
 			hwptr = get_dmaa(es) % es->transs;
 
-			if ((es->fmt & ESS_CFMT_MASK) ==
-			    (ESS_CFMT_STEREO | ESS_CFMT_16BIT))
+			if ((es->fmt & ESS_FMT_MASK) ==
+			    (ESS_FMT_STEREO | ESS_FMT_16BIT))
 				    hwptr <<= 1;
 
 			diff = (es->transs + hwptr - es->hwptr) % es->transs;
@@ -2362,12 +2311,14 @@ static void ess_update_ptrp(snd_pcm_subchn_t * subchn)
 			es->hwptr = hwptr;
 			es->count += diff;
 
-			if (es->count > (unsigned) es->transf) {
+			if (es->count > es->transf) {
+				spin_unlock(&es->reg_lock);
 				snd_pcm_transfer_done(subchn);	/* Update */
+				spin_lock(&es->reg_lock);
 				es->count -= es->transf;
 			}
 #ifdef ESM_EDEBUG
-			if (es->count > (signed) es->transf)
+			if (es->count > es->transf)
 
 				snd_printk
 				    ("ess_update_ptrp: IRQ to slow!\n");
@@ -2391,7 +2342,7 @@ static void ess_update_ptrc(snd_pcm_subchn_t * subchn)
 			spin_lock(&es->reg_lock);
 			hwptr = get_dmac(es) % es->transs;
 
-			if (es->fmt & ESS_CFMT_STEREO)
+			if (es->fmt & ESS_FMT_STEREO)
 				hwptr <<= 1;
 
 			diff = (es->transs + hwptr - es->hwptr) % es->transs;
@@ -2399,12 +2350,14 @@ static void ess_update_ptrc(snd_pcm_subchn_t * subchn)
 			es->hwptr = hwptr;
 			es->count += diff;
 
-			if (es->count > (unsigned) es->transf) {
+			if (es->count > es->transf) {
+				spin_unlock(&es->reg_lock);
 				snd_pcm_transfer_done(subchn);	/* Update */
+				spin_lock(&es->reg_lock);
 				es->count -= es->transf;
 			}
 #ifdef ESM_EDEBUG
-			if (es->count > (signed) es->transf)
+			if (es->count > es->transf)
 
 				snd_printk
 				    ("ess_update_ptrc: IRQ to slow!\n");
@@ -2420,11 +2373,11 @@ void snd_es1968_interrupt(es1968_t * esm)
 	snd_pcm_subchn_t *subchn;
 
 
-	if (!(event = ES_INB(esm->io_port + 0x1A))) {
+	if (!(event = inb(esm->io_port + 0x1A))) {
 		return;
 	}
 
-	ES_OUTW(ES_INW(esm->io_port + 4) & 1, esm->io_port + 4);
+	outw(inw(esm->io_port + 4) & 1, esm->io_port + 4);
 
 #ifdef ESM_IDEBUG
 	snd_printk("maestro int: %x\n", event);
@@ -2433,21 +2386,19 @@ void snd_es1968_interrupt(es1968_t * esm)
 	if (event & ESM_HWVOL_IRQ) {
 		/* XXX if we have a hw volume control int enable
 		   all the ints?  doesn't make sense.. */
-		event = ES_INW(esm->io_port + 0x18);
-		ES_OUTB(0xFF, esm->io_port + 0x1A);
+		event = inw(esm->io_port + 0x18);
+		outb(0xFF, esm->io_port + 0x1A);
 #ifdef ESM_DDEBUG
 		snd_printk("HWVol Int (Why this?) !\n");
 #endif
 	} else {
 		/* else ack 'em all, i imagine */
-		ES_OUTB(0xFF, esm->io_port + 0x1A);
+		outb(0xFF, esm->io_port + 0x1A);
 	}
 
-#ifdef ESM_MIDI
 	if (event & ESM_MPU401_IRQ) {
 		snd_mpu401_uart_interrupt(esm->rmidi);
 	}
-#endif
 
 	if (event & ESM_SOUND_IRQ) {
            	subchn = esm->pcm->chn[SND_PCM_CHANNEL_PLAYBACK].subchn;
