@@ -50,9 +50,9 @@ static inline unsigned char snd_ice1712_read(ice1712_t * ice, unsigned char addr
 	return inb(ICEREG(ice, DATA));
 }
 
-static void snd_ice1712_codec_write(void *private_data,
-				    unsigned short reg,
-				    unsigned short val)
+static void snd_ice1712_ac97_write(void *private_data,
+				   unsigned short reg,
+				   unsigned short val)
 {
 	ice1712_t *ice = (ice1712_t *)private_data;
 	int tm;
@@ -75,7 +75,7 @@ static void snd_ice1712_codec_write(void *private_data,
 			break;
 }
 
-static unsigned short snd_ice1712_codec_read(void *private_data,
+static unsigned short snd_ice1712_ac97_read(void *private_data,
 					     unsigned short reg)
 {
 	ice1712_t *ice = (ice1712_t *)private_data;
@@ -100,6 +100,44 @@ static unsigned short snd_ice1712_codec_read(void *private_data,
 	return inw(ICEREG(ice, AC97_DATA));
 }
 
+#define CODEC_A 0x40
+#define CODEC_B 0x80
+
+static void snd_ice1712_ak4524_write(ice1712_t *ice, unsigned char codecs_mask,
+				     unsigned char addr, unsigned char data)
+{
+	unsigned char tmp;
+	int idx;
+	int addrdata;
+	down(&ice->gpio_mutex);
+	tmp = snd_ice1712_read(ice, ICE1712_IREG_GPIO_DATA);
+	tmp &= ~codecs_mask;
+	snd_ice1712_write(ice, ICE1712_IREG_GPIO_DATA, tmp);
+	udelay(150);
+	addr &= 0x07;
+	addrdata = 0xa000 | (addr << 8) | data;
+	for (idx = 15; idx >= 0; idx--) {
+		tmp &= ~0x30;
+		if (addrdata & (1 << idx))
+			tmp |= 0x10;
+		snd_ice1712_write(ice, ICE1712_IREG_GPIO_DATA, tmp);
+		udelay(200);
+		tmp |= 0x20;
+		snd_ice1712_write(ice, ICE1712_IREG_GPIO_DATA, tmp);
+		/* We give the control to the scheduler every 0.6 ms */
+		if (idx % 2 == 0) {
+			set_current_state(TASK_UNINTERRUPTIBLE);
+			schedule_timeout(1);
+		} else
+			udelay(200);
+	}
+	tmp |= codecs_mask;
+	snd_ice1712_write(ice, ICE1712_IREG_GPIO_DATA, tmp);
+	udelay(150);
+	up(&ice->gpio_mutex);
+}
+
+
 static void snd_ice1712_delta_set_spdif_out(ice1712_t *ice, snd_pcm_subchn_t *subchn)
 {
 	unsigned char val, tmp;
@@ -1082,6 +1120,48 @@ static int snd_ice1712_group_pro_capture(snd_kmixer_group_t * group,
 	return change;
 }
 
+#if 0
+static int snd_ice1712_ak4524_dac_volume(snd_kmixer_element_t *element,
+					 int w_flag, int *volume,
+					 int index)
+{
+	ice1712_t *ice = snd_magic_cast(ice1712_t, element->private_data, -ENXIO);
+	int change = 0;
+	if (!w_flag) {
+		volume[0] = ice->ak4524_dac_volume[index];
+	} else {
+		change = ice->ak4524_dac_volume[index] != volume[0];
+		if (change) {
+			int codec = index / 2 == 0 ? CODEC_A : CODEC_B;
+			int addr = 6 + index % 2;
+			ice->ak4524_dac_volume[index] = volume[0];
+			snd_ice1712_ak4524_write(ice, codec, addr, volume[0]);
+		}
+	}
+	return change;
+}
+
+static int snd_ice1712_ak4524_adc_volume(snd_kmixer_element_t *element,
+					 int w_flag, int *volume,
+					 int index)
+{
+	ice1712_t *ice = snd_magic_cast(ice1712_t, element->private_data, -ENXIO);
+	int change = 0;
+	if (!w_flag) {
+		volume[0] = ice->ak4524_adc_volume[index];
+	} else {
+		change = ice->ak4524_adc_volume[index] != volume[0];
+		if (change) {
+			int codec = index / 2 == 0 ? CODEC_A : CODEC_B;
+			int addr = 4 + index % 2;
+			ice->ak4524_adc_volume[index] = volume[0];
+			snd_ice1712_ak4524_write(ice, codec, addr, volume[0]);
+		}
+	}
+	return change;
+}
+#endif
+
 static int snd_ice1712_build_pro_mixer(ice1712_t *ice, int pcm_pro_dev)
 {
 	static struct snd_mixer_element_volume1_range table_range[2] = {
@@ -1162,8 +1242,8 @@ int snd_ice1712_mixer(ice1712_t * ice, int device, int pcm_count, int *pcm_devs,
 	if (!(ice->eeprom.codec & ICE1712_CFG_NO_CON_AC97)) {
 		ac97_t ac97;
 		memset(&ac97, 0, sizeof(ac97));
-		ac97.write = snd_ice1712_codec_write;
-		ac97.read = snd_ice1712_codec_read;
+		ac97.write = snd_ice1712_ac97_write;
+		ac97.read = snd_ice1712_ac97_read;
 		ac97.private_data = ice;
 		ac97.private_free = snd_ice1712_mixer_free_ac97;
 		if ((err = snd_ac97_mixer(ice->card, device, &ac97, pcm_count, pcm_devs, &mixer)) < 0) {
@@ -1676,6 +1756,17 @@ static int snd_ice1712_read_eeprom(ice1712_t *ice)
 	return 0;
 }
 
+static void snd_ice1712_ak4524_init(ice1712_t *ice)
+{
+	static unsigned char inits[8] = { 0x07, 0x03, 0x60, 0x19,
+					 0x7f, 0x7f, 0x7f, 0x7f };
+	unsigned char reg;
+	for (reg = 0; reg < 8; ++reg) {
+		snd_ice1712_ak4524_write(ice, CODEC_A | CODEC_B, 
+					 reg, inits[reg]);
+	}
+}
+
 static void snd_ice1712_chip_init(ice1712_t *ice)
 {
 	outb(ICE1712_RESET | ICE1712_NATIVE, ICEREG(ice, CONTROL));
@@ -1689,6 +1780,12 @@ static void snd_ice1712_chip_init(ice1712_t *ice)
 	snd_ice1712_write(ice, ICE1712_IREG_GPIO_WRITE_MASK, ice->eeprom.gpiomask);
 	snd_ice1712_write(ice, ICE1712_IREG_GPIO_DIRECTION, ice->eeprom.gpiodir);
 	snd_ice1712_write(ice, ICE1712_IREG_GPIO_DATA, ice->eeprom.gpiostate);
+	switch (ice->eeprom.subvendor) {
+	case ICE1712_SUBDEVICE_DELTA66:
+	case ICE1712_SUBDEVICE_DELTA44:
+		snd_ice1712_ak4524_init(ice);
+		break;
+	}
 }
 
 static void snd_ice1712_build_switches(ice1712_t *ice)
@@ -1741,6 +1838,7 @@ int snd_ice1712_create(snd_card_t * card,
 	if (ice == NULL)
 		return -ENOMEM;
 	spin_lock_init(&ice->reg_lock);
+	init_MUTEX(&ice->gpio_mutex);
 	ice->spdif_defaults = 0x01 |		/* consumer format */
 			      0x10 |		/* no emphasis */
 			      0x20;		/* PCM encoder/decoder */
