@@ -163,11 +163,10 @@ static void snd_intel8x0_setup_fragments(intel8x0_t *codec, ichdev_t *ichdev)
 
 static inline void snd_intel8x0_update(intel8x0_t *codec, ichdev_t *ichdev)
 {
-	unsigned long flags;
 	unsigned int port = codec->bmport + ichdev->reg_offset;
 	int ack = 0;
 
-	spin_lock_irqsave(&codec->reg_lock, flags);
+	spin_lock(&codec->reg_lock);
 	ichdev->position += ichdev->fragsize1;
 	ichdev->position %= ichdev->size;
 	ichdev->lvi++;
@@ -179,7 +178,7 @@ static inline void snd_intel8x0_update(intel8x0_t *codec, ichdev_t *ichdev)
 	// printk("new: bdbar[%i] = 0x%x [0x%x], prefetch = %i, all = 0x%x, 0x%x\n", ichdev->lvi * 2, ichdev->bdbar[ichdev->lvi * 2], ichdev->bdbar[ichdev->lvi * 2 + 1], inb(ICH_REG_PI_PIV + port), inl(port + 4), inb(port + ICH_REG_PI_CR));
 	if ((ack = (--ichdev->ack == 0)) != 0)
 		ichdev->ack = ichdev->ack_reload;
-	spin_unlock_irqrestore(&codec->reg_lock, flags);
+	spin_unlock(&codec->reg_lock);
 	if (ack && ichdev->subchn)
 		snd_pcm_transfer_done(ichdev->subchn);
 	outb(ICH_FIFOE | ICH_BCIS | ICH_LVBCI, port + ICH_REG_PI_SR);
