@@ -401,7 +401,7 @@ int __init snd_rme9652_create (snd_card_t * card,
 	unsigned short cmdw;
 
 	rme9652->card = card;
-	rme9652->lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&rme9652->lock);
 
 	/* XXX whats the return on this if it fails ? */
 
@@ -2438,17 +2438,16 @@ EXPORT_SYMBOL(snd_rme9652_free);
 EXPORT_SYMBOL(snd_rme9652_create);
 EXPORT_SYMBOL(snd_rme9652_interrupt);
 
-#ifdef MODULE
-
-int __init init_module(void)
+static int __init alsa_rme9652_init(void)
 {
 	return 0;
 }
 
-void __exit cleanup_module(void)
+static void __exit alsa_rme9652_exit(void)
 {
 }
 
-#endif
+module_init(alsa_rme9652_init)
+module_exit(alsa_rme9652_exit)
 
 
