@@ -25,7 +25,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    rme9652_mem.c,v 1.3 2000/03/08 13:54:59 perex Exp
+    rme9652_mem.c,v 1.3.2.1 2000/05/24 10:41:21 iwai Exp
 */
 
 #define SND_MAIN_OBJECT_FILE
@@ -103,7 +103,7 @@ static void rme9652_free_pages(char *ptr, unsigned long size)
 	free_pages((unsigned long) ptr, pg);
 }
 
-void *snd_rme9652_get_buffer ()
+void *snd_rme9652_get_buffer (void)
 
 {
 	int i;
