@@ -789,7 +789,7 @@ static int snd_trident_synth_create_port(trident_t * trident, int idx)
 	case TRIDENT_DEVICE_ID_NX:	str = "Trident 4DWave-NX"; break;
 	case TRIDENT_DEVICE_ID_SI7018:	str = "SiS 7018"; break;
 	}
-	sprintf(name, "%s port %i", str);
+	sprintf(name, "%s port %i", str, idx);
 	p->chset->port = snd_seq_event_port_attach(trident->synth.seq_client,
 						   &callbacks,
 						   SND_SEQ_PORT_CAP_WRITE | SND_SEQ_PORT_CAP_SUBS_WRITE,
