@@ -1,8 +1,11 @@
 /*
  *  Copyright (c) 1999 by Uros Bizjak <uros@kss-loka.si>
- *                        Takashi Iwai <iwai@ww.uni-erlangen.de>
+ *                        Takashi Iwai <tiwai@suse.de>
  *
- *  SB16ASP/AWE32 CSP control
+ *  SB16ASP/AWE32 CSP control (http://www.kss-loka.si/~uros/CSP.html)
+ *
+ *  CSP microcode loader:
+ *   http://www.kss-loka.si/~uros/csptools-0.6.0pre1.tar.gz
  *
  *   This program is free software; you can redistribute it and/or modify 
  *   it under the terms of the GNU General Public License as published by
@@ -23,7 +26,6 @@
 #define SND_MAIN_OBJECT_FILE
 #include "../../include/driver.h"
 #include "../../include/info.h"
-#include "../../include/sb.h"
 #include "../../include/sb16_csp.h"
 
 #ifdef MODULE_PARM
@@ -32,6 +34,24 @@ MODULE_DESCRIPTION("ALSA driver for SB16 Creative Signal Processor\n\
 classes: {sound}");
 #endif MODULE_PARM
 
+#ifdef SND_LITTLE_ENDIAN
+#define CSP_HDR_VALUE(a,b,c,d)	((a) | ((b)<<8) | ((c)<<16) | ((d)<<24))
+#define LE_SHORT(v)		(v)
+#define LE_INT(v)		(v)
+#else
+#define CSP_HDR_VALUE(a,b,c,d)	((d) | ((c)<<8) | ((b)<<16) | ((a)<<24))
+#define LE_SHORT(v)		bswap_16(v)
+#define LE_INT(v)		bswap_32(v)
+#endif
+
+#define RIFF_HEADER	CSP_HDR_VALUE('R', 'I', 'F', 'F')
+#define CSP__HEADER	CSP_HDR_VALUE('C', 'S', 'P', ' ')
+#define LIST_HEADER	CSP_HDR_VALUE('L', 'I', 'S', 'T')
+#define FUNC_HEADER	CSP_HDR_VALUE('f', 'u', 'n', 'c')
+#define CODE_HEADER	CSP_HDR_VALUE('c', 'o', 'd', 'e')
+#define INIT_HEADER	CSP_HDR_VALUE('i', 'n', 'i', 't')
+#define MAIN_HEADER	CSP_HDR_VALUE('m', 'a', 'i', 'n')
+
 /*
  * RIFF data format
  */
@@ -50,16 +70,6 @@ typedef struct desc_header {
 	__u16 flags_rates;
 } desc_header_t;
 
-#define CSP_HDR_VALUE(a, b, c, d) (a|(b<<8)|(c<<16)|(d<<24))
-
-#define RIFF_HEADER	CSP_HDR_VALUE('R', 'I', 'F', 'F')
-#define CSP__HEADER	CSP_HDR_VALUE('C', 'S', 'P', ' ')
-#define LIST_HEADER	CSP_HDR_VALUE('L', 'I', 'S', 'T')
-#define FUNC_HEADER	CSP_HDR_VALUE('f', 'u', 'n', 'c')
-#define CODE_HEADER	CSP_HDR_VALUE('c', 'o', 'd', 'e')
-#define INIT_HEADER	CSP_HDR_VALUE('i', 'n', 'i', 't')
-#define MAIN_HEADER	CSP_HDR_VALUE('m', 'a', 'i', 'n')
-
 /*
  * prototypes
  */
@@ -316,12 +326,12 @@ static int snd_sb_csp_riff_load(snd_sb_csp_t * p, snd_sb_csp_microcode_t * mcode
 	if (copy_from_user(&file_h, data_ptr, sizeof(file_h)))
 		return -EFAULT;
 	if ((file_h.name != RIFF_HEADER) ||
-	    (file_h.len >= SND_SB_CSP_MAX_MICROCODE_FILE_SIZE - sizeof(file_h))) {
+	    (LE_INT(file_h.len) >= SND_SB_CSP_MAX_MICROCODE_FILE_SIZE - sizeof(file_h))) {
 		snd_printd(__FUNCTION__ ": Invalid RIFF header\n");
 		return -EINVAL;
 	}
 	data_ptr += sizeof(file_h);
-	data_end = data_ptr + file_h.len;
+	data_end = data_ptr + LE_INT(file_h.len);
 
 	if (copy_from_user(&item_type, data_ptr, sizeof(item_type)))
 		return -EFAULT;
@@ -331,7 +341,7 @@ static int snd_sb_csp_riff_load(snd_sb_csp_t * p, snd_sb_csp_microcode_t * mcode
 	}
 	data_ptr += sizeof (item_type);
 
-	for (; data_ptr < data_end; data_ptr += item_h.len) {
+	for (; data_ptr < data_end; data_ptr += LE_INT(item_h.len)) {
 		if (copy_from_user(&item_h, data_ptr, sizeof(item_h)))
 			return -EFAULT;
 		data_ptr += sizeof(item_h);
@@ -344,14 +354,21 @@ static int snd_sb_csp_riff_load(snd_sb_csp_t * p, snd_sb_csp_microcode_t * mcode
 		case FUNC_HEADER:
 			if (copy_from_user(&funcdesc_h, data_ptr + sizeof(item_type), sizeof(funcdesc_h)))
 				return -EFAULT;
-			func_nr = funcdesc_h.func_nr;
+			func_nr = LE_SHORT(funcdesc_h.func_nr);
 			break;
 		case CODE_HEADER:
 			if (func_nr != info.func_req)
 				break;	/* not required function, try next */
 			data_ptr += sizeof(item_type);
 
-			p->running = 0;	/* Clear all flags */
+			/* destroy QSound mixer element */
+			if (p->mode == SND_SB_CSP_MODE_QSOUND) {
+				snd_sb16_mixer_qsound_destroy(p);
+			}
+			/* Clear all flags */
+			p->running = 0;
+			p->mode = 0;
+
 			/* load microcode blocks */
 			for (;;) {
 				if (data_ptr >= data_end)
@@ -363,11 +380,11 @@ static int snd_sb_csp_riff_load(snd_sb_csp_t * p, snd_sb_csp_microcode_t * mcode
 				if (code_h.name != INIT_HEADER)
 					break;
 				data_ptr += sizeof(code_h);
-				err = snd_sb_csp_load(p, data_ptr, code_h.len,
+				err = snd_sb_csp_load(p, data_ptr, LE_INT(code_h.len),
 						      SND_SB_CSP_LOAD_INITBLOCK | SND_SB_CSP_LOAD_FROMUSER);
 				if (err)
 					return err;
-				data_ptr += code_h.len;
+				data_ptr += LE_INT(code_h.len);
 			}
 			/* main microcode block */
 			if (copy_from_user(&code_h, data_ptr, sizeof(code_h)))
@@ -378,7 +395,7 @@ static int snd_sb_csp_riff_load(snd_sb_csp_t * p, snd_sb_csp_microcode_t * mcode
 				return -EINVAL;
 			}
 			data_ptr += sizeof(code_h);
-			err = snd_sb_csp_load(p, data_ptr, code_h.len,
+			err = snd_sb_csp_load(p, data_ptr, LE_INT(code_h.len),
 					      SND_SB_CSP_LOAD_FROMUSER);
 			if (err)
 				return err;
@@ -387,12 +404,12 @@ static int snd_sb_csp_riff_load(snd_sb_csp_t * p, snd_sb_csp_microcode_t * mcode
 			strncpy(p->codec_name, info.codec_name, sizeof(p->codec_name) - 1);
 			p->codec_name[sizeof(p->codec_name) - 1] = 0;
 			p->func_nr = func_nr;
-			p->mode = funcdesc_h.flags_play_rec;
-			switch (funcdesc_h.VOC_type) {
+			p->mode = LE_SHORT(funcdesc_h.flags_play_rec);
+			switch (LE_SHORT(funcdesc_h.VOC_type)) {
 			case 0x0001:	/* QSound decoder */
-				if (funcdesc_h.flags_play_rec == SND_SB_CSP_MODE_DSP_WRITE) {
-					if (!(snd_sb16_mixer_qsound_build(p)))
-						/* clear all other mode flags */
+				if (LE_SHORT(funcdesc_h.flags_play_rec) == SND_SB_CSP_MODE_DSP_WRITE) {
+					if (snd_sb16_mixer_qsound_build(p) == 0)
+						/* set QSound flag and clear all other mode flags */
 						p->mode = SND_SB_CSP_MODE_QSOUND;
 				}
 				p->acc_format = 0;
@@ -419,12 +436,12 @@ static int snd_sb_csp_riff_load(snd_sb_csp_t * p, snd_sb_csp_microcode_t * mcode
 				p->acc_format = p->acc_width = p->acc_rates = 0;
 				p->mode = 0;
 				snd_printd(__FUNCTION__ ": Unsupported CSP codec type: 0x%04x\n",
-					   funcdesc_h.VOC_type);
+					   LE_SHORT(funcdesc_h.VOC_type));
 				return -EINVAL;
 			}
-			p->acc_channels = funcdesc_h.flags_stereo_mono;
-			p->acc_width = funcdesc_h.flags_16bit_8bit;
-			p->acc_rates = funcdesc_h.flags_rates;
+			p->acc_channels = LE_SHORT(funcdesc_h.flags_stereo_mono);
+			p->acc_width = LE_SHORT(funcdesc_h.flags_16bit_8bit);
+			p->acc_rates = LE_SHORT(funcdesc_h.flags_rates);
 
 			/* Decouple CSP from IRQ and DMAREQ lines */
 			spin_lock_irqsave(&p->codec->reg_lock, flags);
@@ -961,9 +978,6 @@ static int snd_sb16_mixer_qsound_build(snd_sb_csp_t * p)
 	eff1_info.max_space = SND_SB_CSP_QSOUND_MAX_RIGHT;
 
 	snd_debug_check(mixer == NULL, -EINVAL);
-	/* return if QSound element is already built */
-	if (p->qsound_element)
-		return 0;
 
 	spin_lock_init(&p->q_lock);
 
